@@ -142,7 +142,7 @@ autoEEG EEG_readFromBdfFile (MelderFile file) {
 			trace (U"Channel <<", channelNames [ichannel], U">>");
 		}
 		bool hasLetters = str32equ (channelNames [numberOfChannels], U"EDF Annotations");
-		double samplingFrequency = NUMundefined;
+		double samplingFrequency = undefined;
 		for (long channel = 1; channel <= numberOfChannels; channel ++) {
 			fread (buffer, 1, 80, f); buffer [80] = '\0';   // transducer type
 		}
@@ -176,7 +176,7 @@ autoEEG EEG_readFromBdfFile (MelderFile file) {
 		for (long channel = 1; channel <= numberOfChannels; channel ++) {
 			fread (buffer, 1, 8, f); buffer [8] = '\0';   // number of samples in each data record
 			long numberOfSamplesInThisDataRecord = atol (buffer);
-			if (samplingFrequency == NUMundefined) {
+			if (isundef (samplingFrequency)) {
 				numberOfSamplesPerDataRecord = numberOfSamplesInThisDataRecord;
 				samplingFrequency = numberOfSamplesInThisDataRecord / durationOfDataRecord;
 			}
@@ -193,7 +193,7 @@ autoEEG EEG_readFromBdfFile (MelderFile file) {
 		his numberOfChannels = numberOfChannels;
 		autoSound me = Sound_createSimple (numberOfChannels, duration, samplingFrequency);
 		Melder_assert (my nx == numberOfSamplesPerDataRecord * numberOfDataRecords);
-		autoNUMvector <unsigned char> dataBuffer (0L, 3 * numberOfSamplesPerDataRecord - 1);
+		autoNUMvector <unsigned char> dataBuffer ((integer) 0, 3 * numberOfSamplesPerDataRecord - 1);
 		for (long record = 1; record <= numberOfDataRecords; record ++) {
 			for (long channel = 1; channel <= numberOfChannels; channel ++) {
 				double factor = channel == numberOfChannels ? 1.0 : physicalMinimum [channel] / digitalMinimum [channel];
@@ -234,7 +234,7 @@ autoEEG EEG_readFromBdfFile (MelderFile file) {
 		if (hasLetters) {
 			thee = TextGrid_create (0, duration, U"Mark Trigger", U"Mark Trigger");
 			autoMelderString letters;
-			double time = NUMundefined;
+			double time = undefined;
 			for (long i = 1; i <= my nx; i ++) {
 				unsigned long value = (long) my z [numberOfChannels] [i];
 				for (int byte = 1; byte <= numberOfStatusBits / 8; byte ++) {
@@ -244,18 +244,18 @@ autoEEG EEG_readFromBdfFile (MelderFile file) {
 						MelderString_appendCharacter (& letters, kar);
 					} else if (letters. string [0] != U'\0') {
 						if (letters. string [0] == U'+') {
-							if (NUMdefined (time)) {
+							if (isdefined (time)) {
 								try {
 									TextGrid_insertPoint (thee.get(), 1, time, U"");
 								} catch (MelderError) {
 									Melder_throw (U"Did not insert empty mark (", letters. string, U") on Mark tier.");
 								}
-								time = NUMundefined;   // defensive
+								time = undefined;   // defensive
 							}
 							time = Melder_atof (& letters. string [1]);
 							MelderString_empty (& letters);
 						} else {
-							if (! NUMdefined (time)) {
+							if (isundef (time)) {
 								Melder_throw (U"Undefined time for label at sample ", i, U".");
 							}
 							try {
@@ -272,15 +272,15 @@ autoEEG EEG_readFromBdfFile (MelderFile file) {
 							} catch (MelderError) {
 								Melder_throw (U"Did not insert mark (", letters. string, U") on Trigger tier.");
 							}
-							time = NUMundefined;   // crucial
+							time = undefined;   // crucial
 							MelderString_empty (& letters);
 						}
 					}
 				}
 			}
-			if (NUMdefined (time)) {
+			if (isdefined (time)) {
 				TextGrid_insertPoint (thee.get(), 1, time, U"");
-				time = NUMundefined;   // defensive
+				time = undefined;   // defensive
 			}
 		} else {
 			thee = TextGrid_create (0, duration,
@@ -534,11 +534,11 @@ void EEG_setChannelToZero (EEG me, const char32 *channelName) {
 	}
 }
 
-void EEG_removeTriggers (EEG me, int which_Melder_STRING, const char32 *criterion) {
+void EEG_removeTriggers (EEG me, kMelder_string which, const char32 *criterion) {
 	try {
 		if (my textgrid -> tiers->size < 2 || ! Melder_equ (my textgrid -> tiers->at [2] -> name, U"Trigger"))
 			Melder_throw (me, U" does not have a Trigger channel.");
-		TextGrid_removePoints (my textgrid.get(), 2, which_Melder_STRING, criterion);
+		TextGrid_removePoints (my textgrid.get(), 2, which, criterion);
 	} catch (MelderError) {
 		Melder_throw (me, U": triggers not removed.");
 	}
@@ -618,7 +618,7 @@ autoEEG EEG_extractPart (EEG me, double tmin, double tmax, bool preserveTimes) {
 		for (long ichan = 1; ichan <= my numberOfChannels; ichan ++) {
 			thy channelNames [ichan] = Melder_dup (my channelNames [ichan]);
 		}
-		thy sound = Sound_extractPart (my sound.get(), tmin, tmax, kSound_windowShape_RECTANGULAR, 1.0, preserveTimes);
+		thy sound = Sound_extractPart (my sound.get(), tmin, tmax, kSound_windowShape::RECTANGULAR, 1.0, preserveTimes);
 		thy textgrid = TextGrid_extractPart (my textgrid.get(), tmin, tmax, preserveTimes);
 		thy xmin = thy textgrid -> xmin;
 		thy xmax = thy textgrid -> xmax;
