@@ -86,12 +86,12 @@ static void FFNet_checkLayerNumber (FFNet me, long layer) {
 	}
 }
 
-autostring32 FFNet_createNameFromTopology (FFNet me) {
+char32 * FFNet_createNameFromTopology (FFNet me) {
 	autoMelderString name;
-	MelderString_copy (&name, my nUnitsInLayer[0]);
-	for (long i = 1; i <= my nLayers; i++) {
-		MelderString_appendCharacter (&name, U'-');
-		MelderString_append (&name, my nUnitsInLayer[i]);
+	MelderString_copy (& name, my nUnitsInLayer [0]);
+	for (long i = 1; i <= my nLayers; i ++) {
+		MelderString_appendCharacter (& name, U'-');
+		MelderString_append (& name, my nUnitsInLayer [i]);
 	}
 	autostring32 naam = Melder_dup (name.string);
 	return naam.transfer();
@@ -288,7 +288,7 @@ double FFNet_getBias (FFNet me, long layer, long unit) {
 		long bias_unit = my wLast[node];
 		return my w[bias_unit];
 	} catch (MelderError) {
-		return NUMundefined;
+		return undefined;
 	}
 }
 
@@ -582,7 +582,7 @@ long FFNet_getNumberOfUnitsInLayer (FFNet me, int layer) {
 }
 
 double FFNet_getMinimum (FFNet me) {
-	return my minimizer ? Minimizer_getMinimum (my minimizer.get()) : NUMundefined;
+	return ( my minimizer ? Minimizer_getMinimum (my minimizer.get()) : undefined );
 }
 
 void FFNet_drawTopology (FFNet me, Graphics g) {
