@@ -1,6 +1,6 @@
 /* LPC_to_Spectrogram.cpp
  *
- * Copyright (C) 1994-2011, 2015 David Weenink
+ * Copyright (C) 1994-2011, 2015-2017 David Weenink
  *
  * This code is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -35,15 +35,14 @@ autoSpectrogram LPC_to_Spectrogram (LPC me, double dfMin, double bandwidthReduct
 		}
 		double freqStep = samplingFrequency / nfft;
 
-		autoSpectrogram thee = Spectrogram_create (my xmin, my xmax, my nx, my dx, my x1,
-		                                           0.0, samplingFrequency / 2.0, nfft / 2 + 1, freqStep, 0.0);
+		autoSpectrogram thee = Spectrogram_create (my xmin, my xmax, my nx, my dx, my x1, 0.0, samplingFrequency / 2.0, nfft / 2 + 1, freqStep, 0.0);
 
-		for (long i = 1; i <= my nx; i++) {
+		for (long i = 1; i <= my nx; i ++) {
 			double t = Sampled_indexToX (me, i);
 			autoSpectrum spec = LPC_to_Spectrum (me, t, dfMin, bandwidthReduction, deEmphasisFrequency);
-			for (long j = 1; j <= spec -> nx; j++) {
-				double re = spec -> z[1][j], im = spec -> z[2][j];
-				thy z[j][i] =  re * re + im * im;
+			for (long j = 1; j <= spec -> nx; j ++) {
+				double re = spec -> z [1] [j], im = spec -> z [2] [j];
+				thy z [j] [i] =  re * re + im * im;
 			}
 		}
 		return thee;
