@@ -39,18 +39,18 @@ DO
 }
 
 FORM (WINDOW_Art_viewAndEdit, U"View & Edit Articulation", nullptr) {
-	for (int i = 1; i <= kArt_muscle_MAX; i ++)
-		REAL (kArt_muscle_getText (i), U"0.0")
+	for (int i = 1; i <= (int) kArt_muscle::MAX; i ++)
+		REAL (kArt_muscle_getText ((kArt_muscle) i), U"0.0")
 OK
 	FIND_ONE (Art)
-	for (int i = 1; i <= kArt_muscle_MAX; i ++)
-		SET_REAL (kArt_muscle_getText (i), my art [i]);
+	for (int i = 1; i <= (int) kArt_muscle::MAX; i ++)
+		SET_REAL (kArt_muscle_getText ((kArt_muscle) i), my art [i]);
 DO
 	FIND_ONE (Art)
 		if (theCurrentPraatApplication -> batch)
 			Melder_throw (U"Cannot edit an Art from batch.");
-		for (int i = 1; i <= kArt_muscle_MAX; i ++)
-			my art [i] = GET_REAL (kArt_muscle_getText (i));
+		for (int i = 1; i <= (int) kArt_muscle::MAX; i ++)
+			my art [i] = GET_REAL (kArt_muscle_getText ((kArt_muscle) i));
 	END
 }
 
@@ -67,14 +67,14 @@ DO
 }
 
 FORM (GRAPHICS_Artword_draw, U"Draw one Artword tier", nullptr) {
-	OPTIONMENUVAR (muscle, U"Muscle", kArt_muscle_LUNGS)
-	for (int ienum = 1; ienum <= kArt_muscle_MAX; ienum ++)
-		OPTION (kArt_muscle_getText (ienum))
+	OPTIONMENUVAR (muscle, U"Muscle", (int) kArt_muscle::LUNGS)
+	for (int ienum = 1; ienum <= (int) kArt_muscle::MAX; ienum ++)
+		OPTION (kArt_muscle_getText ((kArt_muscle) ienum))
 	BOOLEANVAR (garnish, U"Garnish", true)
 	OK
 DO
 	GRAPHICS_EACH (Artword)
-		Artword_draw (me, GRAPHICS, muscle, garnish);
+		Artword_draw (me, GRAPHICS, (kArt_muscle) muscle, garnish);
 	GRAPHICS_EACH_END
 }
 
@@ -89,13 +89,13 @@ DIRECT (WINDOW_Artword_viewAndEdit) {
 
 FORM (REAL_Artword_getTarget, U"Get one Artword target", nullptr) {
 	REALVAR (time, U"Time (seconds)", U"0.0")
-	OPTIONMENUVAR (muscle, U"Muscle", kArt_muscle_LUNGS)
-	for (int ienum = 1; ienum <= kArt_muscle_MAX; ienum ++)
-		OPTION (kArt_muscle_getText (ienum))
+	OPTIONMENUVAR (muscle, U"Muscle", (int) kArt_muscle::LUNGS)
+	for (int ienum = 1; ienum <= (int) kArt_muscle::MAX; ienum ++)
+		OPTION (kArt_muscle_getText ((kArt_muscle) ienum))
 	OK
 DO
 	NUMBER_ONE (Artword)
-		double result = Artword_getTarget (me, muscle, time);
+		double result = Artword_getTarget (me, (kArt_muscle) muscle, time);
 	NUMBER_ONE_END (U"")
 }
 
@@ -106,14 +106,14 @@ DIRECT (HELP_Artword_help) {
 FORM (MODIFY_Artword_setTarget, U"Set one Artword target", nullptr) {
 	REALVAR (time, U"Time (seconds)", U"0.0")
 	REALVAR (targetValue, U"Target value (0-1)", U"0.0")
-	OPTIONMENUVAR (muscle, U"Muscle", kArt_muscle_LUNGS)
-	for (int ienum = 1; ienum <= kArt_muscle_MAX; ienum ++)
-		OPTION (kArt_muscle_getText (ienum))
+	OPTIONMENUVAR (muscle, U"Muscle", (int) kArt_muscle::LUNGS)
+	for (int ienum = 1; ienum <= (int) kArt_muscle::MAX; ienum ++)
+		OPTION (kArt_muscle_getText ((kArt_muscle) ienum))
 	OK
 DO
 	if (time < 0.0) Melder_throw (U"The specified time should not be less than 0.");
 	MODIFY_EACH (Artword)
-		Artword_setTarget (me, muscle, time, targetValue);
+		Artword_setTarget (me, (kArt_muscle) muscle, time, targetValue);
 	MODIFY_EACH_END
 }
 
@@ -226,7 +226,7 @@ FORM (NEW1_Speaker_create, U"Create a Speaker", U"Create Speaker...") {
 	OK
 DO
 	CREATE_ONE
-		autoSpeaker result = Speaker_create (kindOfSpeaker, Melder_atoi (numberOfTubesInGlottis));
+		autoSpeaker result = Speaker_create (kindOfSpeaker, (int16) Melder_atoi (numberOfTubesInGlottis));   // conversion OK because the values are 1, 2, 10
 	CREATE_ONE_END (name)
 }
 
