@@ -1,6 +1,6 @@
 /* Collection_extensions.cpp
  *
- * Copyright (C) 1994-2011, 2015-2016 David Weenink
+ * Copyright (C) 1994-2011, 2015-2017 David Weenink
  *
  * This code is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -163,7 +163,7 @@ double OrderedOfString_getFractionDifferent (OrderedOfString me, OrderedOfString
 	long numberOfDifferences = OrderedOfString_getNumberOfDifferences (me, thee);
 
 	if (numberOfDifferences < 0) {
-		return NUMundefined;
+		return undefined;
 	}
 	return my size == 0 ? 0.0 : (0.0 + numberOfDifferences) / my size;
 }
