@@ -24,7 +24,7 @@
 */
 
 #include <limits.h>
-#include "../num/NUM.h"
+#include "melder.h"
 #include "regularExp.h"
 
 /* machine precision */
@@ -41,7 +41,7 @@ int NUMstring_containsPrintableCharacter (const char32 *s);
 
 void NUMstring_chopWhiteSpaceAtExtremes_inline (char32 *string);
 
-double *NUMstring_to_numbers (const char32 *s, long *numbers_found);
+real * NUMstring_to_numbers (const char32 *s, integer *numbers_found);
 /* return array with the number of numbers found */
 
 /*
@@ -129,8 +129,8 @@ void NUMdmatrix_printMatlabForm (double **m, long nr, long nc, const char32 *nam
 	7, 8, 9];
 */
 
-bool NUMdmatrix_hasFiniteElements (double **m, long row1, long row2, long col1, long col2);
-/* true if all the elements are finite i.e. not plus or minus infinity, and not NaN */
+bool NUMdmatrix_containsUndefinedElements (double **m, long row1, long row2, long col1, long col2);
+/* true if at least one of the elements is undefined (i.e. infinite or NaN) */
 
 void NUMdmatrix_diagnoseCells (double **m, long rb, long re, long cb, long ce, long maximumNumberOfPositionsToReport);
 /* which cells are not finite? */
@@ -286,7 +286,7 @@ double NUMmultivariateKurtosis (double **x, long nrows, long ncols, int method);
 	method = 1 : Schott (2001), J. of Statistical planning and Inference 94, 25-36.
 */
 
-void NUMmad (double *x, long n, double *location, int wantlocation, double *mad, double *work);
+void NUMmad (double *x, integer n, double *location, bool wantlocation, double *mad, double *work);
 /*
 	Computes the median absolute deviation, i.e., the median of the
 	absolute deviations from the median, and adjust by a factor for
@@ -299,8 +299,8 @@ void NUMmad (double *x, long n, double *location, int wantlocation, double *mad,
 	If work == NULL, the routine allocates (and destroys) its own memory.
  */
 
-void NUMstatistics_huber (double *x, long n, double *location, int wantlocation,
-	double *scale, int wantscale, double k, double tol, double *work);
+void NUMstatistics_huber (double *x, integer n, double *location, bool wantlocation,
+	double *scale, bool wantscale, double k, double tol, double *work);
 /*
 	Finds the Huber M-estimator for location with scale specified,
 	scale with location specified, or both if neither is specified.
@@ -730,7 +730,7 @@ void NUMnrbis (void (*f)(double x, double *fx, double *dfx, void *closure), doub
 	Find the root of a function between xmin and xmax.
 	Method: Newton-Raphson with bisection (i.e., derivative is known!).
 	Error condition:
-		return NUMundefined if root not bracketed.
+		return undefined if root not bracketed.
 */
 
 double NUMridders (double (*f) (double x, void *closure), double xmin, double xmax, void *closure);
