@@ -1,6 +1,6 @@
 /* DTW.cpp
  *
- * Copyright (C) 1993-2013, 2015-2016 David Weenink
+ * Copyright (C) 1993-2013, 2015-2016 David Weenink, 2017 Paul Boersma
  *
  * This code is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -492,7 +492,7 @@ double DTW_getPathY (DTW me, double tx) {
 		i ++;
 	}
 	if (i > my pathLength) {
-		return NUMundefined;
+		return undefined;
 	}
 	long iy = my path [i]. y; /* row */
 
@@ -605,7 +605,7 @@ long DTW_getMaximumConsecutiveSteps (DTW me, int direction) {
 
 static void DTW_paintDistances_raw (DTW me, Graphics g, double xmin, double xmax, double ymin,
                                     double ymax, double minimum, double maximum, bool garnish, bool inset) {
-	long ixmin, ixmax, iymin, iymax;
+	integer ixmin, ixmax, iymin, iymax;
 	if (xmax <= xmin) {
 		xmin = my xmin;
 		xmax = my xmax;
@@ -652,7 +652,7 @@ void DTW_paintDistances (DTW me, Graphics g, double xmin, double xmax, double ym
 }
 
 static double RealTier_getXAtIndex (RealTier me, long point) {
-	double x = NUMundefined;
+	double x = undefined;
 	if (point > 0 && point <= my points.size) {
 		x = my points.at [point] -> number;
 	}
@@ -895,7 +895,7 @@ void DTW_drawDistancesAlongPath (DTW me, Graphics g, double xmin, double xmax, d
 	if (xmin >= xmax) {
 		xmin = my xmin; xmax = my xmax;
 	}
-	long ixmax, ixmin;
+	integer ixmax, ixmin;
 	if (! Matrix_getWindowSamplesX (me, xmin, xmax, & ixmin, & ixmax)) {
 		return;
 	}
@@ -1016,9 +1016,6 @@ autoDTW Spectrograms_to_DTW (Spectrogram me, Spectrogram thee, int matchStart, i
 	}
 }
 
-#define FREQUENCY(frame)  ((frame) -> candidate [1]. frequency)
-#define NOT_VOICED(f)  ((f) <= 0.0 || (f) >= my ceiling)   /* This includes NUMundefined! */
-
 static int Pitch_findFirstAndLastVoicedFrame (Pitch me, long *first, long *last) {
 	*first = 1;
 	while (*first <= my nx && ! Pitch_isVoiced_i (me, *first)) {
@@ -1054,23 +1051,23 @@ autoDTW Pitches_to_DTW_sgc (Pitch me, Pitch thee, double vuv_costs, double time_
 		*/
 		autoDTW him = DTW_create (my xmin, my xmax, my nx, my dx, my x1, thy xmin, thy xmax, thy nx, thy dx, thy x1);
 		autoNUMvector<double> pitchx (1, thy nx);
-		int unit = kPitch_unit_SEMITONES_100;
+		kPitch_unit unit = kPitch_unit::SEMITONES_100;
 		for (long j = 1; j <= thy nx; j++) {
-			pitchx [j] = Sampled_getValueAtSample (thee, j, Pitch_LEVEL_FREQUENCY, unit);
+			pitchx [j] = Sampled_getValueAtSample (thee, j, Pitch_LEVEL_FREQUENCY, (int) unit);
 		}
 
 		for (long i = 1; i <= my nx; i++) {
-			double pitchy = Sampled_getValueAtSample (me, i, Pitch_LEVEL_FREQUENCY, unit);
+			double pitchy = Sampled_getValueAtSample (me, i, Pitch_LEVEL_FREQUENCY, (int) unit);
 			double t1 = my x1 + (i - 1) * my dx;
 			for (long j = 1; j <= thy nx; j++) {
 				double t2 = thy x1 + (j - 1) * thy dx;
-				double dist_f = 0.0; // based on pitch difference
+				double dist_f = 0.0;   // based on pitch difference
 				double dist_t = fabs (t1 - t2);
-				if (pitchy == NUMundefined) {
-					if (pitchx [j] != NUMundefined) {
+				if (isundef (pitchy)) {
+					if (isdefined (pitchx [j])) {
 						dist_f = vuv_costs;
 					}
-				} else if (pitchx [j] == NUMundefined) {
+				} else if (isundef (pitchx [j])) {
 					dist_f = vuv_costs;
 				} else {
 					dist_f = fabs (pitchy - pitchx[j]);
@@ -1096,23 +1093,23 @@ autoDTW Pitches_to_DTW (Pitch me, Pitch thee, double vuv_costs, double time_weig
 
 		autoDTW him = DTW_create (my xmin, my xmax, my nx, my dx, my x1, thy xmin, thy xmax, thy nx, thy dx, thy x1);
 		autoNUMvector<double> pitchx (1, thy nx);
-		int unit = kPitch_unit_SEMITONES_100;
+		kPitch_unit unit = kPitch_unit::SEMITONES_100;
 		for (long j = 1; j <= thy nx; j ++) {
-			pitchx[j] = Sampled_getValueAtSample (thee, j, Pitch_LEVEL_FREQUENCY, unit);
+			pitchx[j] = Sampled_getValueAtSample (thee, j, Pitch_LEVEL_FREQUENCY, (int) unit);
 		}
 
 		for (long i = 1; i <= my nx; i ++) {
-			double pitchy = Sampled_getValueAtSample (me, i, Pitch_LEVEL_FREQUENCY, unit);
+			double pitchy = Sampled_getValueAtSample (me, i, Pitch_LEVEL_FREQUENCY, (int) unit);
 			double t1 = my x1 + (i - 1) * my dx;
 			for (long j = 1; j <= thy nx; j++) {
 				double t2 = thy x1 + (j - 1) * thy dx;
 				double dist_f = 0; // based on pitch difference
 				double dist_t = fabs (t1 - t2);
-				if (pitchy == NUMundefined) {
-					if (pitchx [j] != NUMundefined) {
+				if (isundef (pitchy)) {
+					if (isdefined (pitchx [j])) {
 						dist_f = vuv_costs;
 					}
-				} else if (pitchx [j] == NUMundefined) {
+				} else if (isundef (pitchx [j])) {
 					dist_f = vuv_costs;
 				} else {
 					dist_f = fabs (pitchy - pitchx [j]);
@@ -1167,9 +1164,10 @@ autoMatrix DTW_to_Matrix_cumulativeDistances (DTW me, double sakoeChibaBand, int
     }
 }
 
-
 static void DTW_relaxConstraints (DTW me, double band, int slope, double *relaxedBand, int *relaxedSlope) {
+	(void) slope;
 	double dtw_slope = (my ymax - my ymin - band) / (my xmax - my xmin - band);
+	dtw_slope = dtw_slope+1.0; // fake instruction t avoid compiler warning
 	*relaxedBand = 0.0;
 	*relaxedSlope = 1;
 }
