@@ -25,6 +25,30 @@
 #include "Matrix_extensions.h"
 #include "NUM2.h"
 
+
+autoMatrix Eigen_extractEigenvector (Eigen me, long index, long numberOfRows, long numberOfColumns) {
+	try {
+		if (numberOfRows == 0 && numberOfColumns == 0) {
+			numberOfRows = 1; numberOfColumns = my dimension;
+		}
+		if (numberOfRows == 0) {
+			numberOfRows = lround (ceil ((double) my dimension / numberOfColumns));
+		} else if (numberOfColumns == 0) {
+			numberOfColumns = lround (ceil ((double) my dimension / numberOfRows));
+		}
+		autoMatrix thee = Matrix_createSimple (numberOfRows, numberOfColumns);
+		long i = 1;
+		for (long irow = 1; irow <= numberOfRows; irow++) {
+			for (long icol = 1; icol <= numberOfColumns; icol++) {
+				thy z [irow] [icol] = i <= my dimension ? my eigenvectors [index] [i++] : 0.0;
+			}
+		}
+		return thee;
+	} catch (MelderError) {
+		Melder_throw (me, U"No eigenvector extracted.");
+	}
+}
+
 autoMatrix Eigen_and_Matrix_to_Matrix_projectRows (Eigen me, Matrix thee, long numberOfDimensionsToKeep) {
 	try {
 		if (numberOfDimensionsToKeep <= 0 || numberOfDimensionsToKeep > my numberOfEigenvalues) {
