@@ -61,13 +61,15 @@ void GaussianMixture_updateProbabilityMarginals (GaussianMixture me, double **p,
 long GaussianMixture_getNumberOfParametersInComponent (GaussianMixture me);
 
 static void NUMdvector_scaleAsProbabilities (double *v, long n) {
-	double sum = 0;
-	for (long i = 1; i <= n; i++) {
-		sum += v[i];
+	real80 sum = 0.0;
+	for (long i = 1; i <= n; i ++) {
+		sum += v [i];
 	}
-	if (sum > 0) for (long i = 1; i <= n; i++) {
-			v[i] /= sum;
+	if (sum > 0.0) {
+		for (long i = 1; i <= n; i ++) {
+			v [i] /= sum;
 		}
+	}
 }
 
 static void GaussianMixture_updateCovariance (GaussianMixture me, long component, double **data, long numberOfRows, double **p) {
@@ -81,7 +83,7 @@ static void GaussianMixture_updateCovariance (GaussianMixture me, long component
 	// update the means
 
 	for (long j = 1; j <= thy numberOfColumns; j ++) {
-		thy centroid [j] = 0;
+		thy centroid [j] = 0.0;
 		for (long i = 1; i <= numberOfRows; i ++) {
 			double gamma = mixprob * p [i] [component] / p [i] [my numberOfComponents + 1];
 			thy centroid [j] += gamma * data [i] [j] ; // eq. Bishop 9.17
@@ -257,7 +259,7 @@ autoGaussianMixture TableOfReal_to_GaussianMixture_fromRowLabels (TableOfReal me
 		GaussianMixture_setLabelsFromTableOfReal (thee.get(), me);
 
 		for (long i = 1; i <= numberOfComponents; i ++) {
-			autoTableOfReal tab = TableOfReal_extractRowsWhereLabel (me, kMelder_string_EQUAL_TO, dist -> rowLabels [i]);
+			autoTableOfReal tab = TableOfReal_extractRowsWhereLabel (me, kMelder_string::EQUAL_TO, dist -> rowLabels [i]);
 			autoCovariance cov = TableOfReal_to_Covariance (tab.get());
 			Covariance_into_Covariance (cov.get(), thy covariances->at [i]);
 			Thing_setName (thy covariances->at [i], dist -> rowLabels [i]);
@@ -302,7 +304,7 @@ autoCovariance GaussianMixture_to_Covariance_between (GaussianMixture me) {
 
 		for (long i = 1; i <= my numberOfComponents; i ++) {
 			Covariance him = my covariances->at [i];
-			double nobs = his numberOfObservations - 1; // we loose 1 degree of freedom
+			double nobs = his numberOfObservations - 1; // we lose 1 degree of freedom
 			for (long ir = 1; ir <= my dimension; ir ++) {
 				double dir = his centroid [ir] - thy centroid [ir];
 				for (long ic = ir; ic <= my dimension; ic ++) {
@@ -345,7 +347,7 @@ autoCovariance GaussianMixture_to_Covariance_within (GaussianMixture me) {
 					}
 				}
 			}
-			thy numberOfObservations += his numberOfObservations - 1; // we loose a degree of freedom?
+			thy numberOfObservations += his numberOfObservations - 1; // we lose a degree of freedom?
 		}
 
 		// Leave centroid at 0 so we can add the within and between covariance nicely
@@ -435,7 +437,7 @@ autoPCA GaussianMixture_to_PCA (GaussianMixture me) {
 }
 
 void GaussianMixture_getIntervalsAlongDirections (GaussianMixture me, long d1, long d2, double nsigmas, double *xmin, double *xmax, double *ymin, double *ymax) {
-	*xmin = *xmax = *ymin = *ymax = NUMundefined;
+	*xmin = *xmax = *ymin = *ymax = undefined;
 	if (d1 < 1 || d1 > my dimension || d2 < 1 || d2 > my dimension) {
 		Melder_throw (U"Incorrect directions.");
 	}
@@ -1015,7 +1017,7 @@ void GaussianMixture_removeComponent_bookkeeping (GaussianMixture me, long compo
 }
 
 double GaussianMixture_and_TableOfReal_getLikelihoodValue (GaussianMixture me, TableOfReal thee, int criterion) {
-	double value = NUMundefined;
+	double value = undefined;
 	autoNUMmatrix<double> pp (1, thy numberOfRows + 1, 1, my numberOfComponents + 1);
 	if (GaussianMixture_and_TableOfReal_getProbabilities (me, thee, 0, pp.peek())) {
 		value = GaussianMixture_getLikelihoodValue (me, pp.peek(), thy numberOfRows, criterion);
@@ -1387,7 +1389,7 @@ autoTableOfReal GaussianMixture_and_TableOfReal_to_TableOfReal_BHEPNormalityTest
 			             - 4.0 * pow (delta, -d2) * (1.0 + 3.0 * d * beta4 / (2.0 * delta) + d * (d + 2.0) * beta8 / (2.0 * delta2));
 			double mu2 = mu * mu;
 
-			double prob = NUMundefined, tnb = NUMundefined, lnmu = NUMundefined, lnvar = NUMundefined;
+			double prob = undefined, tnb = undefined, lnmu = undefined, lnvar = undefined;
 
 			try {
 				SSCP_expandLowerCholesky (cov);
