@@ -1,6 +1,6 @@
 /* Intensity_extensions.cpp
  *
- * Copyright (C) 2007-2011 David Weenink, 2015 Paul Boersma
+ * Copyright (C) 2007-2011 David Weenink, 2015,2017 Paul Boersma
  *
  * This code is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -31,12 +31,16 @@ static void IntervalTier_addBoundaryUnsorted (IntervalTier me, long iinterval, d
 		Melder_throw (U"Time is outside interval.");
 	}
 
-	// Find interval to split
+	/*
+		Find interval to split.
+	*/
 	if (iinterval <= 0) {
 		iinterval = IntervalTier_timeToLowIndex (me, time);
 	}
 
-	// Modify end time of left label
+	/*
+		Modify end time of left label.
+	*/
 	TextInterval ti = my intervals.at [iinterval];
 	ti -> xmax = time;
 	TextInterval_setText (ti, leftLabel);
@@ -49,7 +53,7 @@ autoTextGrid Intensity_to_TextGrid_detectSilences (Intensity me, double silenceT
 	try {
 		double duration = my xmax - my xmin, time;
 
-		if (silenceThreshold_dB >= 0) {
+		if (silenceThreshold_dB >= 0.0) {
 			Melder_throw (U"The silence threshold w.r.t. the maximum intensity should be a negative number.");
 		}
 
@@ -61,12 +65,12 @@ autoTextGrid Intensity_to_TextGrid_detectSilences (Intensity me, double silenceT
 		}
 
 		double intensity_max_db, intensity_min_db, xOfMaximum, xOfMinimum;
-		Vector_getMaximumAndX (me, 0, 0, 1, NUM_PEAK_INTERPOLATE_PARABOLIC, &intensity_max_db, &xOfMaximum);
-		Vector_getMinimumAndX (me, 0, 0, 1, NUM_PEAK_INTERPOLATE_PARABOLIC, &intensity_min_db, &xOfMinimum);
+		Vector_getMaximumAndX (me, 0.0, 0.0, 1, NUM_PEAK_INTERPOLATE_PARABOLIC, & intensity_max_db, & xOfMaximum);
+		Vector_getMinimumAndX (me, 0.0, 0.0, 1, NUM_PEAK_INTERPOLATE_PARABOLIC, & intensity_min_db, & xOfMinimum);
 		double intensity_dbRange = intensity_max_db - intensity_min_db;
 
-		if (intensity_dbRange < 10) {
-			Melder_warning (U"The loudest and softest part in your sound only differ by ", intensity_dbRange, U" dB.");
+		if (intensity_dbRange < 10.0) {
+			Melder_warning (U"The loudest and softest part in your sound differ by only ", intensity_dbRange, U" dB.");
 		}
 		double intensityThreshold = intensity_max_db - fabs (silenceThreshold_dB);
 
@@ -74,21 +78,21 @@ autoTextGrid Intensity_to_TextGrid_detectSilences (Intensity me, double silenceT
 			return thee;
 		}
 
-		int inSilenceInterval = my z[1][1] < intensityThreshold;
+		bool inSilenceInterval = my z [1] [1] < intensityThreshold;
 		long iinterval = 1;
 		const char32 *label;
-		for (long i = 2; i <= my nx; i++) {
-			int addBoundary = 0;
-			if (my z[1][i] < intensityThreshold) {
-				if (!inSilenceInterval) { // Start of silence
-					addBoundary = 1;
-					inSilenceInterval = 1;
+		for (long i = 2; i <= my nx; i ++) {
+			bool addBoundary = false;
+			if (my z [1] [i] < intensityThreshold) {
+				if (! inSilenceInterval) {   // start of silence
+					addBoundary = true;
+					inSilenceInterval = true;
 					label = soundingLabel;
 				}
 			} else {
-				if (inSilenceInterval) { // End of silence
-					addBoundary = 1;
-					inSilenceInterval = 0;
+				if (inSilenceInterval) {   // end of silence
+					addBoundary = true;
+					inSilenceInterval = false;
 					label = silenceLabel;
 				}
 			}
@@ -100,17 +104,20 @@ autoTextGrid Intensity_to_TextGrid_detectSilences (Intensity me, double silenceT
 			}
 		}
 
-		// (re)label last interval */
+		/*
+			(re)label last interval.
+		*/
 
 		label = inSilenceInterval ? silenceLabel : soundingLabel;
 		TextInterval_setText (it -> intervals.at [iinterval], label);
 		it -> intervals. sort ();
 
-		// First remove short non-silence intervals in-between silence intervals and
-		// then remove the remaining short silence intervals.
-		// This works much better than first removing short silence intervals and
-		// then short non-silence intervals.
-
+		/*
+			First remove short non-silence intervals in-between silence intervals and
+			then remove the remaining short silence intervals.
+			This works much better than first removing short silence intervals and
+			then short non-silence intervals.
+		*/
 		IntervalTier_cutIntervals_minimumDuration (it, soundingLabel, minSoundingDuration);
 		IntervalTier_cutIntervalsOnLabelMatch (it, silenceLabel);
 		IntervalTier_cutIntervals_minimumDuration (it, silenceLabel, minSilenceDuration);
@@ -127,24 +134,25 @@ autoIntensity IntensityTier_to_Intensity (IntensityTier me, double dt) {
 		long nt = (long) floor ((my xmax - my xmin) / dt);
 		double t1 = 0.5 * dt;
 		autoIntensity thee = Intensity_create (my xmin, my xmax, nt, dt, t1);
-		for (long i = 1; i <= nt; i++) {
+		for (long i = 1; i <= nt; i ++) {
 			double time = t1 + (i - 1) * dt;
-			thy z[1][i] = RealTier_getValueAtTime (me, time);
+			thy z [1] [i] = RealTier_getValueAtTime (me, time);
 		}
 		return thee;
 	} catch (MelderError) {
-		Melder_throw (me, U" no Intensity created.");
+		Melder_throw (me, U": Intensity not created.");
 	}
 }
 
 autoTextGrid IntensityTier_to_TextGrid_detectSilences (IntensityTier me, double dt, double silenceThreshold_dB, double minSilenceDuration,
-	double minSoundingDuration, const char32 *silenceLabel, const char32 *soundingLabel) {
+	double minSoundingDuration, const char32 *silenceLabel, const char32 *soundingLabel)
+{
 	try {
 		autoIntensity intensity = IntensityTier_to_Intensity (me, dt);
 		autoTextGrid thee = Intensity_to_TextGrid_detectSilences (intensity.get(), silenceThreshold_dB, minSilenceDuration, minSoundingDuration, silenceLabel, soundingLabel);
 		return thee;
 	} catch (MelderError) {
-		Melder_throw (me, U" no TextGrid created.");
+		Melder_throw (me, U": TextGrid not created.");
 	}
 }
 
