@@ -80,33 +80,33 @@ void Matrix_scatterPlot (Matrix me, Graphics g, long icx, long icy, double xmin,
 
 void Matrix_drawAsSquares (Matrix me, Graphics g, double xmin, double xmax, double ymin, double ymax, int garnish) {
 	Graphics_Colour colour = Graphics_inqColour (g);
-	long ixmin, ixmax, iymin, iymax;
+	integer ixmin, ixmax, iymin, iymax;
 
 	if (xmax <= xmin) {
 		xmin = my xmin;
 		xmax = my xmax;
 	}
-	long nx = Matrix_getWindowSamplesX (me, xmin, xmax, &ixmin, &ixmax);
+	integer nx = Matrix_getWindowSamplesX (me, xmin, xmax, & ixmin, & ixmax);
 	if (ymax <= ymin) {
 		ymin = my ymin;
 		ymax = my ymax;
 	}
-	long ny = Matrix_getWindowSamplesY (me, ymin, ymax, &iymin, &iymax);
+	integer ny = Matrix_getWindowSamplesY (me, ymin, ymax, & iymin, & iymax);
 	double min, max = nx > ny ? nx : ny;
 	double dx = (xmax - xmin) / max, dy = (ymax - ymin) / max;
 	Graphics_setInner (g);
 	Graphics_setWindow (g, xmin, xmax, ymin, ymax);
 	Matrix_getWindowExtrema (me, ixmin, ixmax, iymin, iymax, & min, & max);
 	double wAbsMax = fabs (max) > fabs (min) ? fabs (max) : fabs (min);
-	for (long i = iymin; i <= iymax; i++) {
+	for (integer i = iymin; i <= iymax; i++) {
 		double y = Matrix_rowToY (me, i);
-		for (long j = ixmin; j <= ixmax; j++) {
+		for (integer j = ixmin; j <= ixmax; j++) {
 			double x = Matrix_columnToX (me, j);
 			double d = 0.95 * sqrt (fabs (my z[i][j]) / wAbsMax);
 			if (d > 0) {
-				double x1WC = x - d * dx / 2, x2WC = x + d * dx / 2;
-				double y1WC = y - d * dy / 2, y2WC = y + d * dy / 2;
-				if (my z[i][j] > 0) {
+				double x1WC = x - d * dx / 2.0, x2WC = x + d * dx / 2.0;
+				double y1WC = y - d * dy / 2.0, y2WC = y + d * dy / 2.0;
+				if (my z [i] [j] > 0.0) {
 					Graphics_setColour (g, Graphics_WHITE);
 				}
 				Graphics_fillRectangle (g, x1WC, x2WC, y1WC, y2WC);
@@ -132,37 +132,41 @@ void Matrix_drawAsSquares (Matrix me, Graphics g, double xmin, double xmax, doub
 
 void Matrix_scale (Matrix me, int choice) {
 	double min, max, extremum;
-	long nZero = 0;
+	integer nZero = 0;
 
 	if (choice == 2) { /* by row */
-		for (long i = 1; i <= my ny; i++) {
+		for (integer i = 1; i <= my ny; i++) {
 			Matrix_getWindowExtrema (me, 1, my nx, i, i, &min, &max);
 			extremum = fabs (max) > fabs (min) ? fabs (max) : fabs (min);
 			if (extremum == 0.0) {
-				nZero++;
-			} else for (long j = 1; j <= my nx; j++) {
-					my z[i][j] /= extremum;
+				nZero ++;
+			} else {
+				for (integer j = 1; j <= my nx; j ++) {
+					my z [i] [j] /= extremum;
 				}
+			}
 		}
 	} else if (choice == 3) { /* by col */
-		for (long j = 1; j <= my nx; j++) {
+		for (integer j = 1; j <= my nx; j++) {
 			Matrix_getWindowExtrema (me, j, j, 1, my ny, &min, &max);
-			extremum =  fabs (max) > fabs (min) ? fabs (max) : fabs (min);
+			extremum = fabs (max) > fabs (min) ? fabs (max) : fabs (min);
 			if (extremum == 0.0) {
-				nZero++;
-			} else for (long i = 1; i <= my ny; i++) {
-					my z[i][j] /= extremum;
+				nZero ++;
+			} else {
+				for (integer i = 1; i <= my ny; i ++) {
+					my z [i] [j] /= extremum;
 				}
+			}
 		}
 	} else if (choice == 1) { /* overall */
 		Matrix_getWindowExtrema (me, 1, my nx, 1, my ny, &min, &max);
 		extremum =  fabs (max) > fabs (min) ? fabs (max) : fabs (min);
 		if (extremum == 0.0) {
-			nZero++;
+			nZero ++;
 		} else {
-			for (long i = 1; i <= my ny; i++) {
-				for (long j = 1; j <= my nx; j++) {
-					my z[i][j] /= extremum;
+			for (integer i = 1; i <= my ny; i ++) {
+				for (integer j = 1; j <= my nx; j ++) {
+					my z [i] [j] /= extremum;
 				}
 			}
 		}
@@ -178,9 +182,9 @@ void Matrix_scale (Matrix me, int choice) {
 autoMatrix Matrix_transpose (Matrix me) {
 	try {
 		autoMatrix thee = Matrix_create (my ymin, my ymax, my ny, my dy, my y1, my xmin, my xmax, my nx, my dx, my x1);
-		for (long i = 1; i <= my ny; i++) {
-			for (long j = 1; j <= my nx; j++) {
-				thy z[j][i] = my z[i][j];
+		for (integer i = 1; i <= my ny; i ++) {
+			for (integer j = 1; j <= my nx; j ++) {
+				thy z [j ][i] = my z [i] [j];
 			}
 		}
 		return thee;
@@ -201,7 +205,7 @@ void Matrix_drawDistribution (Matrix me, Graphics g, double xmin, double xmax, d
 	if (ymax <= ymin) {
 		ymin = my ymin; ymax = my ymax;
 	}
-	long ixmin, ixmax, iymin, iymax;
+	integer ixmin, ixmax, iymin, iymax;
 	if ((Matrix_getWindowSamplesX (me, xmin, xmax, & ixmin, & ixmax) == 0) || 
 		(Matrix_getWindowSamplesY (me, ymin, ymax, & iymin, & iymax) == 0)) {
 		return;
@@ -272,21 +276,21 @@ void Matrix_drawSliceY (Matrix me, Graphics g, double x, double ymin, double yma
 	if (x < my xmin || x > my xmax) {
 		return;
 	}
-	long ix = Matrix_xToNearestColumn (me, x);
+	integer ix = Matrix_xToNearestColumn (me, x);
 
 	if (ymax <= ymin) {
 		ymin = my ymin;
 		ymax = my ymax;
 	}
 
-	long iymin, iymax;
-	long ny = Matrix_getWindowSamplesY (me, ymin, ymax, &iymin, &iymax);
+	integer iymin, iymax;
+	integer ny = Matrix_getWindowSamplesY (me, ymin, ymax, & iymin, & iymax);
 	if (ny < 1) {
 		return;
 	}
 
 	if (max <= min) {
-		Matrix_getWindowExtrema (me, ix, ix, iymin, iymax, &min, &max);
+		Matrix_getWindowExtrema (me, ix, ix, iymin, iymax, & min, & max);
 	}
 	if (max <= min) {
 		min -= 0.5; max += 0.5;
@@ -296,8 +300,8 @@ void Matrix_drawSliceY (Matrix me, Graphics g, double x, double ymin, double yma
 	Graphics_setWindow (g, ymin, ymax, min, max);
 	Graphics_setInner (g);
 
-	for (long i = iymin; i <= iymax; i++) {
-		y[i] = my z[i][ix];
+	for (integer i = iymin; i <= iymax; i ++) {
+		y [i] = my z [i] [ix];
 	}
 	Graphics_function (g, y.peek(), iymin, iymax, Matrix_rowToY (me, iymin), Matrix_rowToY (me, iymax));
 	Graphics_unsetInner (g);
@@ -343,10 +347,10 @@ double Matrix_getMean (Matrix me, double xmin, double xmax, double ymin, double
 	if (ymax <= ymin) {
 		ymin = my ymin; ymax = my ymax;
 	}
-	long ixmin, ixmax, iymin, iymax;
+	integer ixmin, ixmax, iymin, iymax;
 	if ((Matrix_getWindowSamplesX (me, xmin, xmax, & ixmin, & ixmax) == 0) ||
 		(Matrix_getWindowSamplesY (me, ymin, ymax, & iymin, & iymax) == 0)) {
-		return NUMundefined;
+		return undefined;
 	}
 	double sum = 0.0;
 	for (long row = iymin; row <= iymax; row++) {
@@ -364,14 +368,14 @@ double Matrix_getStandardDeviation (Matrix me, double xmin, double xmax, double
 	if (ymax <= ymin) {
 		ymin = my ymin; ymax = my ymax;
 	}
-	long ixmin, ixmax, iymin, iymax;
+	integer ixmin, ixmax, iymin, iymax;
 	if ((Matrix_getWindowSamplesX (me, xmin, xmax, & ixmin, & ixmax) == 0) ||
 		(Matrix_getWindowSamplesY (me, ymin, ymax, & iymin, & iymax) == 0)) {
-		return NUMundefined;
+		return undefined;
 	}
 	long nx = ixmax - ixmin + 1, ny = iymax - iymin + 1;
 	if (nx == 1 && ny == 1) {
-		return NUMundefined;
+		return undefined;
 	}
 	double mean = Matrix_getMean (me, xmin, xmax, ymin, ymax), sum = 0;
 	for (long row = iymin; row <= iymax; row++) {
@@ -415,7 +419,7 @@ autoDaata IDXFormattedMatrixFileRecognizer (int numberOfBytesRead, const char *h
 	trace (U"Cell size =", cellSizeBytes);
 	double numberOfBytes = numberOfCells * cellSizeBytes + 4 + numberOfDimensions * 4;
 	trace (U"Number of bytes =", numberOfBytes);
-	long numberOfBytesInFile = MelderFile_length (file);
+	integer numberOfBytesInFile = MelderFile_length (file);
 	trace (U"File size = ", numberOfBytesInFile);
 	if (numberOfBytes > numberOfBytesInFile || (long) numberOfBytes < numberOfBytesInFile) { // may occur if it is not an IDX file
 		return autoDaata ();
@@ -429,7 +433,7 @@ autoMatrix Matrix_readFromIDXFormatFile (MelderFile file) {
 	/*
 		From: http://yann.lecun.com/exdb/mnist/
 		
-		The IDX file format is a simple format for vectors and multidimensional matrices of various numerical types.
+		The IDX file format is a simple format for multidimensional arrays of various numerical types.
 
 		The basic format is
 
@@ -441,9 +445,9 @@ autoMatrix Matrix_readFromIDXFormatFile (MelderFile file) {
 			size in dimension N
 		data
 
-		The magic number is an integer (MSB first). The first 2 bytes are always 0.
+		The magic number is a four-byte integer (most significant byte first). The first 2 bytes are always 0.
 
-		The third byte codes the type of the data:
+		The third byte encodes the type of the data:
 		0x08: unsigned byte
 		0x09: signed byte
 		0x0B: short (2 bytes)
@@ -451,67 +455,68 @@ autoMatrix Matrix_readFromIDXFormatFile (MelderFile file) {
 		0x0D: float (4 bytes)
 		0x0E: double (8 bytes)
 
-		The 4-th byte codes the number of dimensions of the vector/matrix: 1 for vectors, 2 for matrices....
+		The 4-th byte encodes the number of dimensions (indices) of the array: 1 for vectors, 2 for matrices....
 
-		The sizes in each dimension are 4-byte integers (MSB first, big endian, like in most non-Intel processors).
+		The numbers of elements in each dimension (for a matrix: number of rows and number of columns)
+		are 4-byte integers (MSB first, big endian, as in most non-Intel processors).
 
-		The data is stored like in a C array, i.e. the index in the last dimension changes the fastest. 
+		The data is stored like in a C array, i.e. the index in the last dimension changes the fastest.
 
 	*/
 	try {
 		autofile f = Melder_fopen (file, "r");
-		unsigned int b1 = bingetu1 (f); // 0
-		unsigned int b2 = bingetu1 (f); // 0
+		unsigned int b1 = bingetu8 (f);   // 0
+		unsigned int b2 = bingetu8 (f);   // 0
 		if (b1 != 0 || b2 != 0) {
 			Melder_throw (U"Starting two bytes should be zero.");
 		}
-		unsigned int b3 = bingetu1 (f); // data type
-		unsigned int b4 = bingetu1 (f); // number of dimensions
-		long ncols = bingeti32 (f), nrows = 1; // ok if vector 
+		unsigned int b3 = bingetu8 (f);   // data type
+		unsigned int b4 = bingetu8 (f);   // number of dimensions
+		long ncols = bingeti32 (f), nrows = 1;   // ok if vector
 		if (b4 > 1) {
 			nrows = ncols;
 			ncols = bingeti32 (f);
 		}
-		while (b4 > 2) { // accumulate all other dimensions in the columns
+		while (b4 > 2) {   // accumulate all other dimensions in the columns
 			long n2 = bingeti32 (f);
-			ncols *= n2; // put the matrix in one row
+			ncols *= n2;   // put the matrix in one row
 			-- b4;
 		}
 		autoMatrix me = Matrix_create (0.0, ncols, ncols, 1, 0.5, 0, nrows, nrows, 1.0, 0.5);
-		if (b3 == 0x08) { // unsigned byte
+		if (b3 == 0x08) {   // 8 bits unsigned
 			for (long irow = 1; irow <= nrows; irow ++) {
 				for (long icol = 1; icol <= ncols; icol ++) {
-					my z [irow] [icol] = bingetu1 (f);
+					my z [irow] [icol] = bingetu8 (f);
 				}
 			}
-		} else if (b3 == 0x09) { // signed byte
+		} else if (b3 == 0x09) {   // 8 bits signed
 			for (long irow = 1; irow <= nrows; irow ++) {
 				for (long icol = 1; icol <= ncols; icol ++) {
-					my z [irow] [icol] = bingeti1 (f);
+					my z [irow] [icol] = bingeti8 (f);
 				}
 			}
-		} else if (b3 == 0x0B) { // short (2 bytes)
+		} else if (b3 == 0x0B) {   // 16 bits signed
 			for (long irow = 1; irow <= nrows; irow ++) {
 				for (long icol = 1; icol <= ncols; icol ++) {
-					my z [irow] [icol] = bingeti2 (f);
+					my z [irow] [icol] = bingeti16 (f);
 				}
 			}
-		} else if (b3 == 0x0C) { // int (4 bytes)
+		} else if (b3 == 0x0C) {   // 32 bits signed
 			for (long irow = 1; irow <= nrows; irow ++) {
 				for (long icol = 1; icol <= ncols; icol ++) {
 					my z [irow] [icol] = bingeti32 (f);
 				}
 			}
-		} else if (b3 == 0x0D) { // float (4 bytes)
+		} else if (b3 == 0x0D) {   // 32-bits IEEE floating point
 			for (long irow = 1; irow <= nrows; irow ++) {
 				for (long icol = 1; icol <= ncols; icol ++) {
-					my z [irow] [icol] = bingetr4 (f);
+					my z [irow] [icol] = bingetr32 (f);
 				}
 			}
-		} else if (b3 == 0x0E) { // double (8 bytes)
+		} else if (b3 == 0x0E) {   // 64-bits IEEE floating point
 			for (long irow = 1; irow <= nrows; irow ++) {
 				for (long icol = 1; icol <= ncols; icol ++) {
-					my z [irow] [icol] = bingetr8 (f);
+					my z [irow] [icol] = bingetr64 (f);
 				}
 			}
 		} else {
