@@ -1,6 +1,6 @@
 /* Polynomial.cpp
  *
- * Copyright (C) 1993-2016 David Weenink
+ * Copyright (C) 1993-2016,2017 David Weenink
  *
  * This code is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -62,19 +62,20 @@
 void Polynomial_evaluateWithDerivative (Polynomial me, double x, double *f, double *df) {
 	long double p = my coefficients [my numberOfCoefficients], dp = 0.0, xc = x;
 
-	for (long i = my numberOfCoefficients - 1; i > 0; i--) {
+	for (long i = my numberOfCoefficients - 1; i > 0; i --) {
 		dp = dp * xc + p;
 		p =  p * xc + my coefficients [i];
 	}
-	*f = (double) p; *df = (double) dp;
+	*f = (double) p;
+	*df = (double) dp;
 }
 
 /* Get value and derivative */
 static void Polynomial_evaluateWithDerivative_z (Polynomial me, dcomplex *z, dcomplex *p, dcomplex *dp) {
-	long double pr = my coefficients[my numberOfCoefficients], pi = 0;
-	long double dpr = 0, dpi = 0, x = z -> re, y = z -> im;
+	long double pr = my coefficients[my numberOfCoefficients], pi = 0.0;
+	long double dpr = 0.0, dpi = 0.0, x = z -> re, y = z -> im;
 
-	for (long i = my numberOfCoefficients - 1; i > 0; i--) {
+	for (long i = my numberOfCoefficients - 1; i > 0; i --) {
 		long double tr   = dpr;
 		dpr  =  dpr * x -  dpi * y + pr;
 		dpi  =   tr * y +  dpi * x + pi;
@@ -82,8 +83,8 @@ static void Polynomial_evaluateWithDerivative_z (Polynomial me, dcomplex *z, dco
 		pr   =   pr * x -   pi * y + my coefficients[i];
 		pi   =   tr * y +   pi * x;
 	}
-	p -> re =   (double) pr;  p -> im =  (double) pi;
-	dp -> re =  (double) dpr; dp -> im = (double) dpi;
+	*p = { (double) pr, (double) pi };
+	*dp = { (double) dpr, (double) dpi };
 }
 
 
@@ -97,11 +98,12 @@ void Polynomial_evaluateDerivatives (Polynomial me, double x, double *derivative
 		derivatives [j] = 0.0;
 	}
 	for (long i = degree - 1; i >= 0; i--) {
-		long n = (numberOfDerivatives < (degree - i) ? numberOfDerivatives : degree - i);
-		for (long j = n; j >= 1; j--) {
-			derivatives [j] = derivatives [j] * x +  derivatives [j - 1];
+		long n =
+			numberOfDerivatives < degree - i ? numberOfDerivatives : degree - i;
+		for (long j = n; j >= 1; j --) {
+			derivatives [j] = derivatives [j] * x + derivatives [j - 1];
 		}
-		derivatives [0] = derivatives [0] * x + my coefficients [i + 1];  // Evaluate polynomial (Horner)
+		derivatives [0] = derivatives [0] * x + my coefficients [i + 1];   // evaluate polynomial (Horner)
 	}
 	double fact = 1.0;
 	for (long j = 2; j <= numberOfDerivatives; j ++) {
@@ -131,14 +133,14 @@ static void polynomial_divide (double *u, long m, double *v, long n, double *q,
 	// Copy u[1..m] into r[1..n] to prevent overwriting of u.
 	// Put the q coefficients to zero for cases n > m.
 
-	for (long k = 1; k <= m; k++) {
+	for (long k = 1; k <= m; k ++) {
 		r[k] = u[k];
-		q[k] = 0;
+		q[k] = 0.0;
 	}
 
-	for (long k = m - n + 1; k > 0; k--) { /* D1 */
+	for (long k = m - n + 1; k > 0; k --) { /* D1 */
 		q[k] = r[n + k - 1] / v[n]; /* D2 with u -> r*/
-		for (long j = n + k - 1; j >= k; j--) {
+		for (long j = n + k - 1; j >= k; j --) {
 			r[j] -= q[k] * v[j - k + 1];
 		}
 	}
@@ -156,16 +158,19 @@ static void Polynomial_polish_realroot (Polynomial me, double *x, long maxit) {
 		Polynomial_evaluateWithDerivative (me, *x, &p, &dp);
 		double fabsp = fabs (p);
 		if (fabsp > pmin || fabs (fabsp - pmin) < NUMfpp -> eps) {
-			// We stop because the approximation gets worse or we cannot get closer anymore
-			// Return previous (best) value for x.
-
-			*x = xbest; return;
-		}
-		pmin = fabsp; xbest = *x;
-		if (fabs (dp) == 0) {
+			/*
+				We stop, because the approximation is getting worse or we cannot get any closer.
+				Return the previous (hitherto best) value for x.
+			*/
+			*x = xbest;
 			return;
 		}
-		double dx = p / dp; /* Newton -Raphson */
+		pmin = fabsp;
+		xbest = *x;
+		if (fabs (dp) == 0.0) {
+			return;
+		}
+		double dx = p / dp;   // Newton-Raphson
 		*x -= dx;
 	}
 	// Melder_throw (U"Maximum number of iterations exceeded.");
@@ -183,16 +188,19 @@ static void Polynomial_polish_complexroot_nr (Polynomial me, dcomplex *z, long m
 		Polynomial_evaluateWithDerivative_z (me, z, &p, &dp);
 		double fabsp = dcomplex_abs (p);
 		if (fabsp > pmin || fabs (fabsp - pmin) < NUMfpp -> eps) {
-			// We stop because the approximation gets worse.
-			// Return previous (best) value for z.
-
-			*z = zbest; return;
-		}
-		pmin = fabsp; zbest = *z;
-		if (dcomplex_abs (dp) == 0) {
+			/*
+				We stop, because the approximation is getting worse.
+				Return the previous (hitherto best) value for z.
+			*/
+			*z = zbest;
 			return;
 		}
-		dcomplex dz = dcomplex_div (p , dp); /* Newton -Raphson */
+		pmin = fabsp;
+		zbest = *z;
+		if (dcomplex_abs (dp) == 0.0) {
+			return;
+		}
+		dcomplex dz = dcomplex_div (p, dp);   // Newton-Raphson
 		*z = dcomplex_sub (*z, dz);
 	}
 	// Melder_throw (U"Maximum number of iterations exceeded.");
@@ -224,36 +232,42 @@ static void NUMpolynomial_recurrence (double *pn, long degree, double a, double
 static void svdcvm (double **v, long mfit, long ma, int *frozen, double *w, double **cvm) {
 	autoNUMvector<double> wti (1, mfit);
 
-	for (long i = 1; i <= mfit; i++) {
+	for (long i = 1; i <= mfit; i ++) {
 		if (w[i] != 0.0) {
 			wti[i] = 1.0 / (w[i] * w[i]);
+		} else {
+			;   // TODO: write up an explanation for why it is not necessary to do anything if w[i] is zero
 		}
 	}
-	for (long i = 1; i <= mfit; i++) {
-		for (long j = 1; j <= i; j++) {
-			double sum = 0;
-			for (long k = 1; k <= mfit; k++) {
+	for (long i = 1; i <= mfit; i ++) {
+		for (long j = 1; j <= i; j ++) {
+			long double sum = 0.0;
+			for (long k = 1; k <= mfit; k ++) {
 				sum += v[i][k] * v[j][k] * wti[k];
 			}
-			cvm[j][i] = cvm[i][j] = sum;
+			cvm[j][i] = cvm[i][j] = (double) sum;
 		}
 	}
 
-	for (long i = mfit + 1; i <= ma; i++) {
-		for (long j = 1; j <= i; j++) {
-			cvm[j][i] = cvm[i][j] = 0;
+	for (long i = mfit + 1; i <= ma; i ++) {
+		for (long j = 1; j <= i; j ++) {
+			cvm[j][i] = cvm[i][j] = 0.0;
 		}
 	}
 
 	long k = mfit;
-	for (long j = ma; j > 0; j--) {
+	for (long j = ma; j > 0; j --) {
 		//			if (! frozen || ! frozen[i]) why i?? TODO
 		if (! frozen || ! frozen[j]) {
-			for (long i = 1; i <= ma; i++) {
-				double t = cvm[i][k]; cvm[i][k] = cvm[i][j]; cvm[i][j] = t;
+			for (long i = 1; i <= ma; i ++) {
+				double t = cvm[i][k];
+				cvm[i][k] = cvm[i][j];
+				cvm[i][j] = t;
 			}
-			for (long i = 1; i <= ma; i++) {
-				double t = cvm[k][i]; cvm[k][i] = cvm[j][i]; cvm[j][i] = t;
+			for (long i = 1; i <= ma; i ++) {
+				double t = cvm[k][i];
+				cvm[k][i] = cvm[j][i];
+				cvm[j][i] = t;
 			}
 			k--;
 		}
@@ -264,20 +278,17 @@ static void svdcvm (double **v, long mfit, long ma, int *frozen, double *w, doub
 
 Thing_implement (FunctionTerms, Function, 0);
 
-double structFunctionTerms :: v_evaluate (double x) {
-	(void) x;
-	return NUMundefined;
+double structFunctionTerms :: v_evaluate (double /* x */) {
+	return undefined;
 }
 
-void structFunctionTerms :: v_evaluate_z (dcomplex *z, dcomplex *p) {
-	(void) z;
-	p -> re = p -> im = NUMundefined;
+dcomplex structFunctionTerms :: v_evaluate_z (dcomplex /* z */) {
+	return { undefined, undefined };
 }
 
-void structFunctionTerms :: v_evaluateTerms (double x, double terms[]) {
-	(void) x;
-	for (long i = 1; i <= numberOfCoefficients; i++) {
-		terms[i] = NUMundefined;
+void structFunctionTerms :: v_evaluateTerms (double /* x */, double terms []) {
+	for (long i = 1; i <= numberOfCoefficients; i ++) {
+		terms [i] = undefined;
 	}
 }
 
@@ -315,9 +326,9 @@ void structFunctionTerms :: v_getExtrema (double x1, double x2, double *p_xmin,
 	}
 }
 
-static inline void FunctionTerms_extendCapacityIf (FunctionTerms me, long minimum) {
+static inline void FunctionTerms_extendCapacityIf (FunctionTerms me, integer minimum) {
 	if (my _capacity < minimum) {
-		NUMvector_append<double> (& my coefficients, 1, & minimum);
+		NUMvector_append <double> (& my coefficients, 1, & minimum);
 		my _capacity = minimum;
 	}
 }
@@ -340,12 +351,12 @@ autoFunctionTerms FunctionTerms_create (double xmin, double xmax, long numberOfC
 	}
 }
 
-void FunctionTerms_initFromString (FunctionTerms me, double xmin, double xmax, const char32 *s, int allowTrailingZeros) {
-	long numberOfCoefficients;
-	autoNUMvector<double> numbers (NUMstring_to_numbers (s, &numberOfCoefficients), 1);
+void FunctionTerms_initFromString (FunctionTerms me, double xmin, double xmax, const char32 *s, bool allowTrailingZeros) {
+	integer numberOfCoefficients;
+	autoNUMvector <real> numbers (NUMstring_to_numbers (s, & numberOfCoefficients), 1);
 	if (! allowTrailingZeros) {
-		while (numbers[numberOfCoefficients] == 0 && numberOfCoefficients > 1) {
-			numberOfCoefficients--;
+		while (numbers [numberOfCoefficients] == 0 && numberOfCoefficients > 1) {
+			numberOfCoefficients --;
 		}
 	}
 
@@ -365,8 +376,8 @@ double FunctionTerms_evaluate (FunctionTerms me, double x) {
 	return my v_evaluate (x);
 }
 
-void FunctionTerms_evaluate_z (FunctionTerms me, dcomplex *z, dcomplex *p) {
-	my v_evaluate_z (z, p);
+dcomplex FunctionTerms_evaluate_z (FunctionTerms me, dcomplex z) {
+	return my v_evaluate_z (z);
 }
 
 void FunctionTerms_evaluateTerms (FunctionTerms me, double x, double terms[]) {
@@ -550,17 +561,17 @@ double structPolynomial :: v_evaluate (double x) {
 	return (double) p;
 }
 
-void structPolynomial :: v_evaluate_z (dcomplex *z, dcomplex *p) {
-	long double x = z -> re, y = z -> im;
+dcomplex structPolynomial :: v_evaluate_z (dcomplex z) {
+	real80 x = z.re, y = z.im;
 
-	long double pr = coefficients [numberOfCoefficients];
-	long double pi = 0;
-	for (long i = numberOfCoefficients - 1; i > 0; i--) {
+	real80 pr = coefficients [numberOfCoefficients];
+	real80 pi = 0.0;
+	for (long i = numberOfCoefficients - 1; i > 0; i --) {
 		long double prtmp = pr;
-		pr =  pr * x - pi * y + coefficients[i];
+		pr =  pr * x - pi * y + coefficients [i];
 		pi = prtmp * y + pi * x;
 	}
-	p -> re = (double) pr; p -> im = (double) pi;
+	return { (double) pr, (double) pi };
 }
 
 void structPolynomial :: v_evaluateTerms (double x, double terms[]) {
@@ -674,8 +685,8 @@ autoPolynomial Polynomial_scaleX (Polynomial me, double xmin, double xmax) {
 
 		double a = (my xmin - my xmax) / (xmin - xmax);
 		double b = my xmin - a * xmin;
-		thy coefficients[2] = my coefficients[2] * a;
-		thy coefficients[1] += my coefficients[2] * b;
+		thy coefficients [2] = my coefficients [2] * a;
+		thy coefficients [1] += my coefficients [2] * b;
 		if (my numberOfCoefficients == 2) {
 			return thee;
 		}
@@ -686,13 +697,15 @@ autoPolynomial Polynomial_scaleX (Polynomial me, double xmin, double xmax) {
 
 		// Start the recursion: P[1] = a x + b; P[0] = 1;
 
-		pnm1[2] = a; pnm1[1] = b; pnm2[1] = 1;
-		for (long n = 2; n <= my numberOfCoefficients - 1; n++) {
+		pnm1 [2] = a;
+		pnm1 [1] = b;
+		pnm2 [1] = 1;
+		for (long n = 2; n <= my numberOfCoefficients - 1; n ++) {
 			double *t1 = pnm1, *t2 = pnm2;
 			NUMpolynomial_recurrence (pn, n, a, b, 0, pnm1, pnm2);
 			if (my coefficients[n + 1] != 0) {
-				for (long j = 1; j <= n + 1; j++) {
-					thy coefficients[j] += my coefficients[n + 1] * pn[j];
+				for (long j = 1; j <= n + 1; j ++) {
+					thy coefficients [j] += my coefficients [n + 1] * pn [j];
 				}
 			}
 			pnm1 = pn;
@@ -709,22 +722,23 @@ double Polynomial_evaluate (Polynomial me, double x) {
 	return my v_evaluate (x);
 }
 
-void Polynomial_evaluate_z (Polynomial me, dcomplex *z, dcomplex *p) {
-	my v_evaluate_z (z, p);
+dcomplex Polynomial_evaluate_z (Polynomial me, dcomplex z) {
+	my v_evaluate_z (z);
 }
 
 static void Polynomial_evaluate_z_cart (Polynomial me, double r, double phi, double *re, double *im) {
 	double rn = 1;
 
-	*re = my coefficients[1]; *im = 0;
-	if (r == 0) {
+	*re = my coefficients [1];
+	*im = 0.0;
+	if (r == 0.0) {
 		return;
 	}
-	for (long i = 2; i <= my numberOfCoefficients; i++) {
+	for (long i = 2; i <= my numberOfCoefficients; i ++) {
 		rn *= r;
 		double arg = (i - 1) * phi;
-		*re += my coefficients[i] * rn * cos (arg);
-		*im += my coefficients[i] * rn * sin (arg);
+		*re += my coefficients [i] * rn * cos (arg);
+		*im += my coefficients [i] * rn * sin (arg);
 	}
 }
 
@@ -735,8 +749,8 @@ autoPolynomial Polynomial_getDerivative (Polynomial me) {
 			return Polynomial_create (my xmin, my xmax, 0);
 		}
 		autoPolynomial thee = Polynomial_create (my xmin, my xmax, my numberOfCoefficients - 2);
-		for (long i = 1; i <= thy numberOfCoefficients; i++) {
-			thy coefficients[i] = i * my coefficients[i + 1];
+		for (long i = 1; i <= thy numberOfCoefficients; i ++) {
+			thy coefficients [i] = i * my coefficients [i + 1];
 		}
 		return thee;
 	} catch (MelderError) {
@@ -747,8 +761,8 @@ autoPolynomial Polynomial_getDerivative (Polynomial me) {
 autoPolynomial Polynomial_getPrimitive (Polynomial me, double constant) {
 	try {
 		autoPolynomial thee = Polynomial_create (my xmin, my xmax, my numberOfCoefficients);
-		for (long i = 1; i <= my numberOfCoefficients; i++) {
-			thy coefficients[i + 1] = my coefficients[i] / i;
+		for (long i = 1; i <= my numberOfCoefficients; i ++) {
+			thy coefficients [i + 1] = my coefficients [i] / i;
 		}
 		thy coefficients [1] = constant;
 		return thee;
@@ -766,9 +780,9 @@ void Polynomial_initFromRealRoots (Polynomial me, double *roots, long numberOfRo
 		FunctionTerms_extendCapacityIf (me, numberOfRoots + 1);
 		double *c = & my coefficients [1];
 		long n = 1;
-		c [0] = - roots[1];
+		c [0] = - roots [1];
 		c [1] = 1.0;
-		for (long i = 2; i <= numberOfRoots; i++) {
+		for (long i = 2; i <= numberOfRoots; i ++) {
 			c [n + 1] = c [n];
 			for (long j = n; j >= 1; j --) {
 				c [j] = c [j - 1] - c [j] * roots [i];
@@ -785,7 +799,7 @@ void Polynomial_initFromRealRoots (Polynomial me, double *roots, long numberOfRo
 autoPolynomial Polynomial_createFromRealRootsString (double xmin, double xmax, const char32 *s) {
 	try {
 		autoPolynomial me = Thing_new (Polynomial);
-		long numberOfRoots;
+		integer numberOfRoots;
 		autoNUMvector<double> roots (NUMstring_to_numbers (s, & numberOfRoots), 1);
 		FunctionTerms_init (me.get(), xmin, xmax, numberOfRoots + 1);
 		Polynomial_initFromRealRoots (me.get(), roots.peek(), numberOfRoots);
@@ -813,7 +827,7 @@ void Polynomial_initFromProductOfSecondOrderTerms (Polynomial me, double *a, lon
 		for (long j = numberOfCoefficients; j > 2; j --) {
 			my coefficients [j] += a [i] * my coefficients [j - 1] + my coefficients [j - 2];
 		}
-		my coefficients [2] += a [i]; // a [i] * my coefficients [1]
+		my coefficients [2] += a [i];   // a [i] * my coefficients [1]
 		numberOfCoefficients += 2;
 	}
 	my numberOfCoefficients = numberOfCoefficients;
@@ -822,8 +836,8 @@ void Polynomial_initFromProductOfSecondOrderTerms (Polynomial me, double *a, lon
 autoPolynomial Polynomial_createFromProductOfSecondOrderTermsString (double xmin, double xmax, const char32 *s) {
 	try {
 		autoPolynomial me = Thing_new (Polynomial);
-		long numberOfTerms;
-		autoNUMvector<double> a (NUMstring_to_numbers (s, & numberOfTerms), 1);
+		integer numberOfTerms;
+		autoNUMvector <real> a (NUMstring_to_numbers (s, & numberOfTerms), 1);
 		FunctionTerms_init (me.get(), xmin, xmax, 2 * numberOfTerms + 1);
 		Polynomial_initFromProductOfSecondOrderTerms (me.get(), a.peek(), numberOfTerms);
 		return me;
@@ -920,7 +934,7 @@ void Polynomials_divide (Polynomial me, Polynomial thee, autoPolynomial *q, auto
 		if (degree < 0) {
 			degree = 0;
 		}
-		while (degree > 1 && rc[degree] == 0) {
+		while (degree > 1 && rc [degree] == 0.0) {
 			degree--;
 		}
 		ar = Polynomial_create (my xmin, my xmax, degree);
@@ -935,18 +949,18 @@ void Polynomials_divide (Polynomial me, Polynomial thee, autoPolynomial *q, auto
 Thing_implement (LegendreSeries, FunctionTerms, 0);
 
 double structLegendreSeries :: v_evaluate (double x) {
-	double p = coefficients[1];
+	double p = coefficients [1];
 
 	// Transform x from domain [xmin, xmax] to domain [-1, 1]
 
 	if (x < xmin || x > xmax) {
-		return NUMundefined;
+		return undefined;
 	}
 
 	double pim1 = x = (2 * x - xmin - xmax) / (xmax - xmin);
 
 	if (numberOfCoefficients > 1) {
-		double pim2 = 1, twox = 2 * x, f2 = x, d = 1.0;
+		double pim2 = 1, twox = 2.0 * x, f2 = x, d = 1.0;
 		p += coefficients[2] * pim1;
 		for (long i = 3; i <= numberOfCoefficients; i++) {
 			double f1 = d++;
@@ -961,8 +975,8 @@ double structLegendreSeries :: v_evaluate (double x) {
 
 void structLegendreSeries :: v_evaluateTerms (double x, double terms[]) {
 	if (x < xmin || x > xmax) {
-		for (long i = 1; i <= numberOfCoefficients; i++) {
-			terms[i] = NUMundefined;
+		for (long i = 1; i <= numberOfCoefficients; i ++) {
+			terms[i] = undefined;
 		}
 		return;
 	}
@@ -973,12 +987,12 @@ void structLegendreSeries :: v_evaluateTerms (double x, double terms[]) {
 
 	terms[1] = 1;
 	if (numberOfCoefficients > 1) {
-		double twox = 2 * x, f2 = x, d = 1.0;
+		double twox = 2.0 * x, f2 = x, d = 1.0;
 		terms[2] = x;
-		for (long i = 3; i <= numberOfCoefficients; i++) {
-			double f1 = d++;
+		for (long i = 3; i <= numberOfCoefficients; i ++) {
+			double f1 = d ++;
 			f2 += twox;
-			terms[i] = (f2 * terms[i - 1] - f1 * terms[i - 2]) / d;
+			terms[i] = (f2 * terms [i - 1] - f1 * terms [i - 2]) / d;
 		}
 	}
 }
@@ -1017,12 +1031,12 @@ autoLegendreSeries LegendreSeries_getDerivative (LegendreSeries me) {
 	try {
 		autoLegendreSeries thee = LegendreSeries_create (my xmin, my xmax, my numberOfCoefficients - 1);
 
-		for (long n = 1; n <= my numberOfCoefficients - 1; n++) {
+		for (long n = 1; n <= my numberOfCoefficients - 1; n ++) {
 			// P[n]'(x) = Sum (k=0..nonNegative, (2n - 4k - 1) P[n-2k-1](x))
 
 			long n2 = n - 1;
-			for (long k = 0; n2 >= 0; k++, n2 -= 2) {
-				thy coefficients [n2 + 1] += (2 * n - 4 * k - 1) * my coefficients[n + 1];
+			for (long k = 0; n2 >= 0; k ++, n2 -= 2) {
+				thy coefficients [n2 + 1] += (2 * n - 4 * k - 1) * my coefficients [n + 1];
 			}
 		}
 		return thee;
@@ -1036,12 +1050,12 @@ autoPolynomial LegendreSeries_to_Polynomial (LegendreSeries me) {
 		double xmin = -1, xmax = 1;
 		autoPolynomial thee = Polynomial_create (xmin, xmax, my numberOfCoefficients - 1);
 
-		thy coefficients[1] = my coefficients[1]; /* * p[1] */
+		thy coefficients [1] = my coefficients [1];   /* * p[1] */
 		if (my numberOfCoefficients == 1) {
 			return thee;
 		}
 
-		thy coefficients[2] = my coefficients[2]; /* * p[2] */
+		thy coefficients [2] = my coefficients [2];   /* * p[2] */
 		if (my numberOfCoefficients > 2) {
 			autoNUMvector<double> buf (1, 3 * my numberOfCoefficients);
 
@@ -1051,15 +1065,16 @@ autoPolynomial LegendreSeries_to_Polynomial (LegendreSeries me) {
 
 			// Start the recursion: P[1] = x; P[0] = 1;
 
-			pnm1[2] = 1; pnm2[1] = 1;
-			for (long n = 2; n <= my numberOfCoefficients - 1; n++) {
+			pnm1 [2] = 1;
+			pnm2 [1] = 1;
+			for (long n = 2; n <= my numberOfCoefficients - 1; n ++) {
 				double a = (2 * n - 1.0) / n;
 				double c = - (n - 1.0) / n;
 				double *t1 = pnm1, *t2 = pnm2;
 				NUMpolynomial_recurrence (pn, n, a, 0, c, pnm1, pnm2);
-				if (my coefficients[n + 1] != 0) {
-					for (long j = 1; j <= n + 1; j++) {
-						thy coefficients[j] += my coefficients[n + 1] * pn[j];
+				if (my coefficients [n + 1] != 0) {
+					for (long j = 1; j <= n + 1; j ++) {
+						thy coefficients [j] += my coefficients [n + 1] * pn [j];
 					}
 				}
 				pnm1 = pn; pnm2 = t1; pn = t2;
@@ -1089,17 +1104,17 @@ autoRoots Roots_create (long numberOfRoots) {
 }
 
 void Roots_fixIntoUnitCircle (Roots me) {
-	dcomplex z10 = dcomplex_create (1, 0);
-	for (long i = my min; i <= my max; i++) {
-		if (dcomplex_abs (my v[i]) > 1.0) {
-			my v[i] = dcomplex_div (z10, dcomplex_conjugate (my v[i]));
+	dcomplex z10 { 1.0, 0.0 };
+	for (long i = my min; i <= my max; i ++) {
+		if (dcomplex_abs (my v [i]) > 1.0) {
+			my v [i] = dcomplex_div (z10, dcomplex_conjugate (my v [i]));
 		}
 	}
 }
 
 static void NUMdcvector_extrema_re (dcomplex v[], long lo, long hi, double *min, double *max) {
 	*min = *max = v[lo].re;
-	for (long i = lo + 1; i <= hi; i++) {
+	for (long i = lo + 1; i <= hi; i ++) {
 		if (v[i].re < *min) {
 			*min = v[i].re;
 		} else if (v[i].re > *max) {
@@ -1110,11 +1125,11 @@ static void NUMdcvector_extrema_re (dcomplex v[], long lo, long hi, double *min,
 
 static void NUMdcvector_extrema_im (dcomplex v[], long lo, long hi, double *min, double *max) {
 	*min = *max = v[lo].im;
-	for (long i = lo + 1; i <= hi; i++) {
-		if (v[i].im < *min) {
-			*min = v[i].im;
-		} else if (v[i].im > *max) {
-			*max = v[i].im;
+	for (long i = lo + 1; i <= hi; i ++) {
+		if (v [i]. im < *min) {
+			*min = v [i]. im;
+		} else if (v [i]. im > *max) {
+			*max = v [i]. im;
 		}
 	}
 }
@@ -1124,14 +1139,15 @@ void Roots_draw (Roots me, Graphics g, double rmin, double rmax, double imin, do
 	double eps = 1e-6;
 
 	if (rmax <= rmin) {
-		NUMdcvector_extrema_re (my v, 1, my max, &rmin, &rmax);
+		NUMdcvector_extrema_re (my v, 1, my max, & rmin, & rmax);
 	}
 	double denum = fabs (rmax) > fabs (rmin) ? fabs (rmax) : fabs (rmin);
 	if (denum == 0) {
 		denum = 1;
 	}
 	if (fabs ( (rmax - rmin) / denum) < eps) {
-		rmin -= 1; rmax += 1;
+		rmin -= 1;
+		rmax += 1;
 	}
 	if (imax <= imin) {
 		NUMdcvector_extrema_im (my v, 1, my max, &imin, &imax);
@@ -1141,7 +1157,8 @@ void Roots_draw (Roots me, Graphics g, double rmin, double rmax, double imin, do
 		denum = 1;
 	}
 	if (fabs ( (imax - imin) / denum) < eps) {
-		imin -= 1; imax += 1;
+		imin -= 1;
+		imax += 1;
 	}
 	Graphics_setInner (g);
 	Graphics_setWindow (g, rmin, rmax, imin, imax);
@@ -1157,10 +1174,10 @@ void Roots_draw (Roots me, Graphics g, double rmin, double rmax, double imin, do
 	Graphics_unsetInner (g);
 	if (garnish) {
 		Graphics_drawInnerBox (g);
-		if (rmin * rmax < 0) {
+		if (rmin * rmax < 0.0) {
 			Graphics_markLeft (g, 0.0, true, true, true, U"0");
 		}
-		if (imin * imax < 0) {
+		if (imin * imax < 0.0) {
 			Graphics_markBottom (g, 0.0, true, true, true, U"0");
 		}
 		Graphics_marksLeft (g, 2, true, true, false);
@@ -1182,8 +1199,8 @@ autoRoots Polynomial_to_Roots (Polynomial me) {
 		// parts of eigenvalues wr[1..n] and wi[1..n].
 
 		autoNUMvector<double> hes (1, n2 + n + n);
-		double *wr = &hes[n2];
-		double *wi = &hes[n2 + n];
+		double *wr = & hes [n2];
+		double *wi = & hes [n2 + n];
 
 		// Fill the upper Hessenberg matrix (storage is Fortran)
 		// C: [i][j] -> Fortran: (j-1)*n + i
@@ -1199,7 +1216,7 @@ autoRoots Polynomial_to_Roots (Polynomial me) {
 
 		char job = 'E', compz = 'N';
 		long ilo = 1, ihi = n, ldh = n, ldz = n, lwork = -1, info;
-		double *z = 0, wt[1];
+		double *z = 0, wt [1];
 		NUMlapack_dhseqr (&job, &compz, &n, &ilo, &ihi, &hes[1], &ldh, &wr[1], &wi[1], z, &ldz, wt, &lwork, &info);
 		if (info != 0) {
 			if (info < 0) {
@@ -1293,7 +1310,7 @@ double Polynomial_findOneSimpleRealRoot_ridders (Polynomial me, double xmin, dou
 }
 
 void Polynomial_divide_firstOrderFactor (Polynomial me, double factor, double *p_remainder) { // P(x)/(x-a)
-	double remainder = NUMundefined;
+	double remainder = undefined;
 	if (my numberOfCoefficients > 1) {
 		remainder = my coefficients [my numberOfCoefficients];
 		for (long j = my numberOfCoefficients - 1; j > 0; j --) {
@@ -1414,7 +1431,7 @@ Thing_implement (ChebyshevSeries, FunctionTerms, 0);
 */
 double structChebyshevSeries :: v_evaluate (double x) {
 	if (x < xmin || x > xmax) {
-		return NUMundefined;
+		return undefined;
 	}
 
 	double d1 = 0, d2 = 0;
@@ -1438,7 +1455,7 @@ double structChebyshevSeries :: v_evaluate (double x) {
 void structChebyshevSeries :: v_evaluateTerms (double x, double *terms) {
 	if (x < xmin || x > xmax) {
 		for (long i = 1; i <= numberOfCoefficients; i++) {
-			terms[i] = NUMundefined;
+			terms[i] = undefined;
 		}
 		return;
 	}
@@ -1565,7 +1582,7 @@ void FunctionTerms_and_RealTier_fit (FunctionTerms me, RealTier thee, int freeze
 		autoSVD svd = SVD_create (numberOfData, numberOfFreeParameters);
 
 		double sigma = RealTier_getStandardDeviation_points (thee, my xmin, my xmax);
-		if (sigma == NUMundefined) {
+		if (isundef (sigma)) {
 			Melder_throw (U"Not enough data points in fit interval.");
 		}
 
@@ -1670,7 +1687,7 @@ static double NUMmspline2 (double points[], long numberOfPoints, long order, lon
 	Melder_assert (numberOfPoints > 2 && order > 0 && index > 0);
 
 	if (index > numberOfSplines) {
-		return NUMundefined;
+		return undefined;
 	}
 
 	/*
@@ -1782,8 +1799,8 @@ static void Spline_initKnotsFromString (Spline me, long degree, const char32 *in
 	if (degree > Spline_MAXIMUM_DEGREE) {
 		Melder_throw (U"Degree must be <= 20.");
 	}
-	long numberOfInteriorKnots;
-	autoNUMvector<double> numbers (NUMstring_to_numbers (interiorKnots, &numberOfInteriorKnots), 1);
+	integer numberOfInteriorKnots;
+	autoNUMvector <real> numbers (NUMstring_to_numbers (interiorKnots, & numberOfInteriorKnots), 1);
 	if (numberOfInteriorKnots > 0) {
 		NUMsort_d (numberOfInteriorKnots, numbers.peek());
 		if (numbers[1] <= my xmin || numbers[numberOfInteriorKnots] > my xmax) {
