@@ -38,7 +38,7 @@ oo_DEFINE_CLASS (FunctionTerms, Function)
 	#if oo_DECLARING
 		// new methods:
 			virtual double v_evaluate (double x);
-			virtual void v_evaluate_z (dcomplex *z, dcomplex *p);
+			virtual dcomplex v_evaluate_z (dcomplex z);
 			virtual void v_evaluateTerms (double x, double terms[]);
 			virtual void v_getExtrema (double x1, double x2, double *xmin, double *ymin, double *xmax, double *ymax);
 			virtual long v_getDegree ();
