@@ -56,7 +56,6 @@ trajectory --> path ????
 #include "FormantGrid.h"
 #include "KlattGrid.h"
 #include "../external/portaudio/portaudio.h"
-#include "praat.h"
 #include "PitchTier_to_PointProcess.h"
 #include "PitchTier_to_Sound.h"
 #include "PointProcess_and_Sound.h"
@@ -103,8 +102,8 @@ Thing_implement (VowelEditor, Editor, 0);
 // maximum number of marks
 #define VowelEditor_MAXIMUM_MARKERS 30
 
-static struct structVowelEditor_F0 f0default { 140.0, 0.0, 40.0, 2000.0, SAMPLING_FREQUENCY, 1, 0.0, 2000 };
-static struct structVowelEditor_F1F2Grid griddefault { 200.0, 500.0, 0, 1, 0, 1, 0.5 };
+static structVowelEditor_F0 f0default { 140.0, 0.0, 40.0, 2000.0, SAMPLING_FREQUENCY, 1, 0.0, 2000 };
+static structVowelEditor_F1F2Grid griddefault { 200.0, 500.0, 0, 1, 0, 1, 0.5 };
 
 #include "oo_DESTROY.h"
 #include "Vowel_def.h"
@@ -139,37 +138,33 @@ static struct {
 	double f1min, f1max, f2min, f2max;
 	double f3, b3, f4, b4;
 	double markTraceEvery, extendDuration;
-	int frequencyScale;
-	int axisOrientation;
 	int speakerType, marksDataset, numberOfMarks, marksFontSize;
-	char32 mark[VowelEditor_MAXIMUM_MARKERS][Preferences_STRING_BUFFER_SIZE];
+	char32 mark [VowelEditor_MAXIMUM_MARKERS] [Preferences_STRING_BUFFER_SIZE];
 } prefs;
 
 void VowelEditor_prefs () {
-	Preferences_addInt (U"VowelEditor.shellWidth", &prefs.shellWidth, 500);
-	Preferences_addInt (U"VowelEditor.shellHeight", &prefs.shellHeight, 500);
-	Preferences_addBool (U"VowelEditor.soundFollowsMouse", &prefs.soundFollowsMouse, true);
-	Preferences_addDouble (U"VowelEditor.f1min", &prefs.f1min, 200.0);
-	Preferences_addDouble (U"VowelEditor.f1max", &prefs.f1max, 1200.0);
-	Preferences_addDouble (U"VowelEditor.f2min", &prefs.f2min, 500.0);
-	Preferences_addDouble (U"VowelEditor.f2max", &prefs.f2max, 3500.0);
-	Preferences_addDouble (U"VowelEditor.f3", &prefs.f3, 2500.0);
-	Preferences_addDouble (U"VowelEditor.b3", &prefs.b3, 250.0);
-	Preferences_addDouble (U"VowelEditor.f4", &prefs.f4, 3500.0);
-	Preferences_addDouble (U"VowelEditor.b4", &prefs.b4, 350.0);
-	Preferences_addDouble (U"VowelEditor.markTraceEvery", &prefs.markTraceEvery, 0.05);
-	Preferences_addDouble (U"VowelEditor.extendDuration", &prefs.extendDuration, 0.05);
-	Preferences_addInt (U"VowelEditor.frequencyScale", &prefs.frequencyScale, 0);
-	Preferences_addInt (U"VowelEditor.axisOrientation", &prefs.axisOrientation, 0);
-	Preferences_addInt (U"VowelEditor.speakerType", &prefs.speakerType, 1);
-	Preferences_addInt (U"VowelEditor.marksDataset", &prefs.marksDataset, 2);
-	Preferences_addInt (U"VowelEditor.marksFontsize", &prefs.marksFontSize, 14);
-	Preferences_addInt (U"VowelEditor.numberOfMarks", &prefs.numberOfMarks, 12);   // 12 is the number of vowels in the default (Dutch) marksDataset
+	Preferences_addInt (U"VowelEditor.shellWidth", & prefs.shellWidth, 500);
+	Preferences_addInt (U"VowelEditor.shellHeight", & prefs.shellHeight, 500);
+	Preferences_addBool (U"VowelEditor.soundFollowsMouse", & prefs.soundFollowsMouse, true);
+	Preferences_addDouble (U"VowelEditor.f1min", & prefs.f1min, 200.0);
+	Preferences_addDouble (U"VowelEditor.f1max", & prefs.f1max, 1200.0);
+	Preferences_addDouble (U"VowelEditor.f2min", & prefs.f2min, 500.0);
+	Preferences_addDouble (U"VowelEditor.f2max", & prefs.f2max, 3500.0);
+	Preferences_addDouble (U"VowelEditor.f3", & prefs.f3, 2500.0);
+	Preferences_addDouble (U"VowelEditor.b3", & prefs.b3, 250.0);
+	Preferences_addDouble (U"VowelEditor.f4", & prefs.f4, 3500.0);
+	Preferences_addDouble (U"VowelEditor.b4", & prefs.b4, 350.0);
+	Preferences_addDouble (U"VowelEditor.markTraceEvery", & prefs.markTraceEvery, 0.05);
+	Preferences_addDouble (U"VowelEditor.extendDuration", & prefs.extendDuration, 0.05);
+	Preferences_addInt (U"VowelEditor.speakerType", & prefs.speakerType, 1);   // TODO: replace with enum
+	Preferences_addInt (U"VowelEditor.marksDataset", & prefs.marksDataset, 2);   // TODO: replace with enum
+	Preferences_addInt (U"VowelEditor.marksFontsize", & prefs.marksFontSize, 14);
+	Preferences_addInt (U"VowelEditor.numberOfMarks", & prefs.numberOfMarks, 12);   // 12 is the number of vowels in the default (Dutch) marksDataset
 	/*
 	 * We don't know how many markers there will be, so the prefs file needs to have the maximum number.
 	 */
 	for (long i = 1; i <= VowelEditor_MAXIMUM_MARKERS; i++) {
-		Preferences_addString (Melder_cat (U"VowelEditor.mark", (i < 10 ? U"0" : U""), i), & prefs.mark[i-1][0], U"x");
+		Preferences_addString (Melder_cat (U"VowelEditor.mark", (i < 10 ? U"0" : U""), i), & prefs.mark [i - 1] [0], U"x");
 	}
 }
 
@@ -194,18 +189,18 @@ static autoVowel Vowel_create_twoFormantSchwa (double duration) {
 		autoVowel me = Vowel_create (duration);
 		autoFormantPoint fp = FormantPoint_create (0.0);
 		fp -> formant [0] = 500.0;
-		fp -> bandwidth[0] = 50.0;
+		fp -> bandwidth [0] = 50.0;
 		fp -> formant [1] = 1500.0;
-		fp -> bandwidth[1] = 150.0;
+		fp -> bandwidth [1] = 150.0;
 		fp -> numberOfFormants = 2;
 		my ft -> points. addItem_move (fp.move());
 		RealTier_addPoint (my pt.get(), 0.0, 140.0);
 
 		fp = FormantPoint_create (duration);
 		fp -> formant [0] = 500.0;
-		fp -> bandwidth[0] = 50.0;
+		fp -> bandwidth [0] = 50.0;
 		fp -> formant [1] = 1500.0;
-		fp -> bandwidth[1] = 150.0;
+		fp -> bandwidth [1] = 150.0;
 		fp -> numberOfFormants = 2;
 		my ft -> points. addItem_move (fp.move());
 		RealTier_addPoint (my pt.get(), duration, 140.0);
@@ -233,9 +228,9 @@ static autoFormantGrid FormantTier_to_FormantGrid (FormantTier me) {
 		for (long ipoint = 1; ipoint <= my points.size; ipoint ++) {
 			FormantPoint fp = my points.at [ipoint];
 			double t = fp -> number;
-			for (long iformant = 1; iformant <= fp -> numberOfFormants; iformant++) {
-				FormantGrid_addFormantPoint (thee.get(), iformant, t, fp -> formant[iformant - 1]);
-				FormantGrid_addBandwidthPoint (thee.get(), iformant, t, fp -> bandwidth[iformant - 1]);
+			for (long iformant = 1; iformant <= fp -> numberOfFormants; iformant ++) {
+				FormantGrid_addFormantPoint (thee.get(), iformant, t, fp -> formant [iformant - 1]);
+				FormantGrid_addBandwidthPoint (thee.get(), iformant, t, fp -> bandwidth [iformant - 1]);
 			}
 		}
 		return thee;
@@ -255,18 +250,19 @@ static void VowelEditor_getF1F2FromXY (VowelEditor me, double x, double y, doubl
 	*f1 = my f1min * pow (my f1max / my f1min, 1.0 - y);
 }
 
-#define REPRESENTNUMBER(x,i) (((x) == NUMundefined) ? U" undef" : Melder_pad (6, Melder_fixed (x, 1)))
+#define REPRESENTNUMBER(x,i) (isundef (x) ? U" undef" : Melder_pad (6, Melder_fixed (x, 1)))
 static void appendF1F2F0 (MelderString *statusInfo, const char32 *intro, double f1, double f2, double f0, const char32 *ending) {
 	MelderString_append (statusInfo, intro, REPRESENTNUMBER (f1, 1), U", ", REPRESENTNUMBER (f2, 2), U", ", REPRESENTNUMBER (f0, 3), ending);
 }
 
 static double getRealFromTextWidget (GuiText me) {
-	double value = NUMundefined;
+	double value = undefined;
 	char32 *dirty = GuiText_getString (me);
 	try {
 		Interpreter_numericExpression (nullptr, dirty, & value);
 	} catch (MelderError) {
-		Melder_clearError (); value = NUMundefined;
+		Melder_clearError ();
+		value = undefined;
 	}
 	Melder_free (dirty);
 	return value;
@@ -288,7 +284,7 @@ static void checkF1F2 (VowelEditor me, double *f1, double *f2) {
 }
 
 static void checkF0 (structVowelEditor_F0 *f0p, double *f0) {
-	if (! NUMdefined (*f0)) {
+	if (isundef (*f0)) {
 		*f0 = f0p -> start;
 	}
 	if (*f0 > f0p -> maximum) {
@@ -325,11 +321,11 @@ static void VowelEditor_getF3F4 (VowelEditor me, double f1, double f2, double *f
 
 static void VowelEditor_updateF0Info (VowelEditor me) {
 	double f0 = getRealFromTextWidget (my f0TextField);
-	checkF0 (&my f0, &f0);
+	checkF0 (& my f0, & f0);
 	GuiText_setString (my f0TextField, Melder_double (f0));
 	my f0.start = f0;
 	double slopeOctPerSec = getRealFromTextWidget (my f0SlopeTextField);
-	if (! NUMdefined (slopeOctPerSec)) {
+	if (isundef (slopeOctPerSec)) {
 		slopeOctPerSec = f0default.slopeOctPerSec;
 	}
 	my f0.slopeOctPerSec = slopeOctPerSec;
@@ -338,7 +334,7 @@ static void VowelEditor_updateF0Info (VowelEditor me) {
 
 static void VowelEditor_updateExtendDuration (VowelEditor me) {
 	double extend = getRealFromTextWidget (my extendTextField);
-	if (! NUMdefined (extend) || extend <= MINIMUM_SOUND_DURATION || extend > my maximumDuration) {
+	if (isundef (extend) || extend <= MINIMUM_SOUND_DURATION || extend > my maximumDuration) {
 		extend = MINIMUM_SOUND_DURATION;
 	}
 	GuiText_setString (my extendTextField, Melder_double (extend));
@@ -347,20 +343,20 @@ static void VowelEditor_updateExtendDuration (VowelEditor me) {
 
 static double VowelEditor_updateDurationInfo (VowelEditor me) {
 	double duration = getRealFromTextWidget (my durationTextField);
-	if (! NUMdefined (duration) || duration < MINIMUM_SOUND_DURATION) {
+	if (isundef (duration) || duration < MINIMUM_SOUND_DURATION) {
 		duration = MINIMUM_SOUND_DURATION;
 	}
 	GuiText_setString (my durationTextField, Melder_double (MICROSECPRECISION (duration)));
 	return duration;
 }
 
-static void Sound_fadeIn (Sound me, double duration, int fromFirstNonZeroSample) {
+static void Sound_fadeIn (Sound me, double duration, bool fromFirstNonZeroSample) {
 	long istart = 1, numberOfSamples = (long) floor (duration / my dx);   // ppgb: waarom afronden naar beneden?
 
 	if (numberOfSamples < 2) {
 		return;
 	}
-	if (fromFirstNonZeroSample != 0) {
+	if (fromFirstNonZeroSample) {
 		// If the first part of the sound is very low level we put sample values to zero and
 		// start windowing from the position where the amplitude is above the minimum level.
 		// WARNING: this part is special for the artificial vowels because
@@ -438,7 +434,7 @@ static void VowelEditor_shiftF1F2 (VowelEditor me, double f1_st, double f2_st) {
 		FormantPoint fp = ft -> points.at [i];
 		double f1 = fp -> formant [0], f2 = fp -> formant [1];
 
-		f1 *= pow (2, f1_st / 12);
+		f1 *= pow (2, f1_st / 12.0);
 		if (f1 < my f1min) {
 			f1 = my f1min;
 		}
@@ -446,9 +442,9 @@ static void VowelEditor_shiftF1F2 (VowelEditor me, double f1_st, double f2_st) {
 			f1 = my f1max;
 		}
 		fp -> formant[0] = f1;
-		fp -> bandwidth[0] = f1 / 10;
+		fp -> bandwidth[0] = f1 / 10.0;
 
-		f2 *= pow (2, f2_st / 12);
+		f2 *= pow (2, f2_st / 12.0);
 		if (f2 < my f2min) {
 			f2 = my f2min;
 		}
@@ -456,7 +452,7 @@ static void VowelEditor_shiftF1F2 (VowelEditor me, double f1_st, double f2_st) {
 			f2 = my f2max;
 		}
 		fp -> formant[1] = f2;
-		fp -> bandwidth[1] = f2 / 10;
+		fp -> bandwidth[1] = f2 / 10.0;
 		double f3, b3, f4, b4;
 		VowelEditor_getF3F4 (me, f1, f2, &f3, &b3, &f4, &b4);
 		fp -> formant[2] = f3;
@@ -513,7 +509,7 @@ static autoSound VowelEditor_createTarget (VowelEditor me) {
 		VowelEditor_updateVowel (me);   // update pitch and duration
 		autoSound thee = Vowel_to_Sound_pulses (my vowel.get(), 44100.0, 0.7, 0.05, 30);
 		Vector_scale (thee.get(), 0.99);
-		Sound_fadeIn (thee.get(), 0.005, 1);
+		Sound_fadeIn (thee.get(), 0.005, true);
 		Sound_fadeOut (thee.get(), 0.005);
 		return thee;
 	} catch (MelderError) {
@@ -624,7 +620,7 @@ static void copyVowelMarksInPreferences_volatile (Table me) {
 		long col_f2 = Table_getColumnIndexFromColumnLabel (me, U"F2");
 		long col_size = Table_getColumnIndexFromColumnLabel (me, U"Size");
 		autoMelderString mark;
-		for (long i = 1; i <= VowelEditor_MAXIMUM_MARKERS; i++) {
+		for (long i = 1; i <= VowelEditor_MAXIMUM_MARKERS; i ++) {
 			if (i <= numberOfRows) {
 				MelderString_copy (&mark, Table_getStringValue_Assert (me, i, col_vowel), U"\t",
 					Table_getStringValue_Assert (me, i, col_f1), U"\t",
@@ -634,9 +630,9 @@ static void copyVowelMarksInPreferences_volatile (Table me) {
 				if (length >= Preferences_STRING_BUFFER_SIZE) {
 					Melder_throw (U"Preference mark ", i, U" contains too many characters");
 				}
-				str32cpy (prefs.mark[i-1], mark.string);
+				str32cpy (prefs.mark [i - 1], mark.string);
 			} else {
-				str32cpy (prefs.mark[i-1], U"x");
+				str32cpy (prefs.mark [i - 1], U"x");
 			}
 		}
 	}
@@ -658,14 +654,14 @@ static void VowelEditor_setMarks (VowelEditor me, int marksDataset, int speakerT
 	const char32 *Sex[3] = { U"", U"m", U"f"};
 	if (marksDataset == 1) {   // American-English
 		autoTable thee = Table_create_petersonBarney1952 ();
-		te = Table_extractRowsWhereColumn_string (thee.get(), 1, kMelder_string_EQUAL_TO, Type[speakerType]);
+		te = Table_extractRowsWhereColumn_string (thee.get(), 1, kMelder_string::EQUAL_TO, Type[speakerType]);
 	} else if (marksDataset == 2) {   // Dutch
 		if (speakerType == 1 || speakerType == 2) {   // male + female from Pols van Nierop
 			autoTable thee = Table_create_polsVanNierop1973 ();
-			te = Table_extractRowsWhereColumn_string (thee.get(), 1, kMelder_string_EQUAL_TO, Sex[speakerType]);
+			te = Table_extractRowsWhereColumn_string (thee.get(), 1, kMelder_string::EQUAL_TO, Sex[speakerType]);
 		} else {
 			autoTable thee = Table_create_weenink1983 ();
-			te = Table_extractRowsWhereColumn_string (thee.get(), 1, kMelder_string_EQUAL_TO, Type[speakerType]);
+			te = Table_extractRowsWhereColumn_string (thee.get(), 1, kMelder_string::EQUAL_TO, Type[speakerType]);
 		}
 	} else if (marksDataset == 3) {   // none
 		my marks.reset();
@@ -687,15 +683,15 @@ static void VowelEditor_createTableFromVowelMarksInPreferences (VowelEditor me)
 	try {
 		autoTable newMarks = Table_createWithColumnNames (0, U"Vowel F1 F2 Size");
 		long nmarksFound = 0;
-		for (long i = 1; i <= numberOfRows; i++) {
-			autoMelderTokens rowi (prefs.mark[i-1]);
+		for (long i = 1; i <= numberOfRows; i ++) {
+			autoMelderTokens rowi (prefs.mark [i - 1]);
 			long numberOfTokens = rowi.count();
 			if (numberOfTokens < 4) { // we are done
 				break;
 			}
 			Table_appendRow (newMarks.get());
-			for (long j = 1; j <= 4; j++) {
-				Table_setStringValue (newMarks.get(), i, j, rowi[j]);
+			for (long j = 1; j <= 4; j ++) {
+				Table_setStringValue (newMarks.get(), i, j, rowi [j]);
 			}
 			nmarksFound++;
 		}
@@ -800,9 +796,9 @@ static void VowelEditor_drawBackground (VowelEditor me, Graphics g) {
 		VowelEditor_getXYFromF1F2 (me, my f1max, my f1max, &x2, &y2);
 		if (x2 >= 0.0 && x2 <= 1.0) {
 			autoPolygon p = Polygon_create (3);
-			p -> x[1] = x1; p -> y[1] = y1;
-			p -> x[2] = x2; p -> y[2] = y2;
-			p -> x[3] =  1; p -> y[3] =  0;
+			p -> x [1] = x1;    p -> y [1] = y1;
+			p -> x [2] = x2;    p -> y [2] = y2;
+			p -> x [3] = 1.0;   p -> y [3] = 0.0;
 			Graphics_fillArea (g, p -> numberOfPoints, & p -> x[1], & p -> y[1]);
 			// Polygon_paint does not work because of use of Graphics_setInner.
 			Graphics_line (g, x1, y1, x2, y2);
@@ -880,14 +876,12 @@ static void menu_cb_help (VowelEditor /* me */, EDITOR_ARGS_DIRECT) {
 }
 
 static void menu_cb_prefs (VowelEditor me, EDITOR_ARGS_FORM) {
-	EDITOR_FORM (U"Preferences", 0);
-		BOOLEAN (U"Sound-follows-mouse", true)
+	EDITOR_FORM (U"Preferences", nullptr);
+		BOOLEAN (U"Sound follows mouse", true)
 	EDITOR_OK
-		SET_INTEGER (U"Sound-follows-mouse", prefs.soundFollowsMouse)
+		SET_INTEGER (U"Sound follows mouse", prefs.soundFollowsMouse)
 	EDITOR_DO
-		my frequencyScale = prefs.frequencyScale;
-		my axisOrientation = prefs.axisOrientation;
-		my soundFollowsMouse = prefs.soundFollowsMouse = GET_INTEGER (U"Sound-follows-mouse");
+		my soundFollowsMouse = prefs.soundFollowsMouse = GET_INTEGER (U"Sound follows mouse");
 		Graphics_updateWs (my graphics.get());
 	EDITOR_END
 }
@@ -904,8 +898,6 @@ static void menu_cb_ranges_f1f2 (VowelEditor me, EDITOR_ARGS_FORM) {
 		SET_REAL (U"left F2 range", prefs.f2min)
 		SET_REAL (U"right F2 range", prefs.f2max)
 	EDITOR_DO
-		my frequencyScale = prefs.frequencyScale;
-		my axisOrientation = prefs.axisOrientation;
 		my f1min = prefs.f1min = GET_REAL (U"left F1 range");
 		my f1max = prefs.f1max = GET_REAL (U"right F1 range");
 		my f2min = prefs.f2min = GET_REAL (U"left F2 range");
@@ -1176,7 +1168,7 @@ static void gui_button_cb_publish (VowelEditor me, GuiButtonEvent /* event */) {
 
 static void gui_button_cb_reverse (VowelEditor me, GuiButtonEvent /* event */) {
 	VowelEditor_Vowel_reverseFormantTier (me);
-	struct structGuiButtonEvent play_event { 0 };
+	structGuiButtonEvent play_event { };
 	gui_button_cb_play (me, & play_event);
 }
 
@@ -1186,7 +1178,7 @@ static void gui_drawingarea_cb_expose (VowelEditor me, GuiDrawingArea_ExposeEven
 	double ts = my vowel -> xmin, te = my vowel -> xmax;
 	FormantTier ft = my vowel -> ft.get();
 	Melder_assert (ft);
-	static MelderString statusInfo { 0 };
+	static MelderString statusInfo { };
 	if (! my graphics) {
 		return;   // could be the case in the very beginning
 	}
@@ -1307,7 +1299,7 @@ static void gui_drawingarea_cb_click (VowelEditor me, GuiDrawingArea_ClickEvent
 		checkXY (&x, &y);
 		// If the new point equals the previous one: no tier update
 		if (xb == x && yb == y) {
-			iskipped++;
+			iskipped ++;
 			continue;
 		}
 		// Add previous point only if at least one previous event was skipped...
@@ -1346,15 +1338,6 @@ static void gui_drawingarea_cb_key (VowelEditor /* me */, GuiDrawingArea_KeyEven
 }
 #endif
 
-static void cb_publish (Editor /*editor*/, autoDaata publish) {
-	try {
-		praat_new (publish.move(), U"");
-		praat_updateSelection ();
-	} catch (MelderError) {
-		Melder_flushError ();
-	}
-}
-
 static void updateWidgets (void *void_me) {
 	iam (VowelEditor);
 	(void) me;
@@ -1469,14 +1452,11 @@ autoVowelEditor VowelEditor_create (const char32 *title, Daata data) {
 		my graphics = Graphics_create_xmdrawingarea (my drawingArea);
 		Melder_assert (my graphics);
 		Graphics_setFontSize (my graphics.get(), 12);
-		Editor_setPublicationCallback (me.get(), cb_publish);
 
 		my f1min = prefs.f1min;
 		my f1max = prefs.f1max;
 		my f2min = prefs.f2min;
 		my f2max = prefs.f2max;
-		my frequencyScale = prefs.frequencyScale;
-		my axisOrientation = prefs.axisOrientation;
 		my speakerType = prefs.speakerType;
 		my marksDataset = prefs.marksDataset;
 		my marksFontSize = prefs.marksFontSize;
