@@ -1,6 +1,6 @@
 /* Ltas.cpp
  *
- * Copyright (C) 1992-2012,2015,2016 Paul Boersma
+ * Copyright (C) 1992-2012,2015,2016,2017 Paul Boersma
  *
  * This code is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -86,7 +86,7 @@ void Ltas_draw (Ltas me, Graphics g, double fmin, double fmax, double minimum, d
 double Ltas_getSlope (Ltas me, double f1min, double f1max, double f2min, double f2max, int averagingUnits) {
 	double low = Sampled_getMean (me, f1min, f1max, 0, averagingUnits, false);
 	double high = Sampled_getMean (me, f2min, f2max, 0, averagingUnits, false);
-	if (low == NUMundefined || high == NUMundefined) return NUMundefined;
+	if (isundef (low) || isundef (high)) return undefined;
 	return averagingUnits == 3 ? high - low : Function_convertSpecialToStandardUnit (me, high / low, 0, averagingUnits);
 }
 
@@ -94,7 +94,7 @@ double Ltas_getLocalPeakHeight (Ltas me, double environmentMin, double environme
 	double environmentLow = Sampled_getMean (me, environmentMin, peakMin, 0, averagingUnits, false);
 	double environmentHigh = Sampled_getMean (me, peakMax, environmentMax, 0, averagingUnits, false);
 	double peak = Sampled_getMean (me, peakMin, peakMax, 0, averagingUnits, false);
-	if (environmentLow == NUMundefined || environmentHigh == NUMundefined || peak == NUMundefined) return NUMundefined;
+	if (isundef (environmentLow) || isundef (environmentHigh) || isundef (peak)) return undefined;
 	return averagingUnits == 3 ? peak - 0.5 * (environmentLow + environmentHigh) :
 		Function_convertSpecialToStandardUnit (me, peak / (0.5 * (environmentLow + environmentHigh)), 0, averagingUnits);
 }
@@ -178,32 +178,32 @@ autoLtas Ltas_computeTrendLine (Ltas me, double fmin, double fmax) {
 		/*
 		 * Find the first and last bin.
 		 */
-		long imin, imax, n;
+		integer imin, imax, n;
 		if ((n = Sampled_getWindowSamples (me, fmin, fmax, & imin, & imax)) < 2)
 			Melder_throw (U"Number of bins too low (", n, U"). Should be at least 2.");
 		autoLtas thee = Data_copy (me);
 		/*
 		 * Compute average amplitude and frequency.
 		 */
-		double sum = 0.0, amean, fmean, numerator = 0.0, denominator = 0.0, slope;
-		for (long i = imin; i <= imax; i ++) {
+		real80 sum = 0.0, numerator = 0.0, denominator = 0.0;
+		for (integer i = imin; i <= imax; i ++) {
 			sum += thy z [1] [i];
 		}
-		amean = sum / n;
-		fmean = thy x1 + (0.5 * (imin + imax) - 1) * thy dx;
+		real amean = real (sum / n);
+		real fmean = thy x1 + (0.5 * (imin + imax) - 1) * thy dx;
 		/*
 		 * Compute slope.
 		 */
-		for (long i = imin; i <= imax; i ++) {
+		for (integer i = imin; i <= imax; i ++) {
 			double da = thy z [1] [i] - amean, df = thy x1 + (i - 1) * thy dx - fmean;
 			numerator += da * df;
 			denominator += df * df;
 		}
-		slope = numerator / denominator;
+		real slope = real (numerator / denominator);
 		/*
 		 * Modify bins.
 		 */
-		for (long i = 1; i <= thy nx; i ++) {
+		for (integer i = 1; i <= thy nx; i ++) {
 			double df = thy x1 + (i - 1) * thy dx - fmean;
 			thy z [1] [i] = amean + slope * df;
 		}
@@ -218,7 +218,7 @@ autoLtas Ltas_subtractTrendLine (Ltas me, double fmin, double fmax) {
 		/*
 		 * Find the first and last bin.
 		 */
-		long imin, imax, n;
+		integer imin, imax, n;
 		if ((n = Sampled_getWindowSamples (me, fmin, fmax, & imin, & imax)) < 2)
 			Melder_throw (U"Number of bins too low (", n, U"). Should be at least 2.");
 		autoLtas thee = Data_copy (me);
@@ -261,7 +261,7 @@ autoLtas Ltas_subtractTrendLine (Ltas me, double fmin, double fmax) {
 
 autoLtas Spectrum_to_Ltas (Spectrum me, double bandWidth) {
 	try {
-		long numberOfBands = ceil ((my xmax - my xmin) / bandWidth);
+		integer numberOfBands = (integer) ceil ((my xmax - my xmin) / bandWidth);
 		if (bandWidth <= my dx)
 			Melder_throw (U"Bandwidth must be greater than ", my dx, U".");
 		autoLtas thee = Thing_new (Ltas);
@@ -311,7 +311,7 @@ autoLtas PointProcess_Sound_to_Ltas (PointProcess pulses, Sound sound,
 {
 	try {
 		long numberOfPeriods = pulses -> nt - 2, totalNumberOfEnergies = 0;
-		autoLtas ltas = Ltas_create (maximumFrequency / bandWidth, bandWidth);
+		autoLtas ltas = Ltas_create ((integer) floor (maximumFrequency / bandWidth), bandWidth);
 		ltas -> xmax = maximumFrequency;
 		autoLtas numbers = Data_copy (ltas.get());
 		if (numberOfPeriods < 1)
@@ -331,14 +331,14 @@ autoLtas PointProcess_Sound_to_Ltas (PointProcess pulses, Sound sound,
 				 */
 				autoSound period = Sound_extractPart (sound,
 					pulses -> t [ipulse] - 0.5 * leftInterval, pulses -> t [ipulse] + 0.5 * rightInterval,
-					kSound_windowShape_RECTANGULAR, 1.0, false);
+					kSound_windowShape::RECTANGULAR, 1.0, false);
 				autoSpectrum spectrum = Sound_to_Spectrum (period.get(), false);
 				for (long ifreq = 1; ifreq <= spectrum -> nx; ifreq ++) {
 					double frequency = spectrum -> xmin + (ifreq - 1) * spectrum -> dx;
 					double realPart = spectrum -> z [1] [ifreq];
 					double imaginaryPart = spectrum -> z [2] [ifreq];
 					double energy = (realPart * realPart + imaginaryPart * imaginaryPart) * 2.0 * spectrum -> dx /* OLD: * sound -> nx */;
-					long iband = ceil (frequency / bandWidth);
+					integer iband = (integer) ceil (frequency / bandWidth);
 					if (iband >= 1 && iband <= ltas -> nx) {
 						ltas -> z [1] [iband] += energy;
 						numbers -> z [1] [iband] += 1;
@@ -351,16 +351,16 @@ autoLtas PointProcess_Sound_to_Ltas (PointProcess pulses, Sound sound,
 		}
 		if (numberOfPeriods < 1)
 			Melder_throw (U"There are no periods in the point process.");
-		for (long iband = 1; iband <= ltas -> nx; iband ++) {
+		for (integer iband = 1; iband <= ltas -> nx; iband ++) {
 			if (numbers -> z [1] [iband] == 0.0) {
-				ltas -> z [1] [iband] = NUMundefined;
+				ltas -> z [1] [iband] = undefined;
 			} else {
 				/*
 				 * Each bin now contains a total energy in Pa2 sec.
 				 * To convert this to power density, we
 				 */
 				double totalEnergyInThisBand = ltas -> z [1] [iband];
-				if (0 /* i.e. if you just want to have a spectrum of the voiced parts... */) {
+				if (false /* i.e. if you just want to have a spectrum of the voiced parts... */) {
 					double energyDensityInThisBand = totalEnergyInThisBand / ltas -> dx;
 					double powerDensityInThisBand = energyDensityInThisBand / (sound -> xmax - sound -> xmin);
 					ltas -> z [1] [iband] = 10.0 * log10 (powerDensityInThisBand / 4.0e-10);
@@ -379,10 +379,10 @@ autoLtas PointProcess_Sound_to_Ltas (PointProcess pulses, Sound sound,
 			}
 		}
 		for (long iband = 1; iband <= ltas -> nx; iband ++) {
-			if (ltas -> z [1] [iband] == NUMundefined) {
+			if (isundef (ltas -> z [1] [iband])) {
 				long ibandleft = iband - 1, ibandright = iband + 1;
-				while (ibandleft >= 1 && ltas -> z [1] [ibandleft] == NUMundefined) ibandleft --;
-				while (ibandright <= ltas -> nx && ltas -> z [1] [ibandright] == NUMundefined) ibandright ++;
+				while (ibandleft >= 1 && isundef (ltas -> z [1] [ibandleft])) ibandleft --;
+				while (ibandright <= ltas -> nx && isundef (ltas -> z [1] [ibandright])) ibandright ++;
 				if (ibandleft < 1 && ibandright > ltas -> nx)
 					Melder_throw (U"Cannot create an Ltas without energy in any bins.");
 				if (ibandleft < 1) {
@@ -444,7 +444,7 @@ autoLtas PointProcess_Sound_to_Ltas_harmonics (PointProcess pulses, Sound sound,
 				long localMaximumHarmonic;
 				autoSound period = Sound_extractPart (sound,
 					pulses -> t [ipulse] - 0.5 * leftInterval, pulses -> t [ipulse] + 0.5 * rightInterval,
-					kSound_windowShape_RECTANGULAR, 1.0, false);
+					kSound_windowShape::RECTANGULAR, 1.0, false);
 				autoSpectrum spectrum = Sound_to_Spectrum (period.get(), false);
 				localMaximumHarmonic = maximumHarmonic < spectrum -> nx ? maximumHarmonic : spectrum -> nx;
 				for (long iharm = 1; iharm <= localMaximumHarmonic; iharm ++) {
