@@ -1,6 +1,6 @@
 /* Pitch.cpp
  *
- * Copyright (C) 1992-2011,2014,2015,2016 Paul Boersma
+ * Copyright (C) 1992-2011,2014,2015,2016,2017 Paul Boersma
  *
  * This code is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -49,35 +49,35 @@ Thing_implement (Pitch, Sampled, 1);
 
 #define FREQUENCY(frame)  ((frame) -> candidate [1]. frequency)
 #define STRENGTH(frame)  ((frame) -> candidate [1]. strength)
-#define NOT_VOICED(f)  ((f) <= 0.0 || (f) >= my ceiling)   /* This includes NUMundefined! */
+#define NOT_VOICED(f)  (! ((f) > 0.0 && (f) < my ceiling))   /* a NaN-resistant formulation */
 
 int structPitch :: v_getMinimumUnit (long ilevel) {
-	return ilevel == Pitch_LEVEL_FREQUENCY ? kPitch_unit_MIN : Pitch_STRENGTH_UNIT_min;
+	return ilevel == Pitch_LEVEL_FREQUENCY ? (int) kPitch_unit::MIN : Pitch_STRENGTH_UNIT_min;
 }
 
 int structPitch :: v_getMaximumUnit (long ilevel) {
-	return ilevel == Pitch_LEVEL_FREQUENCY ? kPitch_unit_MAX : Pitch_STRENGTH_UNIT_max;
+	return ilevel == Pitch_LEVEL_FREQUENCY ? (int) kPitch_unit::MAX : Pitch_STRENGTH_UNIT_max;
 }
 
 const char32 * structPitch :: v_getUnitText (long ilevel, int unit, unsigned long flags) {
 	if (ilevel == Pitch_LEVEL_FREQUENCY) {
 		return
-			unit == kPitch_unit_HERTZ ?
+			unit == (int) kPitch_unit::HERTZ ?
 				flags & Function_UNIT_TEXT_MENU ? U"Hertz" : U"Hz" :
-			unit == kPitch_unit_HERTZ_LOGARITHMIC ?
+			unit == (int) kPitch_unit::HERTZ_LOGARITHMIC ?
 				flags & Function_UNIT_TEXT_MENU ? U"Hertz (logarithmic)" : (flags & Function_UNIT_TEXT_SHORT) && (flags & Function_UNIT_TEXT_GRAPHICAL) ? U"%%Hz%" : U"Hz" :
-			unit == kPitch_unit_MEL ? U"mel" :
-			unit == kPitch_unit_LOG_HERTZ ?
+			unit == (int) kPitch_unit::MEL ? U"mel" :
+			unit == (int) kPitch_unit::LOG_HERTZ ?
 				flags & Function_UNIT_TEXT_MENU ? U"logHertz" : U"logHz" :
-			unit == kPitch_unit_SEMITONES_1 ?
+			unit == (int) kPitch_unit::SEMITONES_1 ?
 				flags & Function_UNIT_TEXT_SHORT ? U"st__1_" : flags & Function_UNIT_TEXT_GRAPHICAL ? U"semitones %%re% 1 Hz" : U"semitones re 1 Hz" :
-			unit == kPitch_unit_SEMITONES_100 ?
+			unit == (int) kPitch_unit::SEMITONES_100 ?
 				flags & Function_UNIT_TEXT_SHORT ? U"st__100_" : flags & Function_UNIT_TEXT_GRAPHICAL ? U"semitones %%re% 100 Hz" : U"semitones re 100 Hz" :
-			unit == kPitch_unit_SEMITONES_200 ?
+			unit == (int) kPitch_unit::SEMITONES_200 ?
 				flags & Function_UNIT_TEXT_SHORT ? U"st__200_" : flags & Function_UNIT_TEXT_GRAPHICAL ? U"semitones %%re% 200 Hz" : U"semitones re 200 Hz" :
-			unit == kPitch_unit_SEMITONES_440 ?
+			unit == (int) kPitch_unit::SEMITONES_440 ?
 				flags & Function_UNIT_TEXT_SHORT ? U"st__a_" : flags & Function_UNIT_TEXT_GRAPHICAL ? U"semitones %%re% 440 Hz" : U"semitones re 440 Hz" :
-			unit == kPitch_unit_ERB ?
+			unit == (int) kPitch_unit::ERB ?
 				flags & Function_UNIT_TEXT_SHORT ? U"erb" : U"ERB" :
 			U"";
 	} else if (ilevel == Pitch_LEVEL_STRENGTH) {
@@ -91,22 +91,22 @@ const char32 * structPitch :: v_getUnitText (long ilevel, int unit, unsigned lon
 }
 
 bool structPitch :: v_isUnitLogarithmic (long ilevel, int unit) {
-	return ilevel == Pitch_LEVEL_FREQUENCY && unit == kPitch_unit_HERTZ_LOGARITHMIC;
+	return ilevel == Pitch_LEVEL_FREQUENCY && unit == (int) kPitch_unit::HERTZ_LOGARITHMIC;
 }
 
 double structPitch :: v_convertStandardToSpecialUnit (double value, long ilevel, int unit) {
 	if (ilevel == Pitch_LEVEL_FREQUENCY) {
 		return
-			unit == kPitch_unit_HERTZ ? value :
-			unit == kPitch_unit_HERTZ_LOGARITHMIC ? value <= 0.0 ? NUMundefined : log10 (value) :
-			unit == kPitch_unit_MEL ? NUMhertzToMel (value) :
-			unit == kPitch_unit_LOG_HERTZ ? value <= 0.0 ? NUMundefined : log10 (value) :
-			unit == kPitch_unit_SEMITONES_1 ? value <= 0.0 ? NUMundefined : 12.0 * log (value / 1.0) / NUMln2 :
-			unit == kPitch_unit_SEMITONES_100 ? value <= 0.0 ? NUMundefined : 12.0 * log (value / 100.0) / NUMln2 :
-			unit == kPitch_unit_SEMITONES_200 ? value <= 0.0 ? NUMundefined : 12.0 * log (value / 200.0) / NUMln2 :
-			unit == kPitch_unit_SEMITONES_440 ? value <= 0.0 ? NUMundefined : 12.0 * log (value / 440.0) / NUMln2 :
-			unit == kPitch_unit_ERB ? NUMhertzToErb (value) :
-			NUMundefined;
+			unit == (int) kPitch_unit::HERTZ ? value :
+			unit == (int) kPitch_unit::HERTZ_LOGARITHMIC ? value <= 0.0 ? undefined : log10 (value) :
+			unit == (int) kPitch_unit::MEL ? NUMhertzToMel (value) :
+			unit == (int) kPitch_unit::LOG_HERTZ ? value <= 0.0 ? undefined : log10 (value) :
+			unit == (int) kPitch_unit::SEMITONES_1 ? value <= 0.0 ? undefined : 12.0 * log (value / 1.0) / NUMln2 :
+			unit == (int) kPitch_unit::SEMITONES_100 ? value <= 0.0 ? undefined : 12.0 * log (value / 100.0) / NUMln2 :
+			unit == (int) kPitch_unit::SEMITONES_200 ? value <= 0.0 ? undefined : 12.0 * log (value / 200.0) / NUMln2 :
+			unit == (int) kPitch_unit::SEMITONES_440 ? value <= 0.0 ? undefined : 12.0 * log (value / 440.0) / NUMln2 :
+			unit == (int) kPitch_unit::ERB ? NUMhertzToErb (value) :
+			undefined;
 	} else {
 		return
 			unit == Pitch_STRENGTH_UNIT_AUTOCORRELATION ? value :
@@ -114,122 +114,122 @@ double structPitch :: v_convertStandardToSpecialUnit (double value, long ilevel,
 				value <= 1e-15 ? 1e15 : value > 1.0 - 1e-15 ? 1e-15 : (1.0 - value) / value :   /* Before losing precision. */
 			unit == Pitch_STRENGTH_UNIT_HARMONICS_NOISE_DB ?
 				value <= 1e-15 ? -150.0 : value > 1.0 - 1e-15 ? 150.0 : 10 * log10 (value / (1.0 - value)) :   /* Before losing precision. */
-			NUMundefined;
+			undefined;
 	}
 }
 
 double structPitch :: v_convertSpecialToStandardUnit (double value, long ilevel, int unit) {
 	if (ilevel == Pitch_LEVEL_FREQUENCY) {
 		return
-			unit == kPitch_unit_HERTZ ? value :
-			unit == kPitch_unit_HERTZ_LOGARITHMIC ? pow (10.0, value) :
-			unit == kPitch_unit_MEL ? NUMmelToHertz (value) :
-			unit == kPitch_unit_LOG_HERTZ ? pow (10.0, value) :
-			unit == kPitch_unit_SEMITONES_1 ? 1.0 * exp (value * (NUMln2 / 12.0)):
-			unit == kPitch_unit_SEMITONES_100 ? 100.0 * exp (value * (NUMln2 / 12.0)):
-			unit == kPitch_unit_SEMITONES_200 ? 200.0 * exp (value * (NUMln2 / 12.0)):
-			unit == kPitch_unit_SEMITONES_440 ? 440.0 * exp (value * (NUMln2 / 12.0)):
-			unit == kPitch_unit_ERB ? NUMerbToHertz (value) :
-			NUMundefined;
+			unit == (int) kPitch_unit::HERTZ ? value :
+			unit == (int) kPitch_unit::HERTZ_LOGARITHMIC ? pow (10.0, value) :
+			unit == (int) kPitch_unit::MEL ? NUMmelToHertz (value) :
+			unit == (int) kPitch_unit::LOG_HERTZ ? pow (10.0, value) :
+			unit == (int) kPitch_unit::SEMITONES_1 ? 1.0 * exp (value * (NUMln2 / 12.0)):
+			unit == (int) kPitch_unit::SEMITONES_100 ? 100.0 * exp (value * (NUMln2 / 12.0)):
+			unit == (int) kPitch_unit::SEMITONES_200 ? 200.0 * exp (value * (NUMln2 / 12.0)):
+			unit == (int) kPitch_unit::SEMITONES_440 ? 440.0 * exp (value * (NUMln2 / 12.0)):
+			unit == (int) kPitch_unit::ERB ? NUMerbToHertz (value) :
+			undefined;
 	} else {
-		return NUMundefined;
+		return undefined;
 	}
 }
 
 #define doesUnitAllowNegativeValues(unit)  \
-	( (unit) == kPitch_unit_HERTZ_LOGARITHMIC || (unit) == kPitch_unit_LOG_HERTZ ||  \
-	  (unit) == kPitch_unit_SEMITONES_1 || (unit) == kPitch_unit_SEMITONES_100 ||  \
-	  (unit) == kPitch_unit_SEMITONES_200 || (unit) == kPitch_unit_SEMITONES_440 )
+	( (unit) == kPitch_unit::HERTZ_LOGARITHMIC || (unit) == kPitch_unit::LOG_HERTZ ||  \
+	  (unit) == kPitch_unit::SEMITONES_1 || (unit) == kPitch_unit::SEMITONES_100 ||  \
+	  (unit) == kPitch_unit::SEMITONES_200 || (unit) == kPitch_unit::SEMITONES_440 )
 
 double structPitch :: v_getValueAtSample (long iframe, long ilevel, int unit) {
 	double f = frame [iframe]. candidate [1]. frequency;
-	if (f <= 0.0 || f >= ceiling) return NUMundefined;   // frequency out of range (or NUMundefined)? Voiceless
+	if (! (f > 0.0 && f < ceiling)) return undefined;   // frequency out of range (or undefined)? Voiceless
 	return v_convertStandardToSpecialUnit (ilevel == Pitch_LEVEL_FREQUENCY ? f : frame [iframe]. candidate [1]. strength, ilevel, unit);
 }
 
 bool Pitch_isVoiced_i (Pitch me, long iframe) {
-	return NUMdefined (Sampled_getValueAtSample (me, iframe, Pitch_LEVEL_FREQUENCY, kPitch_unit_HERTZ));
+	return isdefined (Sampled_getValueAtSample (me, iframe, Pitch_LEVEL_FREQUENCY, (int) kPitch_unit::HERTZ));
 }
 
 bool Pitch_isVoiced_t (Pitch me, double time) {
-	return NUMdefined (Sampled_getValueAtX (me, time, Pitch_LEVEL_FREQUENCY, kPitch_unit_HERTZ, false));
+	return isdefined (Sampled_getValueAtX (me, time, Pitch_LEVEL_FREQUENCY, (int) kPitch_unit::HERTZ, false));
 }
 
-double Pitch_getValueAtTime (Pitch me, double time, int unit, bool interpolate) {
-	return Sampled_getValueAtX (me, time, Pitch_LEVEL_FREQUENCY, unit, interpolate);
+double Pitch_getValueAtTime (Pitch me, double time, kPitch_unit unit, bool interpolate) {
+	return Sampled_getValueAtX (me, time, Pitch_LEVEL_FREQUENCY, (int) unit, interpolate);
 }
 
-double Pitch_getStrengthAtTime (Pitch me, double time, int unit, bool interpolate) {
-	return Sampled_getValueAtX (me, time, Pitch_LEVEL_STRENGTH, unit, interpolate);
+double Pitch_getStrengthAtTime (Pitch me, double time, kPitch_unit unit, bool interpolate) {
+	return Sampled_getValueAtX (me, time, Pitch_LEVEL_STRENGTH, (int) unit, interpolate);
 }
 
 long Pitch_countVoicedFrames (Pitch me) {
-	return Sampled_countDefinedSamples (me, Pitch_LEVEL_FREQUENCY, kPitch_unit_HERTZ);
+	return Sampled_countDefinedSamples (me, Pitch_LEVEL_FREQUENCY, (int) kPitch_unit::HERTZ);
 }
 
-double Pitch_getMean (Pitch me, double tmin, double tmax, int unit) {
-	return Sampled_getMean (me, tmin, tmax, Pitch_LEVEL_FREQUENCY, unit, true);
+double Pitch_getMean (Pitch me, double tmin, double tmax, kPitch_unit unit) {
+	return Sampled_getMean (me, tmin, tmax, Pitch_LEVEL_FREQUENCY, (int) unit, true);
 }
 
-double Pitch_getMeanStrength (Pitch me, double tmin, double tmax, int unit) {
-	return Sampled_getMean (me, tmin, tmax, Pitch_LEVEL_STRENGTH, unit, true);
+double Pitch_getMeanStrength (Pitch me, double tmin, double tmax, int strengthUnit) {
+	return Sampled_getMean (me, tmin, tmax, Pitch_LEVEL_STRENGTH, strengthUnit, true);
 }
 
-double Pitch_getQuantile (Pitch me, double tmin, double tmax, double quantile, int unit) {
-	double value = Sampled_getQuantile (me, tmin, tmax, quantile, Pitch_LEVEL_FREQUENCY, unit);
+double Pitch_getQuantile (Pitch me, double tmin, double tmax, double quantile, kPitch_unit unit) {
+	double value = Sampled_getQuantile (me, tmin, tmax, quantile, Pitch_LEVEL_FREQUENCY, (int) unit);
 	if (value <= 0.0 && ! doesUnitAllowNegativeValues (unit)) {
-		value = NUMundefined;
+		value = undefined;
 	}
 	return value;
 }
 
-double Pitch_getStandardDeviation (Pitch me, double tmin, double tmax, int unit) {
-	return Sampled_getStandardDeviation (me, tmin, tmax, Pitch_LEVEL_FREQUENCY, unit, true);
+double Pitch_getStandardDeviation (Pitch me, double tmin, double tmax, kPitch_unit unit) {
+	return Sampled_getStandardDeviation (me, tmin, tmax, Pitch_LEVEL_FREQUENCY, (int) unit, true);
 }
 
 #define MEL(f)  NUMhertzToMel (f)
 #define SEMITONES(f)  NUMhertzToSemitones (f)
 #define ERB(f)  NUMhertzToErb (f)
 
-void Pitch_getMaximumAndTime (Pitch me, double tmin, double tmax, int unit, bool interpolate,
+void Pitch_getMaximumAndTime (Pitch me, double tmin, double tmax, kPitch_unit unit, bool interpolate,
 	double *return_maximum, double *return_timeOfMaximum)
 {
-	Sampled_getMaximumAndX (me, tmin, tmax, Pitch_LEVEL_FREQUENCY, unit, interpolate, return_maximum, return_timeOfMaximum);
+	Sampled_getMaximumAndX (me, tmin, tmax, Pitch_LEVEL_FREQUENCY, (int) unit, interpolate, return_maximum, return_timeOfMaximum);
 	if (! doesUnitAllowNegativeValues (unit) && return_maximum && *return_maximum <= 0.0)
 	{
-		*return_maximum = NUMundefined;   // unlikely
+		*return_maximum = undefined;   // unlikely
 	}
 }
 
-double Pitch_getMaximum (Pitch me, double tmin, double tmax, int unit, bool interpolate) {
+double Pitch_getMaximum (Pitch me, double tmin, double tmax, kPitch_unit unit, bool interpolate) {
 	double maximum;
 	Pitch_getMaximumAndTime (me, tmin, tmax, unit, interpolate, & maximum, nullptr);
 	return maximum;
 }
 
-double Pitch_getTimeOfMaximum (Pitch me, double tmin, double tmax, int unit, bool interpolate) {
+double Pitch_getTimeOfMaximum (Pitch me, double tmin, double tmax, kPitch_unit unit, bool interpolate) {
 	double time;
 	Pitch_getMaximumAndTime (me, tmin, tmax, unit, interpolate, nullptr, & time);
 	return time;
 }
 
-void Pitch_getMinimumAndTime (Pitch me, double tmin, double tmax, int unit, bool interpolate,
+void Pitch_getMinimumAndTime (Pitch me, double tmin, double tmax, kPitch_unit unit, bool interpolate,
 	double *return_minimum, double *return_timeOfMinimum)
 {
-	Sampled_getMinimumAndX (me, tmin, tmax, Pitch_LEVEL_FREQUENCY, unit, interpolate, return_minimum, return_timeOfMinimum);
+	Sampled_getMinimumAndX (me, tmin, tmax, Pitch_LEVEL_FREQUENCY, (int) unit, interpolate, return_minimum, return_timeOfMinimum);
 	if (! doesUnitAllowNegativeValues (unit) && return_minimum && *return_minimum <= 0.0)
 	{
-		*return_minimum = NUMundefined;   // not so unlikely
+		*return_minimum = undefined;   // not so unlikely
 	}
 }
 
-double Pitch_getMinimum (Pitch me, double tmin, double tmax, int unit, bool interpolate) {
+double Pitch_getMinimum (Pitch me, double tmin, double tmax, kPitch_unit unit, bool interpolate) {
 	double minimum;
 	Pitch_getMinimumAndTime (me, tmin, tmax, unit, interpolate, & minimum, nullptr);
 	return minimum;
 }
 
-double Pitch_getTimeOfMinimum (Pitch me, double tmin, double tmax, int unit, bool interpolate) {
+double Pitch_getTimeOfMinimum (Pitch me, double tmin, double tmax, kPitch_unit unit, bool interpolate) {
 	double time;
 	Pitch_getMinimumAndTime (me, tmin, tmax, unit, interpolate, nullptr, & time);
 	return time;
@@ -242,7 +242,7 @@ static long Pitch_getMeanAbsoluteSlope (Pitch me,
 	autoNUMvector <double> frequencies (1, my nx);
 	for (long i = 1; i <= my nx; i ++) {
 		double frequency = my frame [i]. candidate [1]. frequency;
-		frequencies [i] = frequency > 0.0 && frequency < my ceiling ? frequency : 0.0;
+		frequencies [i] = ( frequency > 0.0 && frequency < my ceiling ? frequency : 0.0 );
 		if (frequencies [i] != 0.0) nVoiced ++;
 	}
 	for (long i = 1; i <= my nx; i ++)   // look for first voiced frame
@@ -271,11 +271,11 @@ static long Pitch_getMeanAbsoluteSlope (Pitch me,
 		if (out_erb) *out_erb = slopeErb / span;
 		if (out_withoutOctaveJumps) *out_withoutOctaveJumps = slopeRobust / span;
 	} else {
-		if (out_hertz) *out_hertz = NUMundefined;
-		if (out_mel) *out_mel = NUMundefined;
-		if (out_semitones) *out_semitones = NUMundefined;
-		if (out_erb) *out_erb = NUMundefined;
-		if (out_withoutOctaveJumps) *out_withoutOctaveJumps = NUMundefined;
+		if (out_hertz) *out_hertz = undefined;
+		if (out_mel) *out_mel = undefined;
+		if (out_semitones) *out_semitones = undefined;
+		if (out_erb) *out_erb = undefined;
+		if (out_withoutOctaveJumps) *out_withoutOctaveJumps = undefined;
 	}
 	return nVoiced;
 }
@@ -302,7 +302,7 @@ long Pitch_getMeanAbsSlope_noOctave (Pitch me, double *slope) {
 
 void structPitch :: v_info () {
 	long nVoiced;
-	autoNUMvector <double> frequencies (Sampled_getSortedValues (this, Pitch_LEVEL_FREQUENCY, kPitch_unit_HERTZ, & nVoiced), 1);
+	autoNUMvector <double> frequencies (Sampled_getSortedValues (this, Pitch_LEVEL_FREQUENCY, (int) kPitch_unit::HERTZ, & nVoiced), 1);
 	structDaata :: v_info ();
 	MelderInfo_writeLine (U"Time domain:");
 	MelderInfo_writeLine (U"   Start time: ", xmin, U" seconds");
@@ -344,8 +344,8 @@ void structPitch :: v_info () {
 		}
 	}
 	if (nVoiced >= 1) {   // extrema, range, mean and standard deviation
-		double minimum = Pitch_getMinimum (this, xmin, xmax, kPitch_unit_HERTZ, false);
-		double maximum = Pitch_getMaximum (this, xmin, xmax, kPitch_unit_HERTZ, false);
+		double minimum = Pitch_getMinimum (this, xmin, xmax, kPitch_unit::HERTZ, false);
+		double maximum = Pitch_getMaximum (this, xmin, xmax, kPitch_unit::HERTZ, false);
 		double meanHertz, meanMel, meanSemitones, meanErb;
 		MelderInfo_write (U"\nMinimum ", Melder_single (minimum), U" Hz = ", Melder_single (MEL (minimum)), U" Mel = ");
 		MelderInfo_writeLine (Melder_single (SEMITONES (minimum)), U" semitones above 100 Hz = ", Melder_single (ERB (minimum)), U" ERB");
@@ -353,17 +353,17 @@ void structPitch :: v_info () {
 		MelderInfo_writeLine (Melder_single (SEMITONES (maximum)), U" semitones above 100 Hz = ", Melder_single (ERB (maximum)), U" ERB");
 		MelderInfo_write (U"Range ", Melder_half (maximum - minimum), U" Hz = ", Melder_single (MEL (maximum) - MEL (minimum)), U" Mel = ");
 		MelderInfo_writeLine (Melder_half (SEMITONES (maximum) - SEMITONES (minimum)), U" semitones = ", Melder_half (ERB (maximum) - ERB (minimum)), U" ERB");
-		meanHertz = Pitch_getMean (this, 0, 0, kPitch_unit_HERTZ);
-		meanMel = Pitch_getMean (this, 0, 0, kPitch_unit_MEL);
-		meanSemitones = Pitch_getMean (this, 0, 0, kPitch_unit_SEMITONES_100);
-		meanErb = Pitch_getMean (this, 0, 0, kPitch_unit_ERB);
+		meanHertz = Pitch_getMean (this, 0, 0, kPitch_unit::HERTZ);
+		meanMel = Pitch_getMean (this, 0, 0, kPitch_unit::MEL);
+		meanSemitones = Pitch_getMean (this, 0, 0, kPitch_unit::SEMITONES_100);
+		meanErb = Pitch_getMean (this, 0, 0, kPitch_unit::ERB);
 		MelderInfo_write (U"Average: ", Melder_single (meanHertz), U" Hz = ", Melder_single (meanMel), U" Mel = ");
 		MelderInfo_writeLine (Melder_single (meanSemitones), U" semitones above 100 Hz = ", Melder_single (meanErb), U" ERB");
 		if (nVoiced >= 2) {
-			double stdevHertz = Pitch_getStandardDeviation (this, 0, 0, kPitch_unit_HERTZ);
-			double stdevMel = Pitch_getStandardDeviation (this, 0, 0, kPitch_unit_MEL);
-			double stdevSemitones = Pitch_getStandardDeviation (this, 0, 0, kPitch_unit_SEMITONES_100);
-			double stdevErb = Pitch_getStandardDeviation (this, 0, 0, kPitch_unit_ERB);
+			double stdevHertz = Pitch_getStandardDeviation (this, 0, 0, kPitch_unit::HERTZ);
+			double stdevMel = Pitch_getStandardDeviation (this, 0, 0, kPitch_unit::MEL);
+			double stdevSemitones = Pitch_getStandardDeviation (this, 0, 0, kPitch_unit::SEMITONES_100);
+			double stdevErb = Pitch_getStandardDeviation (this, 0, 0, kPitch_unit::ERB);
 			MelderInfo_write (U"Standard deviation: ", Melder_half (stdevHertz), U" Hz = ", Melder_half (stdevMel), U" Mel = ");
 			MelderInfo_writeLine (Melder_half (stdevSemitones), U" semitones = ", Melder_half (stdevErb), U" ERB");
 		}
@@ -458,7 +458,7 @@ void Pitch_pathFinder (Pitch me, double silenceThreshold, double voicingThreshol
 			unvoicedStrength = voicingThreshold + (unvoicedStrength > 0 ? unvoicedStrength : 0);
 			for (long icand = 1; icand <= frame->nCandidates; icand ++) {
 				Pitch_Candidate candidate = & frame->candidate [icand];
-				int voiceless = candidate->frequency == 0 || candidate->frequency > ceiling2;
+				bool voiceless = ! (candidate->frequency > 0.0 && candidate->frequency < ceiling2);
 				delta [iframe] [icand] = voiceless ? unvoicedStrength :
 					candidate->strength - octaveCost * NUMlog2 (ceiling / candidate->frequency);
 			}
@@ -479,8 +479,8 @@ void Pitch_pathFinder (Pitch me, double silenceThreshold, double voicingThreshol
 				for (long icand1 = 1; icand1 <= prevFrame -> nCandidates; icand1 ++) {
 					double f1 = prevFrame -> candidate [icand1]. frequency;
 					double transitionCost;
-					bool previousVoiceless = f1 <= 0 || f1 >= ceiling2;
-					bool currentVoiceless = f2 <= 0 || f2 >= ceiling2;
+					bool previousVoiceless = ! (f1 > 0.0 && f1 < ceiling2);
+					bool currentVoiceless = ! (f2 > 0.0 && f2 < ceiling2);
 					if (currentVoiceless) {
 						if (previousVoiceless) {
 							transitionCost = 0;   // both voiceless
@@ -498,7 +498,7 @@ void Pitch_pathFinder (Pitch me, double silenceThreshold, double voicingThreshol
 								for (long jframe = iframe - 2; jframe >= 1; jframe --) {
 									place1 = psi [jframe + 1] [place1];
 									f1 = my frame [jframe]. candidate [place1]. frequency;
-									if (f1 > 0 && f1 < ceiling) {
+									if (f1 > 0.0 && f1 < ceiling) {
 										transitionCost += octaveJumpCost * fabs (NUMlog2 (f1 / f2)) / (iframe - jframe);
 										break;
 									}
@@ -563,7 +563,7 @@ void Pitch_pathFinder (Pitch me, double silenceThreshold, double voicingThreshol
 				Pitch_Frame frame = & my frame [iframe];
 				Pitch_Candidate winner = & frame -> candidate [1];
 				double f = winner -> frequency;
-				if (f > ceiling && f <= ceiling2) {
+				if (f > ceiling && f < ceiling2) {
 					for (long icand = 2; icand <= frame -> nCandidates; icand ++) {
 						Pitch_Candidate loser = & frame -> candidate [icand];
 						if (loser -> frequency == 0.0) {
@@ -581,11 +581,11 @@ void Pitch_pathFinder (Pitch me, double silenceThreshold, double voicingThreshol
 	}
 }
 
-void Pitch_drawInside (Pitch me, Graphics g, double xmin, double xmax, double fmin, double fmax, bool speckle, int unit) {
-	Sampled_drawInside (me, g, xmin, xmax, fmin, fmax, speckle, Pitch_LEVEL_FREQUENCY, unit);
+void Pitch_drawInside (Pitch me, Graphics g, double xmin, double xmax, double fmin, double fmax, bool speckle, kPitch_unit unit) {
+	Sampled_drawInside (me, g, xmin, xmax, fmin, fmax, speckle, Pitch_LEVEL_FREQUENCY, (int) unit);
 }
 
-void Pitch_draw (Pitch me, Graphics g, double tmin, double tmax, double fmin, double fmax, bool garnish, bool speckle, int unit) {
+void Pitch_draw (Pitch me, Graphics g, double tmin, double tmax, double fmin, double fmax, bool garnish, bool speckle, kPitch_unit unit) {
 	Graphics_setInner (g);
 	Pitch_drawInside (me, g, tmin, tmax, fmin, fmax, speckle, unit);
 	Graphics_unsetInner (g);
@@ -593,8 +593,8 @@ void Pitch_draw (Pitch me, Graphics g, double tmin, double tmax, double fmin, do
 		Graphics_drawInnerBox (g);
 		Graphics_textBottom (g, true, U"Time (s)");
 		Graphics_marksBottom (g, 2, true, true, false);
-		Graphics_textLeft (g, true, Melder_cat (U"Pitch (", Function_getUnitText (me, Pitch_LEVEL_FREQUENCY, unit, Function_UNIT_TEXT_GRAPHICAL), U")"));
-		if (Function_isUnitLogarithmic (me, Pitch_LEVEL_FREQUENCY, unit)) {
+		Graphics_textLeft (g, true, Melder_cat (U"Pitch (", Function_getUnitText (me, Pitch_LEVEL_FREQUENCY, (int) unit, Function_UNIT_TEXT_GRAPHICAL), U")"));
+		if (Function_isUnitLogarithmic (me, Pitch_LEVEL_FREQUENCY, (int) unit)) {
 			Graphics_marksLeftLogarithmic (g, 6, true, true, false);
 		} else {
 			Graphics_marksLeft (g, 2, true, true, false);
@@ -610,8 +610,8 @@ void Pitch_difference (Pitch me, Pitch thee) {
 	}
 	for (long i = 1; i <= my nx; i ++) {
 		double myf = my frame [i]. candidate [1]. frequency, thyf = thy frame [i]. candidate [1]. frequency;
-		int myUnvoiced = myf == 0 || myf > my ceiling;
-		int thyUnvoiced = thyf == 0 || thyf > thy ceiling;
+		int myUnvoiced = ! (myf > 0.0 && myf < my ceiling);
+		int thyUnvoiced = ! (thyf > 0.0 && thyf < thy ceiling);
 		double t = Sampled_indexToX (me, i);
 		if (myUnvoiced && ! thyUnvoiced) {
 			Melder_casual (
@@ -711,7 +711,7 @@ autoPitch Pitch_interpolate (Pitch me) {
 	}
 }
 
-autoPitch Pitch_subtractLinearFit (Pitch me, int unit) {
+autoPitch Pitch_subtractLinearFit (Pitch me, kPitch_unit unit) {
 	try {
 		autoPitch thee = Pitch_interpolate (me);
 		/*
@@ -729,7 +729,7 @@ autoPitch Pitch_subtractLinearFit (Pitch me, int unit) {
 		 */
 		double sum = 0.0;
 		for (long i = imin; i <= imax; i ++) {
-			sum += Sampled_getValueAtSample (thee.get(), i, Pitch_LEVEL_FREQUENCY, unit);
+			sum += Sampled_getValueAtSample (thee.get(), i, Pitch_LEVEL_FREQUENCY, (int) unit);
 		}
 		double fmean = sum / n;
 		double tmean = thy x1 + (0.5 * (imin + imax) - 1) * thy dx;
@@ -739,7 +739,7 @@ autoPitch Pitch_subtractLinearFit (Pitch me, int unit) {
 		double numerator = 0.0, denominator = 0.0;
 		for (long i = imin; i <= imax; i ++) {
 			double t = thy x1 + (i - 1) * thy dx - tmean;
-			double f = Sampled_getValueAtSample (thee.get(), i, Pitch_LEVEL_FREQUENCY, unit) - fmean;
+			double f = Sampled_getValueAtSample (thee.get(), i, Pitch_LEVEL_FREQUENCY, (int) unit) - fmean;
 			numerator += f * t;
 			denominator += t * t;
 		}
@@ -750,12 +750,12 @@ autoPitch Pitch_subtractLinearFit (Pitch me, int unit) {
 		for (long i = imin; i <= imax; i ++) {
 			Pitch_Frame myFrame = & my frame [i], thyFrame = & thy frame [i];
 			double t = thy x1 + (i - 1) * thy dx - tmean, myFreq = FREQUENCY (myFrame);
-			double f = Sampled_getValueAtSample (thee.get(), i, Pitch_LEVEL_FREQUENCY, unit);
+			double f = Sampled_getValueAtSample (thee.get(), i, Pitch_LEVEL_FREQUENCY, (int) unit);
 			f -= slope * t;
 			if (NOT_VOICED (myFreq))
 				FREQUENCY (thyFrame) = 0.0;
 			else
-				FREQUENCY (thyFrame) = Function_convertSpecialToStandardUnit (me, f, Pitch_LEVEL_FREQUENCY, unit);
+				FREQUENCY (thyFrame) = Function_convertSpecialToStandardUnit (me, f, Pitch_LEVEL_FREQUENCY, (int) unit);
 		}
 		return thee;
 	} catch (MelderError) {
@@ -802,8 +802,8 @@ autoPitch Pitch_smooth (Pitch me, double bandWidth) {
 		autoMatrix matrix2 = Matrix_create (my xmin, my xmax, my nx, my dx, my x1, 1.0, 1.0, 1, 1.0, 1.0);
 		for (long i = 1; i <= my nx; i ++) {
 			double originalF0 = my frame [i]. candidate [1]. frequency;
-			matrix2 -> z [1] [i] = originalF0 > 0.0 && originalF0 < my ceiling ?
-				sound2 -> z [1] [i + matrix2 -> nx] : 0.0;
+			matrix2 -> z [1] [i] = ( originalF0 > 0.0 && originalF0 < my ceiling ?
+				sound2 -> z [1] [i + matrix2 -> nx] : 0.0 );
 		}
 		autoPitch thee = Matrix_to_Pitch (matrix2.get());
 		thy ceiling = my ceiling;
@@ -815,19 +815,19 @@ autoPitch Pitch_smooth (Pitch me, double bandWidth) {
 
 void Pitch_step (Pitch me, double step, double precision, double tmin, double tmax) {
 	Melder_assert (precision >= 0.0 && precision < 1.0);
-	long imin, imax;
+	integer imin, imax;
 	if (! Sampled_getWindowSamples (me, tmin, tmax, & imin, & imax)) return;
-	for (long i = imin; i <= imax; i ++) {
+	for (integer i = imin; i <= imax; i ++) {
 		Pitch_Frame frame = & my frame [i];
 		double currentFrequency = frame -> candidate [1]. frequency;
 		if (currentFrequency > 0.0 && currentFrequency < my ceiling) {
 			double targetFrequency = currentFrequency * step;
 			double fmin = (1 - precision) * targetFrequency;
 			double fmax = (1 + precision) * targetFrequency;
-			int icand, nearestCandidate = 0;
+			int nearestCandidate = 0;
 			double nearestDistance = my ceiling;
 			if (fmax > my ceiling) fmax = my ceiling;
-			for (icand = 2; icand <= frame -> nCandidates; icand ++) {
+			for (int icand = 2; icand <= frame -> nCandidates; icand ++) {
 				double f = frame -> candidate [icand]. frequency;
 				if (f > fmin && f < fmax) {
 					double localDistance = fabs (f - targetFrequency);
@@ -837,7 +837,7 @@ void Pitch_step (Pitch me, double step, double precision, double tmin, double tm
 					}
 				}
 			}
-			if (nearestCandidate) {   /* Swap candidates. */
+			if (nearestCandidate) {   // swap candidates
 				struct structPitch_Candidate candidate = frame -> candidate [nearestCandidate];
 				frame -> candidate [nearestCandidate] = frame -> candidate [1];
 				frame -> candidate [1] = candidate;
