@@ -2,7 +2,7 @@
 #define _Pitch_h_
 /* Pitch.h
  *
- * Copyright (C) 1992-2011,2014,2015,2016 Paul Boersma
+ * Copyright (C) 1992-2011,2014,2015,2016,2017 Paul Boersma
  *
  * This code is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -90,23 +90,23 @@ bool Pitch_isVoiced_t (Pitch me, double t);
 #define Pitch_NEAREST  0
 #define Pitch_LINEAR  1
 
-double Pitch_getValueAtTime (Pitch me, double time, int unit, bool interpolate);
-double Pitch_getStrengthAtTime (Pitch me, double time, int unit, bool interpolate);
+double Pitch_getValueAtTime (Pitch me, double time, kPitch_unit unit, bool interpolate);
+double Pitch_getStrengthAtTime (Pitch me, double time, kPitch_unit unit, bool interpolate);
 
 long Pitch_countVoicedFrames (Pitch me);
 
-double Pitch_getMean (Pitch me, double tmin, double tmax, int unit);
-double Pitch_getMeanStrength (Pitch me, double tmin, double tmax, int unit);
-double Pitch_getQuantile (Pitch me, double tmin, double tmax, double quantile, int unit);
-double Pitch_getStandardDeviation (Pitch me, double tmin, double tmax, int unit);
-void Pitch_getMaximumAndTime (Pitch me, double tmin, double tmax, int unit, bool interpolate,
+double Pitch_getMean (Pitch me, double tmin, double tmax, kPitch_unit unit);
+double Pitch_getMeanStrength (Pitch me, double tmin, double tmax, int strengthUnit);
+double Pitch_getQuantile (Pitch me, double tmin, double tmax, double quantile, kPitch_unit unit);
+double Pitch_getStandardDeviation (Pitch me, double tmin, double tmax, kPitch_unit unit);
+void Pitch_getMaximumAndTime (Pitch me, double tmin, double tmax, kPitch_unit unit, bool interpolate,
 	double *return_maximum, double *return_timeOfMaximum);
-double Pitch_getMaximum (Pitch me, double tmin, double tmax, int unit, bool interpolate);
-double Pitch_getTimeOfMaximum (Pitch me, double tmin, double tmax, int unit, bool interpolate);
-void Pitch_getMinimumAndTime (Pitch me, double tmin, double tmax, int unit, bool interpolate,
+double Pitch_getMaximum (Pitch me, double tmin, double tmax, kPitch_unit unit, bool interpolate);
+double Pitch_getTimeOfMaximum (Pitch me, double tmin, double tmax, kPitch_unit unit, bool interpolate);
+void Pitch_getMinimumAndTime (Pitch me, double tmin, double tmax, kPitch_unit unit, bool interpolate,
 	double *return_minimum, double *return_timeOfMinimum);
-double Pitch_getMinimum (Pitch me, double tmin, double tmax, int unit, bool interpolate);
-double Pitch_getTimeOfMinimum (Pitch me, double tmin, double tmax, int unit, bool interpolate);
+double Pitch_getMinimum (Pitch me, double tmin, double tmax, kPitch_unit unit, bool interpolate);
+double Pitch_getTimeOfMinimum (Pitch me, double tmin, double tmax, kPitch_unit unit, bool interpolate);
 
 int Pitch_getMaxnCandidates (Pitch me);
 /*
@@ -127,9 +127,9 @@ void Pitch_pathFinder (Pitch me, double silenceThreshold, double voicingThreshol
 #define Pitch_speckle_NO  false
 #define Pitch_speckle_YES  true
 void Pitch_drawInside (Pitch me, Graphics g, double tmin, double tmax, double fmin, double fmax,
-	bool speckle, int yscale);
+	bool speckle, kPitch_unit yscale);
 void Pitch_draw (Pitch me, Graphics g, double tmin, double tmax, double fmin, double fmax, bool garnish,
-	bool speckle, int yscale);
+	bool speckle, kPitch_unit yscale);
 /*
 	draw a pitch contour into a Graphics.
 	If tmax <= tmin, draw whole time domain.
@@ -164,7 +164,7 @@ autoPitch Pitch_interpolate (Pitch me);
 /* Interpolate the pitch values of unvoiced frames. */
 /* No extrapolation beyond first and last voiced frames. */
 
-autoPitch Pitch_subtractLinearFit (Pitch me, int unit);
+autoPitch Pitch_subtractLinearFit (Pitch me, kPitch_unit unit);
 
 autoPitch Pitch_smooth (Pitch me, double bandWidth);
 /* Smoothing by convolution with Gaussian curve.
