@@ -1,6 +1,6 @@
 /* Pitch_to_PointProcess.cpp
  *
- * Copyright (C) 1992-2011,2014,2015,2016 Paul Boersma
+ * Copyright (C) 1992-2011,2014,2015,2016,2017 Paul Boersma
  *
  * This code is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -22,7 +22,7 @@
  * pb 2003/05/17 introduced silence threshold
  * pb 2003/05/20 removed bug in global peak
  * pb 2003/05/22 changed 1.2 to 1.25
- * pb 2004/05/11 undefined pitch is NUMundefined rather than 0.0
+ * pb 2004/05/11 undefined pitch is `undefined` rather than 0.0
  * pb 2004/11/01 Pitch_getVoicedIntervalAfter clips to my xmax
  * pb 2004/11/28 repaired memory leak in Pitch_to_PointProcess
  * pb 2004/11/28 truncated tleft in Pitch_getVoicedIntervalAfter to my xmin (otherwise, getValue can crash)
@@ -111,8 +111,8 @@ static double findExtremum_3 (double *channel1_base, double *channel2_base, long
 
 static double Sound_findExtremum (Sound me, double tmin, double tmax, int includeMaxima, int includeMinima) {
 	long imin = Sampled_xToLowIndex (me, tmin), imax = Sampled_xToHighIndex (me, tmax);
-	Melder_assert (NUMdefined (tmin));
-	Melder_assert (NUMdefined (tmax));
+	Melder_assert (isdefined (tmin));
+	Melder_assert (isdefined (tmax));
 	if (imin < 1) imin = 1;
 	if (imax > my nx) imax = my nx;
 	double iextremum = findExtremum_3 (my z [1], my ny > 1 ? my z [2] : nullptr, imin - 1, imax - imin + 1, includeMaxima, includeMinima);
@@ -124,7 +124,7 @@ static double Sound_findExtremum (Sound me, double tmin, double tmax, int includ
 
 static double Sound_findMaximumCorrelation (Sound me, double t1, double windowLength, double tmin2, double tmax2, double *tout, double *peak) {
 	double maximumCorrelation = -1.0;   // smart 'impossible' starting value
-	double r1_best = NUMundefined, r3_best = NUMundefined, ir = NUMundefined;   // assignments not necessary, but extra safe
+	double r1_best = undefined, r3_best = undefined, ir = undefined;   // assignments not necessary, but extra safe
 	double r1 = 0.0, r2 = 0.0, r3 = 0.0;
 	double halfWindowLength = 0.5 * windowLength;
 	long ileft1 = Sampled_xToNearestIndex ((Sampled) me, t1 - halfWindowLength);
@@ -148,7 +148,7 @@ static double Sound_findMaximumCorrelation (Sound me, double t1, double windowLe
 		}
 		r1 = r2;   // >= 0
 		r2 = r3;   // >= 0
-		r3 = product != 0.0 ? product / (sqrt (norm1 * norm2)) : 0.0;   // >= 0
+		r3 = ( product != 0.0 ? product / (sqrt (norm1 * norm2)) : 0.0 );   // >= 0
 		if (r2 > maximumCorrelation /* true on first test */ && r2 >= r1 && r2 >= r3) {
 			r1_best = r1;
 			maximumCorrelation = r2;
@@ -162,7 +162,7 @@ static double Sound_findMaximumCorrelation (Sound me, double t1, double windowLe
 	 */
 	if (maximumCorrelation > -1.0) {   // was maximumCorrelation ever assigned to?...
 		// ...then r1_best and r3_best and ir must also have been assigned to:
-		Melder_assert (NUMdefined (r1_best) && NUMdefined (r3_best) && NUMdefined (ir));
+		Melder_assert (isdefined (r1_best) && isdefined (r3_best) && isdefined (ir));
 		double d2r = 2 * maximumCorrelation - r1_best - r3_best;
 		if (d2r != 0.0) {
 			double dr = 0.5 * (r3_best - r1_best);
@@ -195,12 +195,12 @@ autoPointProcess Sound_Pitch_to_PointProcess_cc (Sound sound, Pitch pitch) {
 			 */
 			double tmiddle = (tleft + tright) / 2;
 			Melder_progress ((tmiddle - sound -> xmin) / (sound -> xmax - sound -> xmin), U"Sound & Pitch to PointProcess");
-			double f0middle = Pitch_getValueAtTime (pitch, tmiddle, kPitch_unit_HERTZ, Pitch_LINEAR);
+			double f0middle = Pitch_getValueAtTime (pitch, tmiddle, kPitch_unit::HERTZ, Pitch_LINEAR);
 
 			/*
 			 * Our first point is near this middle.
 			 */
-			if (f0middle == NUMundefined) {
+			if (isundef (f0middle)) {
 				Melder_fatal (U"Sound_Pitch_to_PointProcess_cc:"
 					U" tleft ", tleft,
 					U", tright ", tright,
@@ -208,13 +208,13 @@ autoPointProcess Sound_Pitch_to_PointProcess_cc (Sound sound, Pitch pitch) {
 				);
 			}
 			double tmax = Sound_findExtremum (sound, tmiddle - 0.5 / f0middle, tmiddle + 0.5 / f0middle, true, true);
-			Melder_assert (NUMdefined (tmax));
+			Melder_assert (isdefined (tmax));
 			PointProcess_addPoint (point.get(), tmax);
 
 			double tsave = tmax;
 			for (;;) {
-				double f0 = Pitch_getValueAtTime (pitch, tmax, kPitch_unit_HERTZ, Pitch_LINEAR), correlation;
-				if (f0 == NUMundefined) break;
+				double f0 = Pitch_getValueAtTime (pitch, tmax, kPitch_unit::HERTZ, Pitch_LINEAR), correlation;
+				if (isundef (f0)) break;
 				correlation = Sound_findMaximumCorrelation (sound, tmax, 1.0 / f0, tmax - 1.25 / f0, tmax - 0.8 / f0, & tmax, & peak);
 				if (correlation == -1) /*break*/ tmax -= 1.0 / f0;   // this one period will drop out
 				if (tmax < tleft) {
@@ -231,8 +231,8 @@ autoPointProcess Sound_Pitch_to_PointProcess_cc (Sound sound, Pitch pitch) {
 			}
 			tmax = tsave;
 			for (;;) {
-				double f0 = Pitch_getValueAtTime (pitch, tmax, kPitch_unit_HERTZ, Pitch_LINEAR), correlation;
-				if (f0 == NUMundefined) break;
+				double f0 = Pitch_getValueAtTime (pitch, tmax, kPitch_unit::HERTZ, Pitch_LINEAR), correlation;
+				if (isundef (f0)) break;
 				correlation = Sound_findMaximumCorrelation (sound, tmax, 1.0 / f0, tmax + 0.8 / f0, tmax + 1.25 / f0, & tmax, & peak);
 				if (correlation == -1) /*break*/ tmax += 1.0 / f0;
 				if (tmax > tright) {
@@ -274,20 +274,20 @@ autoPointProcess Sound_Pitch_to_PointProcess_peaks (Sound sound, Pitch pitch, in
 			 */
 			double tmiddle = (tleft + tright) / 2;
 			Melder_progress ((tmiddle - sound -> xmin) / (sound -> xmax - sound -> xmin), U"Sound & Pitch: To PointProcess");
-			double f0middle = Pitch_getValueAtTime (pitch, tmiddle, kPitch_unit_HERTZ, Pitch_LINEAR);
+			double f0middle = Pitch_getValueAtTime (pitch, tmiddle, kPitch_unit::HERTZ, Pitch_LINEAR);
 
 			/*
 			 * Our first point is near this middle.
 			 */
-			Melder_assert (NUMdefined (f0middle));
+			Melder_assert (isdefined (f0middle));
 			double tmax = Sound_findExtremum (sound, tmiddle - 0.5 / f0middle, tmiddle + 0.5 / f0middle, includeMaxima, includeMinima);
-			Melder_assert (NUMdefined (tmax));
+			Melder_assert (isdefined (tmax));
 			PointProcess_addPoint (point.get(), tmax);
 
 			double tsave = tmax;
 			for (;;) {
-				double f0 = Pitch_getValueAtTime (pitch, tmax, kPitch_unit_HERTZ, Pitch_LINEAR);
-				if (f0 == NUMundefined) break;
+				double f0 = Pitch_getValueAtTime (pitch, tmax, kPitch_unit::HERTZ, Pitch_LINEAR);
+				if (isundef (f0)) break;
 				tmax = Sound_findExtremum (sound, tmax - 1.25 / f0, tmax - 0.8 / f0, includeMaxima, includeMinima);
 				if (tmax < tleft) {
 					if (tmax - addedRight > 0.8 / f0) {
@@ -301,8 +301,8 @@ autoPointProcess Sound_Pitch_to_PointProcess_peaks (Sound sound, Pitch pitch, in
 			}
 			tmax = tsave;
 			for (;;) {
-				double f0 = Pitch_getValueAtTime (pitch, tmax, kPitch_unit_HERTZ, Pitch_LINEAR);
-				if (f0 == NUMundefined) break;
+				double f0 = Pitch_getValueAtTime (pitch, tmax, kPitch_unit::HERTZ, Pitch_LINEAR);
+				if (isundef (f0)) break;
 				tmax = Sound_findExtremum (sound, tmax + 0.8 / f0, tmax + 1.25 / f0, includeMaxima, includeMinima);
 				if (tmax > tright) {
 					PointProcess_addPoint (point.get(), tmax);
