@@ -1,6 +1,6 @@
 /* PointProcess.cpp
  *
- * Copyright (C) 1992-2012,2015,2016 Paul Boersma
+ * Copyright (C) 1992-2012,2015,2016,2017 Paul Boersma
  *
  * This code is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -41,7 +41,7 @@
 Thing_implement (PointProcess, Function, 0);
 
 static void infoPeriods (PointProcess me, double shortestPeriod, double longestPeriod, double maximumPeriodFactor, int precision) {
-	long numberOfPeriods = PointProcess_getNumberOfPeriods (me, 0.0, 0.0, shortestPeriod, longestPeriod, maximumPeriodFactor);
+	integer numberOfPeriods = PointProcess_getNumberOfPeriods (me, 0.0, 0.0, shortestPeriod, longestPeriod, maximumPeriodFactor);
 	double meanPeriod = PointProcess_getMeanPeriod (me, 0.0, 0.0, shortestPeriod, longestPeriod, maximumPeriodFactor);
 	double stdevPeriod = PointProcess_getStdevPeriod (me, 0.0, 0.0, shortestPeriod, longestPeriod, maximumPeriodFactor);
 	double jitter_local = PointProcess_getJitter_local (me, 0.0, 0.0, shortestPeriod, longestPeriod, maximumPeriodFactor);
@@ -79,19 +79,19 @@ void structPointProcess :: v_info () {
 
 void structPointProcess :: v_shiftX (double xfrom, double xto) {
 	PointProcess_Parent :: v_shiftX (xfrom, xto);
-	for (long i = 1; i <= nt; i ++) {
+	for (integer i = 1; i <= nt; i ++) {
 		NUMshift (& t [i], xfrom, xto);
 	}
 }
 
 void structPointProcess :: v_scaleX (double xminfrom, double xmaxfrom, double xminto, double xmaxto) {
 	PointProcess_Parent :: v_scaleX (xminfrom, xmaxfrom, xminto, xmaxto);
-	for (long i = 1; i <= nt; i ++) {
+	for (integer i = 1; i <= nt; i ++) {
 		NUMscale (& t [i], xminfrom, xmaxfrom, xminto, xmaxto);
 	}
 }
 
-void PointProcess_init (PointProcess me, double tmin, double tmax, long initialMaxnt) {
+void PointProcess_init (PointProcess me, double tmin, double tmax, integer initialMaxnt) {
 	Function_init (me, tmin, tmax);
 	if (initialMaxnt < 1) initialMaxnt = 1;
 	my maxnt = initialMaxnt;
@@ -99,7 +99,7 @@ void PointProcess_init (PointProcess me, double tmin, double tmax, long initialM
 	my t = NUMvector <double> (1, my maxnt);
 }
 
-autoPointProcess PointProcess_create (double tmin, double tmax, long initialMaxnt) {
+autoPointProcess PointProcess_create (double tmin, double tmax, integer initialMaxnt) {
 	try {
 		autoPointProcess me = Thing_new (PointProcess);
 		PointProcess_init (me.get(), tmin, tmax, initialMaxnt);
@@ -111,10 +111,10 @@ autoPointProcess PointProcess_create (double tmin, double tmax, long initialMaxn
 
 autoPointProcess PointProcess_createPoissonProcess (double startingTime, double finishingTime, double density) {
 	try {
-		long nt = NUMrandomPoisson ((finishingTime - startingTime) * density);
+		integer nt = (integer) NUMrandomPoisson ((finishingTime - startingTime) * density);
 		autoPointProcess me = PointProcess_create (startingTime, finishingTime, nt);
 		my nt = nt;
-		for (long i = 1; i <= nt; i ++)
+		for (integer i = 1; i <= nt; i ++)
 			my t [i] = NUMrandomUniform (startingTime, finishingTime);
 		NUMsort_d (my nt, my t);
 		return me;
@@ -123,23 +123,23 @@ autoPointProcess PointProcess_createPoissonProcess (double startingTime, double
 	}
 }
 
-long PointProcess_getLowIndex (PointProcess me, double t) {
+integer PointProcess_getLowIndex (PointProcess me, double t) {
 	if (my nt == 0 || t < my t [1])
 		return 0;
 	if (t >= my t [my nt])   // special case that often occurs in practice
 		return my nt;
 	Melder_assert (my nt != 1);   // may fail if t or my t [1] is NaN
 	/* Start binary search. */
-	long left = 1, right = my nt;
+	integer left = 1, right = my nt;
 	while (left < right - 1) {
-		long mid = (left + right) / 2;
+		integer mid = (left + right) / 2;
 		if (t >= my t [mid]) left = mid; else right = mid;
 	}
 	Melder_assert (right == left + 1);
 	return left;
 }
 
-long PointProcess_getHighIndex (PointProcess me, double t) {
+integer PointProcess_getHighIndex (PointProcess me, double t) {
 	if (my nt == 0)
 		return 0;
 	if (t <= my t [1])
@@ -147,16 +147,16 @@ long PointProcess_getHighIndex (PointProcess me, double t) {
 	if (t > my t [my nt])
 		return my nt + 1;
 	/* Start binary search. */
-	long left = 1, right = my nt;
+	integer left = 1, right = my nt;
 	while (left < right - 1) {
-		long mid = (left + right) / 2;
+		integer mid = (left + right) / 2;
 		if (t > my t [mid]) left = mid; else right = mid;
 	}
 	Melder_assert (right == left + 1);
 	return right;
 }
 
-long PointProcess_getNearestIndex (PointProcess me, double t) {
+integer PointProcess_getNearestIndex (PointProcess me, double t) {
 	if (my nt == 0)
 		return 0;
 	if (t <= my t [1])
@@ -164,9 +164,9 @@ long PointProcess_getNearestIndex (PointProcess me, double t) {
 	if (t >= my t [my nt])
 		return my nt;
 	/* Start binary search. */
-	long left = 1, right = my nt;
+	integer left = 1, right = my nt;
 	while (left < right - 1) {
-		long mid = (left + right) / 2;
+		integer mid = (left + right) / 2;
 		if (t >= my t [mid]) left = mid; else right = mid;
 	}
 	Melder_assert (right == left + 1);
@@ -175,7 +175,7 @@ long PointProcess_getNearestIndex (PointProcess me, double t) {
 
 void PointProcess_addPoint (PointProcess me, double t) {
 	try {
-		if (t == NUMundefined)
+		if (isundef (t))
 			Melder_throw (U"Cannot add a point at an undefined time.");
 		if (my nt >= my maxnt) {
 			/*
@@ -193,9 +193,9 @@ void PointProcess_addPoint (PointProcess me, double t) {
 		if (my nt == 0 || t >= my t [my nt]) {   // special case that often occurs in practice
 			my t [++ my nt] = t;
 		} else {
-			long left = PointProcess_getLowIndex (me, t);
+			integer left = PointProcess_getLowIndex (me, t);
 			if (left == 0 || my t [left] != t) {
-				for (long i = my nt; i > left; i --) my t [i + 1] = my t [i];
+				for (integer i = my nt; i > left; i --) my t [i + 1] = my t [i];
 				my nt ++;
 				my t [left + 1] = t;
 			}
@@ -205,9 +205,9 @@ void PointProcess_addPoint (PointProcess me, double t) {
 	}
 }
 
-void PointProcess_removePoint (PointProcess me, long pointNumber) {
+void PointProcess_removePoint (PointProcess me, integer pointNumber) {
 	if (pointNumber < 1 || pointNumber > my nt) return;
-	for (long i = pointNumber; i < my nt; i ++)
+	for (integer i = pointNumber; i < my nt; i ++)
 		my t [i] = my t [i + 1];
 	my nt --;
 }
@@ -216,12 +216,12 @@ void PointProcess_removePointNear (PointProcess me, double time) {
 	PointProcess_removePoint (me, PointProcess_getNearestIndex (me, time));
 }
 
-void PointProcess_removePoints (PointProcess me, long first, long last) {
+void PointProcess_removePoints (PointProcess me, integer first, integer last) {
 	if (first < 1) first = 1;
 	if (last > my nt) last = my nt;
-	long distance = last - first + 1;
+	integer distance = last - first + 1;
 	if (distance <= 0) return;
-	for (long i = first + distance; i <= my nt; i ++)
+	for (integer i = first + distance; i <= my nt; i ++)
 		my t [i - distance] = my t [i];
 	my nt -= distance;
 }
@@ -234,12 +234,12 @@ void PointProcess_draw (PointProcess me, Graphics g, double tmin, double tmax, b
 	if (tmax <= tmin) { tmin = my xmin; tmax = my xmax; }
 	Graphics_setWindow (g, tmin, tmax, -1.0, 1.0);
 	if (my nt) {
-		long imin = PointProcess_getHighIndex (me, tmin);
-		long imax = PointProcess_getLowIndex  (me, tmax);
+		integer imin = PointProcess_getHighIndex (me, tmin);
+		integer imax = PointProcess_getLowIndex  (me, tmax);
 		int lineType = Graphics_inqLineType (g);
 		Graphics_setLineType (g, Graphics_DOTTED);
 		Graphics_setInner (g);
-		for (long i = imin; i <= imax; i ++) {
+		for (integer i = imin; i <= imax; i ++) {
 			Graphics_line (g, my t [i], -1.0, my t [i], 1.0);
 		}
 		Graphics_setLineType (g, lineType);
@@ -253,8 +253,8 @@ void PointProcess_draw (PointProcess me, Graphics g, double tmin, double tmax, b
 }
 
 double PointProcess_getInterval (PointProcess me, double t) {
-	long ileft = PointProcess_getLowIndex (me, t);
-	if (ileft <= 0 || ileft >= my nt) return NUMundefined;
+	integer ileft = PointProcess_getLowIndex (me, t);
+	if (ileft <= 0 || ileft >= my nt) return undefined;
 	return my t [ileft + 1] - my t [ileft];
 }
 
@@ -263,7 +263,7 @@ autoPointProcess PointProcesses_union (PointProcess me, PointProcess thee) {
 		autoPointProcess him = Data_copy (me);
 		if (thy xmin < my xmin) his xmin = thy xmin;
 		if (thy xmax > my xmax) his xmax = thy xmax;
-		for (long i = 1; i <= thy nt; i ++) {
+		for (integer i = 1; i <= thy nt; i ++) {
 			PointProcess_addPoint (him.get(), thy t [i]);
 		}
 		return him;
@@ -272,12 +272,12 @@ autoPointProcess PointProcesses_union (PointProcess me, PointProcess thee) {
 	}
 }
 
-long PointProcess_findPoint (PointProcess me, double t) {
-	long left = 1, right = my nt;
+integer PointProcess_findPoint (PointProcess me, double t) {
+	integer left = 1, right = my nt;
 	if (my nt == 0) return 0;
 	if (t < my t [left] || t > my t [right]) return 0;
 	while (left < right - 1) {
-		long mid = (left + right) / 2;   // tleft <= t <= tright
+		integer mid = (left + right) / 2;   // tleft <= t <= tright
 		if (t == my t [mid]) return mid;
 		if (t > my t [mid])
 			left = mid;
@@ -294,7 +294,7 @@ autoPointProcess PointProcesses_intersection (PointProcess me, PointProcess thee
 		autoPointProcess him = Data_copy (me);
 		if (thy xmin > my xmin) his xmin = thy xmin;
 		if (thy xmax < my xmax) his xmax = thy xmax;
-		for (long i = my nt; i >= 1; i --)
+		for (integer i = my nt; i >= 1; i --)
 			if (! PointProcess_findPoint (thee, my t [i]))
 				PointProcess_removePoint (him.get(), i);
 		return him;
@@ -306,7 +306,7 @@ autoPointProcess PointProcesses_intersection (PointProcess me, PointProcess thee
 autoPointProcess PointProcesses_difference (PointProcess me, PointProcess thee) {
 	try {
 		autoPointProcess him = Data_copy (me);
-		for (long i = my nt; i >= 1; i --)
+		for (integer i = my nt; i >= 1; i --)
 			if (PointProcess_findPoint (thee, my t [i]))
 				PointProcess_removePoint (him.get(), i);
 		return him;
@@ -318,9 +318,9 @@ autoPointProcess PointProcesses_difference (PointProcess me, PointProcess thee)
 void PointProcess_fill (PointProcess me, double tmin, double tmax, double period) {
 	try {
 		if (tmax <= tmin) tmin = my xmin, tmax = my xmax;   // autowindowing
-		long n = (long) floor ((tmax - tmin) / period);
+		integer n = (integer) floor ((tmax - tmin) / period);
 		double t = 0.5 * (tmin + tmax - n * period);
-		for (long i = 1; i <= n; i ++, t += period) {
+		for (integer i = 1; i <= n; i ++, t += period) {
 			PointProcess_addPoint (me, t);
 		}
 	} catch (MelderError) {
@@ -330,9 +330,9 @@ void PointProcess_fill (PointProcess me, double tmin, double tmax, double period
 
 void PointProcess_voice (PointProcess me, double period, double maxT) {
 	try {
-		long ipointright;
+		integer ipointright;
 		double beginVoiceless = my xmin, endVoiceless;
-		for (long ipointleft = 1; ipointleft <= my nt; ipointleft = ipointright + 1) {
+		for (integer ipointleft = 1; ipointleft <= my nt; ipointleft = ipointright + 1) {
 			endVoiceless = my t [ipointleft];
 			PointProcess_fill (me, beginVoiceless, endVoiceless, period);
 			for (ipointright = ipointleft + 1; ipointright <= my nt; ipointright ++)
@@ -348,19 +348,19 @@ void PointProcess_voice (PointProcess me, double period, double maxT) {
 	}
 }
 
-long PointProcess_getWindowPoints (PointProcess me, double tmin, double tmax, long *p_imin, long *p_imax) {
-	long imin = PointProcess_getHighIndex (me, tmin);
-	long imax = PointProcess_getLowIndex (me, tmax);
+integer PointProcess_getWindowPoints (PointProcess me, double tmin, double tmax, integer *p_imin, integer *p_imax) {
+	integer imin = PointProcess_getHighIndex (me, tmin);
+	integer imax = PointProcess_getLowIndex (me, tmax);
 	if (p_imin) *p_imin = imin;
 	if (p_imax) *p_imax = imax;
 	return imax - imin + 1;
 }
 
-static bool PointProcess_isPeriod (PointProcess me, long ileft, double minimumPeriod, double maximumPeriod, double maximumPeriodFactor) {
+static bool PointProcess_isPeriod (PointProcess me, integer ileft, double minimumPeriod, double maximumPeriod, double maximumPeriodFactor) {
 	/*
 	 * This function answers the question: is the interval from point 'ileft' to point 'ileft+1' a period?
 	 */
-	long iright = ileft + 1;
+	integer iright = ileft + 1;
 	/*
 	 * Period condition 1: both 'ileft' and 'iright' have to be within the point process.
 	 */
@@ -376,27 +376,29 @@ static bool PointProcess_isPeriod (PointProcess me, long ileft, double minimumPe
 			double interval = my t [iright] - my t [ileft];
 			if (interval <= 0.0 || interval < minimumPeriod || interval > maximumPeriod) {
 				return false;
-			} else if (! NUMdefined (maximumPeriodFactor) || maximumPeriodFactor < 1.0) {
+			} else if (isundef (maximumPeriodFactor) || maximumPeriodFactor < 1.0) {
 				return true;
 			} else {
 				/*
 				 * Period condition 3: the interval cannot be too different from both of its neigbours, if any.
 				 */
-				double previousInterval = ileft <= 1 ? NUMundefined : my t [ileft] - my t [ileft - 1];
-				double nextInterval = iright >= my nt ? NUMundefined : my t [iright + 1] - my t [iright];
-				double previousIntervalFactor = NUMdefined (previousInterval) && previousInterval > 0.0 ? interval / previousInterval : NUMundefined;
-				double nextIntervalFactor = NUMdefined (nextInterval) && nextInterval > 0.0 ? interval / nextInterval : NUMundefined;
-				if (! NUMdefined (previousIntervalFactor) && ! NUMdefined (nextIntervalFactor)) {
+				double previousInterval = ( ileft <= 1 ? undefined : my t [ileft] - my t [ileft - 1] );
+				double nextInterval = ( iright >= my nt ? undefined : my t [iright + 1] - my t [iright] );
+				double previousIntervalFactor =
+					( isdefined (previousInterval) && previousInterval > 0.0 ? interval / previousInterval : undefined );
+				double nextIntervalFactor =
+					( isdefined (nextInterval) && nextInterval > 0.0 ? interval / nextInterval : undefined );
+				if (isundef (previousIntervalFactor) && isundef (nextIntervalFactor)) {
 					return true;   // no neighbours: this is a period
 				}
-				if (NUMdefined (previousIntervalFactor) && previousIntervalFactor > 0.0 && previousIntervalFactor < 1.0) {
+				if (isdefined (previousIntervalFactor) && previousIntervalFactor > 0.0 && previousIntervalFactor < 1.0) {
 					previousIntervalFactor = 1.0 / previousIntervalFactor;
 				}
-				if (NUMdefined (nextIntervalFactor) && nextIntervalFactor > 0.0 && nextIntervalFactor < 1.0) {
+				if (isdefined (nextIntervalFactor) && nextIntervalFactor > 0.0 && nextIntervalFactor < 1.0) {
 					nextIntervalFactor = 1.0 / nextIntervalFactor;
 				}
-				if (NUMdefined (previousIntervalFactor) && previousIntervalFactor > maximumPeriodFactor &&
-					NUMdefined (nextIntervalFactor) && nextIntervalFactor > maximumPeriodFactor)
+				if (isdefined (previousIntervalFactor) && previousIntervalFactor > maximumPeriodFactor &&
+					isdefined (nextIntervalFactor) && nextIntervalFactor > maximumPeriodFactor)
 				{
 					return false;
 				}
@@ -406,14 +408,14 @@ static bool PointProcess_isPeriod (PointProcess me, long ileft, double minimumPe
 	return true;
 }
 
-long PointProcess_getNumberOfPeriods (PointProcess me, double tmin, double tmax,
+integer PointProcess_getNumberOfPeriods (PointProcess me, double tmin, double tmax,
 	double minimumPeriod, double maximumPeriod, double maximumPeriodFactor)
 {
 	if (tmax <= tmin) tmin = my xmin, tmax = my xmax;   // autowindowing
-	long imin, imax;
-	long numberOfPeriods = PointProcess_getWindowPoints (me, tmin, tmax, & imin, & imax) - 1;
+	integer imin, imax;
+	integer numberOfPeriods = PointProcess_getWindowPoints (me, tmin, tmax, & imin, & imax) - 1;
 	if (numberOfPeriods < 1) return 0;
-	for (long i = imin; i < imax; i ++) {
+	for (integer i = imin; i < imax; i ++) {
 		if (PointProcess_isPeriod (me, i, minimumPeriod, maximumPeriod, maximumPeriodFactor)) {
 			(void) 0;   // this interval counts as a period
 		} else {
@@ -427,45 +429,45 @@ double PointProcess_getMeanPeriod (PointProcess me, double tmin, double tmax,
 	double minimumPeriod, double maximumPeriod, double maximumPeriodFactor)
 {
 	if (tmax <= tmin) tmin = my xmin, tmax = my xmax;   // autowindowing
-	long imin, imax;
-	long numberOfPeriods = PointProcess_getWindowPoints (me, tmin, tmax, & imin, & imax) - 1;
-	if (numberOfPeriods < 1) return NUMundefined;
-	double sum = 0.0;
-	for (long i = imin; i < imax; i ++) {
+	integer imin, imax;
+	integer numberOfPeriods = PointProcess_getWindowPoints (me, tmin, tmax, & imin, & imax) - 1;
+	if (numberOfPeriods < 1) return undefined;
+	real80 sum = 0.0;
+	for (integer i = imin; i < imax; i ++) {
 		if (PointProcess_isPeriod (me, i, minimumPeriod, maximumPeriod, maximumPeriodFactor)) {
 			sum += my t [i + 1] - my t [i];   // this interval counts as a period
 		} else {
 			numberOfPeriods --;   // this interval does not count as a period
 		}
 	}
-	return numberOfPeriods > 0 ? sum / numberOfPeriods : NUMundefined;
+	return numberOfPeriods > 0 ? real (sum / numberOfPeriods) : undefined;
 }
 
 double PointProcess_getStdevPeriod (PointProcess me, double tmin, double tmax,
 	double minimumPeriod, double maximumPeriod, double maximumPeriodFactor)
 {
 	if (tmax <= tmin) tmin = my xmin, tmax = my xmax;   // autowindowing
-	long imin, imax;
-	long numberOfPeriods = PointProcess_getWindowPoints (me, tmin, tmax, & imin, & imax) - 1;
-	if (numberOfPeriods < 2) return NUMundefined;
+	integer imin, imax;
+	integer numberOfPeriods = PointProcess_getWindowPoints (me, tmin, tmax, & imin, & imax) - 1;
+	if (numberOfPeriods < 2) return undefined;
 	/*
 	 * Compute mean.
 	 */
-	double sum = 0.0;
-	for (long i = imin; i < imax; i ++) {
+	real80 sum = 0.0;
+	for (integer i = imin; i < imax; i ++) {
 		if (PointProcess_isPeriod (me, i, minimumPeriod, maximumPeriod, maximumPeriodFactor)) {
 			sum += my t [i + 1] - my t [i];   // this interval counts as a period
 		} else {
 			numberOfPeriods --;   // this interval does not count as a period
 		}
 	}
-	if (numberOfPeriods < 2) return NUMundefined;
-	double mean = sum / numberOfPeriods;
+	if (numberOfPeriods < 2) return undefined;
+	double mean = real (sum / numberOfPeriods);
 	/*
 	 * Compute variance.
 	 */
-	double sum2 = 0.0;
-	for (long i = imin; i < imax; i ++) {
+	real80 sum2 = 0.0;
+	for (integer i = imin; i < imax; i ++) {
 		if (PointProcess_isPeriod (me, i, minimumPeriod, maximumPeriod, maximumPeriodFactor)) {
 			double dperiod = my t [i + 1] - my t [i] - mean;
 			sum2 += dperiod * dperiod;
@@ -474,7 +476,7 @@ double PointProcess_getStdevPeriod (PointProcess me, double tmin, double tmax,
 	/*
 	 * Compute standard deviation.
 	 */
-	return sqrt (sum2 / (numberOfPeriods - 1));
+	return sqrt (real (sum2 / (numberOfPeriods - 1)));
 }
 
 /* End of file PointProcess.cpp */
