@@ -1,6 +1,6 @@
 /* SampledXY_def.h
  *
- * Copyright (C) 1992-2011,2013,2014,2015 Paul Boersma
+ * Copyright (C) 1992-2011,2013,2014,2015,2017 Paul Boersma
  *
  * This code is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -22,7 +22,7 @@ oo_DEFINE_CLASS (SampledXY, Sampled)
 
 	oo_DOUBLE (ymin)
 	oo_DOUBLE (ymax)
-	oo_LONG (ny)
+	oo_INTEGER (ny)
 	oo_DOUBLE (dy)
 	oo_DOUBLE (y1)
 
