@@ -1,6 +1,6 @@
 /* Sound.cpp
  *
- * Copyright (C) 1992-2012,2014,2015,2016 Paul Boersma
+ * Copyright (C) 1992-2012,2014,2015,2016,2017 Paul Boersma
  *
  * This code is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -196,16 +196,13 @@ autoSound Sounds_combineToStereo (OrderedOf<structSound>* me) {
 						U"You could resample one or more of the sounds before combining.");
 			}
 		}
-		double sharedMinimumTime = NUMundefined, sharedMaximumTime = NUMundefined;
-		for (long isound = 1; isound <= my size; isound ++) {
+		Melder_assert (my size > 0);
+		double sharedMinimumTime = my at [1] -> xmin;
+		double sharedMaximumTime = my at [1] -> xmax;
+		for (long isound = 2; isound <= my size; isound ++) {
 			Sound sound = my at [isound];
-			if (isound == 1) {
-				sharedMinimumTime = sound -> xmin;
-				sharedMaximumTime = sound -> xmax;
-			} else {
-				if (sound -> xmin < sharedMinimumTime) sharedMinimumTime = sound -> xmin;
-				if (sound -> xmax > sharedMaximumTime) sharedMaximumTime = sound -> xmax;
-			}
+			if (sound -> xmin < sharedMinimumTime) sharedMinimumTime = sound -> xmin;
+			if (sound -> xmax > sharedMaximumTime) sharedMaximumTime = sound -> xmax;
 		}
 		autoNUMvector <double> numberOfInitialZeroes (1, my size);
 		long sharedNumberOfSamples = 0;
@@ -252,56 +249,56 @@ autoSound Sound_extractChannel (Sound me, long ichan) {
 	}
 }
 
-static double getSumOfSquares (Sound me, double xmin, double xmax, long *n) {
+static double getSumOfSquares (Sound me, double xmin, double xmax, integer *n) {
 	if (xmax <= xmin) { xmin = my xmin; xmax = my xmax; }
-	long imin, imax;
+	integer imin, imax;
 	*n = Sampled_getWindowSamples (me, xmin, xmax, & imin, & imax);
-	if (*n < 1) return NUMundefined;
-	double sum2 = 0.0;
-	for (long channel = 1; channel <= my ny; channel ++) {
+	if (*n < 1) return undefined;
+	real80 sum2 = 0.0;
+	for (integer channel = 1; channel <= my ny; channel ++) {
 		double *amplitude = my z [channel];
-		for (long i = imin; i <= imax; i ++) {
+		for (integer i = imin; i <= imax; i ++) {
 			double value = amplitude [i];
 			sum2 += value * value;
 		}
 	}
-	return sum2;
+	return (real) sum2;
 }
 
 double Sound_getRootMeanSquare (Sound me, double xmin, double xmax) {
-	long n;
+	integer n;
 	double sum2 = getSumOfSquares (me, xmin, xmax, & n);
-	return NUMdefined (sum2) ? sqrt (sum2 / (n * my ny)) : NUMundefined;
+	return isdefined (sum2) ? sqrt (sum2 / (n * my ny)) : undefined;
 }
 
 double Sound_getEnergy (Sound me, double xmin, double xmax) {
-	long n;
+	integer n;
 	double sum2 = getSumOfSquares (me, xmin, xmax, & n);
-	return NUMdefined (sum2) ? sum2 * my dx / my ny : NUMundefined;
+	return isdefined (sum2) ? sum2 * my dx / my ny : undefined;
 }
 
 double Sound_getPower (Sound me, double xmin, double xmax) {
-	long n;
+	integer n;
 	double sum2 = getSumOfSquares (me, xmin, xmax, & n);
-	return NUMdefined (sum2) ? sum2 / (n * my ny) : NUMundefined;
+	return isdefined (sum2) ? sum2 / (n * my ny) : undefined;
 }
 
 double Sound_getEnergyInAir (Sound me) {
-	long n;
-	double sum2 = getSumOfSquares (me, 0, 0, & n);
-	return NUMdefined (sum2) ? sum2 * my dx / (400 * my ny) : NUMundefined;
+	integer n;
+	double sum2 = getSumOfSquares (me, 0.0, 0.0, & n);
+	return isdefined (sum2) ? sum2 * my dx / (400.0 * my ny) : undefined;
 }
 
 double Sound_getIntensity_dB (Sound me) {
-	long n;
-	double sum2 = getSumOfSquares (me, 0, 0, & n);
-	return NUMdefined (sum2) && sum2 != 0.0 ? 10 * log10 (sum2 / (n * my ny) / 4.0e-10) : NUMundefined;
+	integer n;
+	double sum2 = getSumOfSquares (me, 0.0, 0.0, & n);
+	return isdefined (sum2) && sum2 != 0.0 ? 10.0 * log10 (sum2 / (n * my ny) / 4.0e-10) : undefined;
 }
 
 double Sound_getPowerInAir (Sound me) {
-	long n;
+	integer n;
 	double sum2 = getSumOfSquares (me, 0, 0, & n);
-	return NUMdefined (sum2) ? sum2 / (n * my ny) / 400 : NUMundefined;
+	return ( isdefined (sum2) ? sum2 / (n * my ny) / 400 : undefined );
 }
 
 autoSound Matrix_to_Sound_mono (Matrix me, long row) {
@@ -509,7 +506,7 @@ autoSound Sounds_concatenate (OrderedOf<structSound>& list, double overlapTime)
 	}
 }
 
-autoSound Sounds_convolve (Sound me, Sound thee, enum kSounds_convolve_scaling scaling, enum kSounds_convolve_signalOutsideTimeDomain signalOutsideTimeDomain) {
+autoSound Sounds_convolve (Sound me, Sound thee, kSounds_convolve_scaling scaling, kSounds_convolve_signalOutsideTimeDomain signalOutsideTimeDomain) {
 	try {
 		if (my ny > 1 && thy ny > 1 && my ny != thy ny)
 			Melder_throw (U"The numbers of channels of the two sounds have to be equal or 1.");
@@ -545,10 +542,10 @@ autoSound Sounds_convolve (Sound me, Sound thee, enum kSounds_convolve_scaling s
 			}
 		}
 		switch (signalOutsideTimeDomain) {
-			case kSounds_convolve_signalOutsideTimeDomain_ZERO: {
+			case kSounds_convolve_signalOutsideTimeDomain::ZERO: {
 				// do nothing
 			} break;
-			case kSounds_convolve_signalOutsideTimeDomain_SIMILAR: {
+			case kSounds_convolve_signalOutsideTimeDomain::SIMILAR: {
 				for (long channel = 1; channel <= numberOfChannels; channel ++) {
 					double *a = his z [channel];
 					double edge = n1 < n2 ? n1 : n2;
@@ -562,25 +559,25 @@ autoSound Sounds_convolve (Sound me, Sound thee, enum kSounds_convolve_scaling s
 			//case kSounds_convolve_signalOutsideTimeDomain_PERIODIC: {
 				// do nothing
 			//} break;
-			default: Melder_fatal (U"Sounds_convolve: unimplemented outside-time-domain strategy ", signalOutsideTimeDomain);
+			default: Melder_fatal (U"Sounds_convolve: unimplemented outside-time-domain strategy ", (int) signalOutsideTimeDomain);
 		}
 		switch (scaling) {
-			case kSounds_convolve_scaling_INTEGRAL: {
+			case kSounds_convolve_scaling::INTEGRAL: {
 				Vector_multiplyByScalar (him.get(), my dx / nfft);
 			} break;
-			case kSounds_convolve_scaling_SUM: {
+			case kSounds_convolve_scaling::SUM: {
 				Vector_multiplyByScalar (him.get(), 1.0 / nfft);
 			} break;
-			case kSounds_convolve_scaling_NORMALIZE: {
+			case kSounds_convolve_scaling::NORMALIZE: {
 				double normalizationFactor = Matrix_getNorm (me) * Matrix_getNorm (thee);
 				if (normalizationFactor != 0.0) {
 					Vector_multiplyByScalar (him.get(), 1.0 / nfft / normalizationFactor);
 				}
 			} break;
-			case kSounds_convolve_scaling_PEAK_099: {
+			case kSounds_convolve_scaling::PEAK_099: {
 				Vector_scale (him.get(), 0.99);
 			} break;
-			default: Melder_fatal (U"Sounds_convolve: unimplemented scaling ", scaling);
+			default: Melder_fatal (U"Sounds_convolve: unimplemented scaling ", (int) scaling);
 		}
 		return him;
 	} catch (MelderError) {
@@ -588,7 +585,7 @@ autoSound Sounds_convolve (Sound me, Sound thee, enum kSounds_convolve_scaling s
 	}
 }
 
-autoSound Sounds_crossCorrelate (Sound me, Sound thee, enum kSounds_convolve_scaling scaling, enum kSounds_convolve_signalOutsideTimeDomain signalOutsideTimeDomain) {
+autoSound Sounds_crossCorrelate (Sound me, Sound thee, kSounds_convolve_scaling scaling, kSounds_convolve_signalOutsideTimeDomain signalOutsideTimeDomain) {
 	try {
 		if (my ny > 1 && thy ny > 1 && my ny != thy ny)
 			Melder_throw (U"The numbers of channels of the two sounds have to be equal or 1.");
@@ -628,10 +625,10 @@ autoSound Sounds_crossCorrelate (Sound me, Sound thee, enum kSounds_convolve_sca
 			}
 		}
 		switch (signalOutsideTimeDomain) {
-			case kSounds_convolve_signalOutsideTimeDomain_ZERO: {
+			case kSounds_convolve_signalOutsideTimeDomain::ZERO: {
 				// do nothing
 			} break;
-			case kSounds_convolve_signalOutsideTimeDomain_SIMILAR: {
+			case kSounds_convolve_signalOutsideTimeDomain::SIMILAR: {
 				for (long channel = 1; channel <= numberOfChannels; channel ++) {
 					double *a = his z [channel];
 					double edge = n1 < n2 ? n1 : n2;
@@ -645,25 +642,25 @@ autoSound Sounds_crossCorrelate (Sound me, Sound thee, enum kSounds_convolve_sca
 			//case kSounds_convolve_signalOutsideTimeDomain_PERIODIC: {
 				// do nothing
 			//} break;
-			default: Melder_fatal (U"Sounds_crossCorrelate: unimplemented outside-time-domain strategy ", signalOutsideTimeDomain);
+			default: Melder_fatal (U"Sounds_crossCorrelate: unimplemented outside-time-domain strategy ", (int) signalOutsideTimeDomain);
 		}
 		switch (scaling) {
-			case kSounds_convolve_scaling_INTEGRAL: {
+			case kSounds_convolve_scaling::INTEGRAL: {
 				Vector_multiplyByScalar (him.get(), my dx / nfft);
 			} break;
-			case kSounds_convolve_scaling_SUM: {
+			case kSounds_convolve_scaling::SUM: {
 				Vector_multiplyByScalar (him.get(), 1.0 / nfft);
 			} break;
-			case kSounds_convolve_scaling_NORMALIZE: {
+			case kSounds_convolve_scaling::NORMALIZE: {
 				double normalizationFactor = Matrix_getNorm (me) * Matrix_getNorm (thee);
 				if (normalizationFactor != 0.0) {
 					Vector_multiplyByScalar (him.get(), 1.0 / nfft / normalizationFactor);
 				}
 			} break;
-			case kSounds_convolve_scaling_PEAK_099: {
+			case kSounds_convolve_scaling::PEAK_099: {
 				Vector_scale (him.get(), 0.99);
 			} break;
-			default: Melder_fatal (U"Sounds_crossCorrelate: unimplemented scaling ", scaling);
+			default: Melder_fatal (U"Sounds_crossCorrelate: unimplemented scaling ", (int) scaling);
 		}
 		return him;
 	} catch (MelderError) {
@@ -671,7 +668,7 @@ autoSound Sounds_crossCorrelate (Sound me, Sound thee, enum kSounds_convolve_sca
 	}
 }
 
-autoSound Sound_autoCorrelate (Sound me, enum kSounds_convolve_scaling scaling, enum kSounds_convolve_signalOutsideTimeDomain signalOutsideTimeDomain) {
+autoSound Sound_autoCorrelate (Sound me, kSounds_convolve_scaling scaling, kSounds_convolve_signalOutsideTimeDomain signalOutsideTimeDomain) {
 	try {
 		long numberOfChannels = my ny, n1 = my nx, n2 = n1 + n1 - 1, nfft = 1;
 		while (nfft < n2) nfft *= 2;
@@ -699,10 +696,10 @@ autoSound Sound_autoCorrelate (Sound me, enum kSounds_convolve_scaling scaling,
 			}
 		}
 		switch (signalOutsideTimeDomain) {
-			case kSounds_convolve_signalOutsideTimeDomain_ZERO: {
+			case kSounds_convolve_signalOutsideTimeDomain::ZERO: {
 				// do nothing
 			} break;
-			case kSounds_convolve_signalOutsideTimeDomain_SIMILAR: {
+			case kSounds_convolve_signalOutsideTimeDomain::SIMILAR: {
 				for (long channel = 1; channel <= numberOfChannels; channel ++) {
 					double *a = thy z [channel];
 					double edge = n1;
@@ -716,25 +713,25 @@ autoSound Sound_autoCorrelate (Sound me, enum kSounds_convolve_scaling scaling,
 			//case kSounds_convolve_signalOutsideTimeDomain_PERIODIC: {
 				// do nothing
 			//} break;
-			default: Melder_fatal (U"Sounds_autoCorrelate: unimplemented outside-time-domain strategy ", signalOutsideTimeDomain);
+			default: Melder_fatal (U"Sounds_autoCorrelate: unimplemented outside-time-domain strategy ", (int) signalOutsideTimeDomain);
 		}
 		switch (scaling) {
-			case kSounds_convolve_scaling_INTEGRAL: {
+			case kSounds_convolve_scaling::INTEGRAL: {
 				Vector_multiplyByScalar (thee.get(), my dx / nfft);
 			} break;
-			case kSounds_convolve_scaling_SUM: {
+			case kSounds_convolve_scaling::SUM: {
 				Vector_multiplyByScalar (thee.get(), 1.0 / nfft);
 			} break;
-			case kSounds_convolve_scaling_NORMALIZE: {
+			case kSounds_convolve_scaling::NORMALIZE: {
 				double normalizationFactor = Matrix_getNorm (me) * Matrix_getNorm (me);
 				if (normalizationFactor != 0.0) {
 					Vector_multiplyByScalar (thee.get(), 1.0 / nfft / normalizationFactor);
 				}
 			} break;
-			case kSounds_convolve_scaling_PEAK_099: {
+			case kSounds_convolve_scaling::PEAK_099: {
 				Vector_scale (thee.get(), 0.99);
 			} break;
-			default: Melder_fatal (U"Sounds_autoCorrelate: unimplemented scaling ", scaling);
+			default: Melder_fatal (U"Sounds_autoCorrelate: unimplemented scaling ", (int) scaling);
 		}
 		return thee;
 	} catch (MelderError) {
@@ -745,23 +742,23 @@ autoSound Sound_autoCorrelate (Sound me, enum kSounds_convolve_scaling scaling,
 void Sound_draw (Sound me, Graphics g,
 	double tmin, double tmax, double minimum, double maximum, bool garnish, const char32 *method)
 {
-	long ixmin, ixmax;
 	bool treversed = tmin > tmax;
 	if (treversed) { double temp = tmin; tmin = tmax; tmax = temp; }
 	/*
-	 * Automatic domain.
-	 */
+		Automatic domain.
+	*/
 	if (tmin == tmax) {
 		tmin = my xmin;
 		tmax = my xmax;
 	}
 	/*
-	 * Domain expressed in sample numbers.
-	 */
+		Domain expressed in sample numbers.
+	*/
+	integer ixmin, ixmax;
 	Matrix_getWindowSamplesX (me, tmin, tmax, & ixmin, & ixmax);
 	/*
-	 * Automatic vertical range.
-	 */
+		Automatic vertical range.
+	*/
 	if (minimum == maximum) {
 		Matrix_getWindowExtrema (me, ixmin, ixmax, 1, my ny, & minimum, & maximum);
 		if (minimum == maximum) {
@@ -770,8 +767,8 @@ void Sound_draw (Sound me, Graphics g,
 		}
 	}
 	/*
-	 * Set coordinates for drawing.
-	 */
+		Set coordinates for drawing.
+	*/
 	Graphics_setInner (g);
 	for (long channel = 1; channel <= my ny; channel ++) {
 		Graphics_setWindow (g, treversed ? tmax : tmin, treversed ? tmin : tmax,
@@ -852,7 +849,7 @@ double Sound_getNearestZeroCrossing (Sound me, double position, long channel) {
 		return interpolate (me, leftSample, channel);
 	}
 	/* Search to the left. */
-	if (leftSample > my nx) return NUMundefined;
+	if (leftSample > my nx) return undefined;
 	for (ileft = leftSample - 1; ileft >= 1; ileft --)
 		if ((amplitude [ileft] >= 0.0) != (amplitude [ileft + 1] >= 0.0))
 		{
@@ -860,14 +857,14 @@ double Sound_getNearestZeroCrossing (Sound me, double position, long channel) {
 			break;
 		}
 	/* Search to the right. */
-	if (rightSample < 1) return NUMundefined;
+	if (rightSample < 1) return undefined;
 	for (iright = rightSample + 1; iright <= my nx; iright ++)
 		if ((amplitude [iright] >= 0.0) != (amplitude [iright - 1] >= 0.0))
 		{
 			rightZero = interpolate (me, iright - 1, channel);
 			break;
 		}
-	if (ileft < 1 && iright > my nx) return NUMundefined;
+	if (ileft < 1 && iright > my nx) return undefined;
 	return ileft < 1 ? rightZero : iright > my nx ? leftZero :
 		position - leftZero < rightZero - position ? leftZero : rightZero;
 }
@@ -881,11 +878,11 @@ void Sound_setZero (Sound me, double tmin_in, double tmax_in, bool roundTimesToN
 			if (tmin > my xmin) tmin = Sound_getNearestZeroCrossing (me, tmin_in, channel);
 			if (tmax < my xmax) tmax = Sound_getNearestZeroCrossing (me, tmax_in, channel);
 		}
-		if (tmin == NUMundefined) tmin = my xmin;
-		if (tmax == NUMundefined) tmax = my xmax;
-		long imin, imax;
+		if (isundef (tmin)) tmin = my xmin;
+		if (isundef (tmax)) tmax = my xmax;
+		integer imin, imax;
 		Sampled_getWindowSamples (me, tmin, tmax, & imin, & imax);
-		for (long i = imin; i <= imax; i ++) {
+		for (integer i = imin; i <= imax; i ++) {
 			my z [channel] [i] = 0.0;
 		}
 	}
@@ -900,7 +897,7 @@ autoSound Sound_createAsPureTone (long numberOfChannels, double startingTime, do
 			Melder_throw (U"Cannot create sounds with more than ", Melder_bigInteger (INT32_MAX), U" samples, because they cannot be saved to disk.");
 		autoSound me = Sound_create (numberOfChannels, startingTime, endTime, (long) numberOfSamples_f,
 			1.0 / sampleRate, startingTime + 0.5 / sampleRate);
-		for (long isamp = 1; isamp <= my nx; isamp ++) {
+		for (integer isamp = 1; isamp <= my nx; isamp ++) {
 			double time = my x1 + (isamp - 1) * my dx;
 			double value = amplitude * sin (NUM2pi * frequency * time);
 			double timeFromStart = time - startingTime;
@@ -950,14 +947,14 @@ autoSound Sound_createAsToneComplex (double startTime, double endTime, double sa
 		autoSound me = Sound_create (1, startTime, endTime, lround ((endTime - startTime) * samplingFrequency),
 			1.0 / samplingFrequency, startTime + 0.5 / samplingFrequency);
 		double *amplitude = my z [1];
-		for (long isamp = 1; isamp <= my nx; isamp ++) {
+		for (integer isamp = 1; isamp <= my nx; isamp ++) {
 			double value = 0.0, t = Sampled_indexToX (me.get(), isamp);
 			double omegaStepT = omegaStep * t, firstOmegaT = firstOmega * t;
 			if (phase == Sound_TONE_COMPLEX_SINE) {
-				for (long icomp = 1; icomp <= numberOfComponents; icomp ++)
+				for (integer icomp = 1; icomp <= numberOfComponents; icomp ++)
 					value += sin (firstOmegaT + (icomp - 1) * omegaStepT);
 			} else {
-				for (long icomp = 1; icomp <= numberOfComponents; icomp ++)
+				for (integer icomp = 1; icomp <= numberOfComponents; icomp ++)
 					value += cos (firstOmegaT + (icomp - 1) * omegaStepT);
 			}
 			amplitude [isamp] = value * factor;
@@ -968,79 +965,66 @@ autoSound Sound_createAsToneComplex (double startTime, double endTime, double sa
 	}
 }
 
-void Sound_multiplyByWindow (Sound me, enum kSound_windowShape windowShape) {
+void Sound_multiplyByWindow (Sound me, kSound_windowShape windowShape) {
 	for (long channel = 1; channel <= my ny; channel ++) {
-		long i, n = my nx;
+		integer n = my nx;
 		double *amp = my z [channel];
-		double imid, edge, onebyedge1, factor;
 		switch (windowShape) {
-			case kSound_windowShape_RECTANGULAR:
+			case kSound_windowShape::RECTANGULAR: {
 				;
-			break;
-			case kSound_windowShape_TRIANGULAR:   /* "Bartlett" */
-				for (i = 1; i <= n; i ++) { double phase = (double) i / n;   /* 0..1 */
+			} break; case kSound_windowShape::TRIANGULAR: {   // "Bartlett"
+				for (integer i = 1; i <= n; i ++) { double phase = (double) i / n;   // 0..1
 					amp [i] *= 1.0 - fabs ((2.0 * phase - 1.0)); }
-			break;
-			case kSound_windowShape_PARABOLIC:   /* "Welch" */
-				for (i = 1; i <= n; i ++) { double phase = (double) i / n;
+			} break; case kSound_windowShape::PARABOLIC: {   // "Welch"
+				for (integer i = 1; i <= n; i ++) { double phase = (double) i / n;
 					amp [i] *= 1.0 - (2.0 * phase - 1.0) * (2.0 * phase - 1.0); }
-			break;
-			case kSound_windowShape_HANNING:
-				for (i = 1; i <= n; i ++) { double phase = (double) i / n;
+			} break; case kSound_windowShape::HANNING: {
+				for (integer i = 1; i <= n; i ++) { double phase = (double) i / n;
 					amp [i] *= 0.5 * (1.0 - cos (2.0 * NUMpi * phase)); }
-			break;
-			case kSound_windowShape_HAMMING:
-				for (i = 1; i <= n; i ++) { double phase = (double) i / n;
+			} break; case kSound_windowShape::HAMMING: {
+				for (integer i = 1; i <= n; i ++) { double phase = (double) i / n;
 					amp [i] *= 0.54 - 0.46 * cos (2.0 * NUMpi * phase); }
-			break;
-			case kSound_windowShape_GAUSSIAN_1:
-				imid = 0.5 * (n + 1), edge = exp (-3.0), onebyedge1 = 1 / (1.0 - edge);   /* -0.5..+0.5 */
-				for (i = 1; i <= n; i ++) { double phase = ((double) i - imid) / n;
+			} break; case kSound_windowShape::GAUSSIAN_1: {
+				real imid = 0.5 * (n + 1), edge = exp (-3.0), onebyedge1 = 1.0 / (1.0 - edge);   // -0.5..+0.5
+				for (integer i = 1; i <= n; i ++) { double phase = ((double) i - imid) / n;
 					amp [i] *= (exp (-12.0 * phase * phase) - edge) * onebyedge1; }
-			break;
-			case kSound_windowShape_GAUSSIAN_2:
-				imid = 0.5 * (double) (n + 1), edge = exp (-12.0), onebyedge1 = 1 / (1.0 - edge);
-				for (i = 1; i <= n; i ++) { double phase = ((double) i - imid) / n;
+			} break; case kSound_windowShape::GAUSSIAN_2: {
+				real imid = 0.5 * (double) (n + 1), edge = exp (-12.0), onebyedge1 = 1.0 / (1.0 - edge);
+				for (integer i = 1; i <= n; i ++) { double phase = ((double) i - imid) / n;
 					amp [i] *= (exp (-48.0 * phase * phase) - edge) * onebyedge1; }
-			break;
-			case kSound_windowShape_GAUSSIAN_3:
-				imid = 0.5 * (double) (n + 1), edge = exp (-27.0), onebyedge1 = 1 / (1.0 - edge);
-				for (i = 1; i <= n; i ++) { double phase = ((double) i - imid) / n;
+			} break; case kSound_windowShape::GAUSSIAN_3: {
+				real imid = 0.5 * (double) (n + 1), edge = exp (-27.0), onebyedge1 = 1.0 / (1.0 - edge);
+				for (integer i = 1; i <= n; i ++) { double phase = ((double) i - imid) / n;
 					amp [i] *= (exp (-108.0 * phase * phase) - edge) * onebyedge1; }
-			break;
-			case kSound_windowShape_GAUSSIAN_4:
-				imid = 0.5 * (double) (n + 1), edge = exp (-48.0), onebyedge1 = 1 / (1.0 - edge);
-				for (i = 1; i <= n; i ++) { double phase = ((double) i - imid) / n;
+			} break; case kSound_windowShape::GAUSSIAN_4: {
+				real imid = 0.5 * (double) (n + 1), edge = exp (-48.0), onebyedge1 = 1.0 / (1.0 - edge);
+				for (integer i = 1; i <= n; i ++) { double phase = ((double) i - imid) / n;
 					amp [i] *= (exp (-192.0 * phase * phase) - edge) * onebyedge1; }
-			break;
-			case kSound_windowShape_GAUSSIAN_5:
-				imid = 0.5 * (double) (n + 1), edge = exp (-75.0), onebyedge1 = 1 / (1.0 - edge);
-				for (i = 1; i <= n; i ++) { double phase = ((double) i - imid) / n;
+			} break; case kSound_windowShape::GAUSSIAN_5: {
+				real imid = 0.5 * (double) (n + 1), edge = exp (-75.0), onebyedge1 = 1.0 / (1.0 - edge);
+				for (integer i = 1; i <= n; i ++) { double phase = ((double) i - imid) / n;
 					amp [i] *= (exp (-300.0 * phase * phase) - edge) * onebyedge1; }
-			break;
-			case kSound_windowShape_KAISER_1:
-				imid = 0.5 * (double) (n + 1);
-				factor = 1 / NUMbessel_i0_f (2 * NUMpi);
-				for (i = 1; i <= n; i ++) { double phase = 2 * ((double) i - imid) / n;   /* -1..+1 */
-					double root = 1 - phase * phase;
-					amp [i] *= root <= 0.0 ? 0.0 : factor * NUMbessel_i0_f (2 * NUMpi * sqrt (root)); }
-			break;
-			case kSound_windowShape_KAISER_2:
-				imid = 0.5 * (double) (n + 1);
-				factor = 1 / NUMbessel_i0_f (2 * NUMpi * NUMpi + 0.5);
-				for (i = 1; i <= n; i ++) { double phase = 2 * ((double) i - imid) / n;   /* -1..+1 */
-					double root = 1 - phase * phase;
-					amp [i] *= root <= 0.0 ? 0.0 : factor * NUMbessel_i0_f ((2 * NUMpi * NUMpi + 0.5) * sqrt (root)); }
-			break;
-			default:
-			break;
+			} break; case kSound_windowShape::KAISER_1: {
+				real imid = 0.5 * (double) (n + 1);
+				real factor = 1.0 / NUMbessel_i0_f (2 * NUMpi);
+				for (integer i = 1; i <= n; i ++) { double phase = 2.0 * ((double) i - imid) / n;   // -1..+1
+					double root = 1.0 - phase * phase;
+					amp [i] *= root <= 0.0 ? 0.0 : factor * NUMbessel_i0_f (2.0 * NUMpi * sqrt (root)); }
+			} break; case kSound_windowShape::KAISER_2: {
+				real imid = 0.5 * (double) (n + 1);
+				real factor = 1.0 / NUMbessel_i0_f (2 * NUMpi * NUMpi + 0.5);
+				for (integer i = 1; i <= n; i ++) { double phase = 2.0 * ((double) i - imid) / n;   // -1..+1
+					double root = 1.0 - phase * phase;
+					amp [i] *= root <= 0.0 ? 0.0 : factor * NUMbessel_i0_f ((2.0 * NUMpi * NUMpi + 0.5) * sqrt (root)); }
+			} break; default: {
+			}
 		}
 	}
 }
 
 void Sound_scaleIntensity (Sound me, double newAverageIntensity) {
 	double currentIntensity = Sound_getIntensity_dB (me), factor;
-	if (currentIntensity == NUMundefined) return;
+	if (isundef (currentIntensity)) return;
 	factor = pow (10, (newAverageIntensity - currentIntensity) / 20.0);
 	for (long channel = 1; channel <= my ny; channel ++) {
 		for (long i = 1; i <= my nx; i ++) {
@@ -1055,7 +1039,7 @@ void Sound_overrideSamplingFrequency (Sound me, double rate) {
 	my xmax = my xmin + my nx * my dx;
 }
 
-autoSound Sound_extractPart (Sound me, double t1, double t2, enum kSound_windowShape windowShape, double relativeWidth, bool preserveTimes) {
+autoSound Sound_extractPart (Sound me, double t1, double t2, kSound_windowShape windowShape, double relativeWidth, bool preserveTimes) {
 	try {
 		/*
 		 * We do not clip to the Sound's time domain.
@@ -1144,10 +1128,10 @@ void Sound_filterWithFormants (Sound me, double tmin, double tmax,
 	int numberOfFormants, double formant [], double bandwidth [])
 {
 	try {
-		for (long channel = 1; channel <= my ny; channel ++) {
+		for (integer channel = 1; channel <= my ny; channel ++) {
 			if (tmax <= tmin) { tmin = my xmin; tmax = my xmax; }   // autowindowing
-			long itmin, itmax;
-			long n = Sampled_getWindowSamples (me, tmin, tmax, & itmin, & itmax);
+			integer itmin, itmax;
+			integer n = Sampled_getWindowSamples (me, tmin, tmax, & itmin, & itmax);
 			if (n <= 2)
 				Melder_throw (U"Sound too short.");
 			double *amplitude = my z [channel] + itmin - 1;   // base 1
@@ -1203,11 +1187,11 @@ autoSound Sound_filter_deemphasis (Sound me, double frequency) {
 
 void Sound_reverse (Sound me, double tmin, double tmax) {
 	if (tmax <= tmin) { tmin = my xmin; tmax = my xmax; }   // autowindowing
-	long itmin, itmax;
-	long n = Sampled_getWindowSamples (me, tmin, tmax, & itmin, & itmax) / 2;
+	integer itmin, itmax;
+	integer n = Sampled_getWindowSamples (me, tmin, tmax, & itmin, & itmax) / 2;
 	for (long channel = 1; channel <= my ny; channel ++) {
 		double *amp = my z [channel];
-		for (long i = 0; i < n; i ++) {
+		for (integer i = 0; i < n; i ++) {
 			double dummy = amp [itmin + i];
 			amp [itmin + i] = amp [itmax - i];
 			amp [itmax - i] = dummy;
@@ -1215,7 +1199,7 @@ void Sound_reverse (Sound me, double tmin, double tmax) {
 	}
 }
 
-autoSound Sounds_crossCorrelate_short (Sound me, Sound thee, double tmin, double tmax, int normalize) {
+autoSound Sounds_crossCorrelate_short (Sound me, Sound thee, double tmin, double tmax, bool normalize) {
 	try {
 		if (my dx != thy dx)
 			Melder_throw (U"Sampling frequencies are not equal.");
@@ -1224,15 +1208,15 @@ autoSound Sounds_crossCorrelate_short (Sound me, Sound thee, double tmin, double
 		double dt = my dx;
 		double dphase = (thy x1 - my x1) / dt;
 		dphase -= floor (dphase);   // a number between 0 and 1
-		long i1 = (long) ceil (tmin / dt - dphase);   // index of first sample if sample at dphase has index 0
-		long i2 = (long) floor (tmax / dt - dphase);   // index of last sample if sample at dphase has index 0
-		long nt = i2 - i1 + 1;
+		integer i1 = (integer) ceil (tmin / dt - dphase);   // index of first sample if sample at dphase has index 0
+		integer i2 = (integer) floor (tmax / dt - dphase);   // index of last sample if sample at dphase has index 0
+		integer nt = i2 - i1 + 1;
 		if (nt < 1)
 			Melder_throw (U"Window too small.");
 		double t1 = (dphase + i1) * dt;
 		autoSound him = Sound_create (1, tmin, tmax, nt, dt, t1);
-		for (long i = 1; i <= nt; i ++) {
-			long di = i - 1 + i1;
+		for (integer i = 1; i <= nt; i ++) {
+			integer di = i - 1 + i1;
 			for (long ime = 1; ime <= my nx; ime ++) {
 				if (ime + di < 1) continue;
 				if (ime + di > thy nx) break;
@@ -1243,25 +1227,25 @@ autoSound Sounds_crossCorrelate_short (Sound me, Sound thee, double tmin, double
 		}
 		if (normalize) {
 			double mypower = 0.0, thypower = 0.0;
-			for (long channel = 1; channel <= my ny; channel ++) {
-				for (long i = 1; i <= my nx; i ++) {
+			for (integer channel = 1; channel <= my ny; channel ++) {
+				for (integer i = 1; i <= my nx; i ++) {
 					double value = my z [channel] [i];
 					mypower += value * value;
 				}
-				for (long i = 1; i <= thy nx; i ++) {
+				for (integer i = 1; i <= thy nx; i ++) {
 					double value = thy z [channel] [i];
 					thypower += value * value;
 				}
 			}
 			if (mypower != 0.0 && thypower != 0.0) {
 				double factor = 1.0 / (sqrt (mypower) * sqrt (thypower));
-				for (long i = 1; i <= nt; i ++) {
+				for (integer i = 1; i <= nt; i ++) {
 					his z [1] [i] *= factor;
 				}
 			}
 		} else {
 			double factor = dt / my ny;
-			for (long i = 1; i <= nt; i ++) {
+			for (integer i = 1; i <= nt; i ++) {
 				his z [1] [i] *= factor;
 			}
 		}
