@@ -291,7 +291,7 @@ static void showMeter (SoundRecorder me, short *buffer, long nsamp) {
 		Graphics_text (my graphics.get(), 0.5, 0.5, U"Not recording.");
 		return;
 	}
-	if (my p_meter_which == kSoundRecorder_meter_INTENSITY) {
+	if (my p_meter_which == kSoundRecorder_meter::INTENSITY) {
 		int leftMaximum = 0, rightMaximum = 0;
 		if (my numberOfChannels == 1) {
 			for (long i = 0; i < nsamp; i ++) {
@@ -319,7 +319,7 @@ static void showMeter (SoundRecorder me, short *buffer, long nsamp) {
 			showMaximum (me, 2, rightMaximum);
 			my lastRightMaximum = rightMaximum;
 		}
-	} else if (my p_meter_which == kSoundRecorder_meter_CENTRE_OF_GRAVITY_VERSUS_INTENSITY) {
+	} else if (my p_meter_which == kSoundRecorder_meter::CENTRE_OF_GRAVITY_VERSUS_INTENSITY) {
 		autoSound sound = Sound_create (my numberOfChannels,
 			0.0, nsamp / theControlPanel. sampleRate,
 			nsamp, 1.0 / theControlPanel. sampleRate, 0.5 / theControlPanel. sampleRate);
@@ -329,7 +329,7 @@ static void showMeter (SoundRecorder me, short *buffer, long nsamp) {
 				sound -> z [ichan] [isamp] = * (p ++) / 32768.0;
 			}
 		}
-		Sound_multiplyByWindow (sound.get(), kSound_windowShape_KAISER_2);
+		Sound_multiplyByWindow (sound.get(), kSound_windowShape::KAISER_2);
 		double intensity = Sound_getIntensity_dB (sound.get());
 		autoSpectrum spectrum = Sound_to_Spectrum (sound.get(), true);
 		double centreOfGravity = Spectrum_getCentreOfGravity (spectrum.get(), 1.0);
@@ -535,13 +535,13 @@ static void gui_button_cb_record (SoundRecorder me, GuiButtonEvent /* event */)
 		my lastRightMaximum = 0;
 		if (! my synchronous) {
 			if (my inputUsesPortAudio) {
-				PaStreamParameters streamParameters = { 0 };
+				PaStreamParameters streamParameters = { };
 				streamParameters. device = my deviceIndices [theControlPanel. inputSource];
 				streamParameters. channelCount = my numberOfChannels;
 				streamParameters. sampleFormat = paInt16;
 				streamParameters. suggestedLatency = my deviceInfos [theControlPanel. inputSource] -> defaultLowInputLatency;
 				#if defined (macintosh)
-					PaMacCoreStreamInfo macCoreStreamInfo = { 0 };
+					PaMacCoreStreamInfo macCoreStreamInfo = { };
 					macCoreStreamInfo. size = sizeof (PaMacCoreStreamInfo);
 					macCoreStreamInfo. hostApiType = paCoreAudio;
 					macCoreStreamInfo. version = 0x01;
@@ -741,11 +741,11 @@ static void gui_radiobutton_cb_input (SoundRecorder me, GuiRadioButtonEvent even
 static void gui_radiobutton_cb_fsamp (SoundRecorder me, GuiRadioButtonEvent event) {
 	if (my recording) return;
 	try {
-		double fsamp = NUMundefined;
+		double fsamp = undefined;
 		for (long i = 1; i <= SoundRecorder_IFSAMP_MAX; i ++)
 			if (event -> toggle == my fsamps [i]. button)
 				fsamp = my fsamps [i]. fsamp;
-		Melder_assert (NUMdefined (fsamp));
+		Melder_assert (isdefined (fsamp));
 		/*
 		 * If we push the 48000 button while the sampling frequency is 22050,
 		 * we first get a message that the 22050 button has changed,
@@ -888,13 +888,13 @@ void structSoundRecorder :: v_createChildren ()
 static void writeFakeMonoFile (SoundRecorder me, MelderFile file, int audioFileType) {
 	long nsamp = my nsamp / 2;
 	autoMelderFile mfile = MelderFile_create (file);
-	MelderFile_writeAudioFileHeader (file, audioFileType, theControlPanel. sampleRate, nsamp, 1, 16);
+	MelderFile_writeAudioFileHeader (file, audioFileType, lround (theControlPanel. sampleRate), nsamp, 1, 16);
 	if (Melder_defaultAudioFileEncoding (audioFileType, 16) == Melder_LINEAR_16_BIG_ENDIAN) {
 		for (long i = 0; i < nsamp; i ++)
-			binputi2 ((my buffer [i + i - 2] + my buffer [i + i - 1]) / 2, file -> filePointer);
+			binputi16 ((my buffer [i + i - 2] + my buffer [i + i - 1]) / 2, file -> filePointer);
 	} else {
 		for (long i = 0; i < nsamp; i ++)
-			binputi2LE ((my buffer [i + i - 2] + my buffer [i + i - 1]) / 2, file -> filePointer);
+			binputi16LE ((my buffer [i + i - 2] + my buffer [i + i - 1]) / 2, file -> filePointer);
 	}
 	MelderFile_writeAudioFileTrailer (file, audioFileType, lround (theControlPanel. sampleRate), nsamp, 1, 16);
 	mfile.close ();
@@ -954,17 +954,17 @@ static void menu_cb_writeNist (SoundRecorder me, EDITOR_ARGS_FORM) {
 
 static void updateMenus (SoundRecorder me) {
 	GuiMenuItem_check (my meterIntensityButton,
-		my p_meter_which == kSoundRecorder_meter_INTENSITY);
+		my p_meter_which == kSoundRecorder_meter::INTENSITY);
 	GuiMenuItem_check (my meterCentreOfGravityVersusIntensityButton,
-		my p_meter_which == kSoundRecorder_meter_CENTRE_OF_GRAVITY_VERSUS_INTENSITY);
+		my p_meter_which == kSoundRecorder_meter::CENTRE_OF_GRAVITY_VERSUS_INTENSITY);
 }
 
 static void menu_cb_intensity (SoundRecorder me, EDITOR_ARGS_DIRECT) {
-	my pref_meter_which () = my p_meter_which = kSoundRecorder_meter_INTENSITY;
+	my pref_meter_which () = my p_meter_which = kSoundRecorder_meter::INTENSITY;
 	updateMenus (me);
 }
 static void menu_cb_centreOfGravityVersusIntensity (SoundRecorder me, EDITOR_ARGS_DIRECT) {
-	my pref_meter_which () = my p_meter_which = kSoundRecorder_meter_CENTRE_OF_GRAVITY_VERSUS_INTENSITY;
+	my pref_meter_which () = my p_meter_which = kSoundRecorder_meter::CENTRE_OF_GRAVITY_VERSUS_INTENSITY;
 	updateMenus (me);
 }
 
@@ -994,11 +994,11 @@ autoSoundRecorder SoundRecorder_create (int numberOfChannels) {
 		autoSoundRecorder me = Thing_new (SoundRecorder);
 		my inputUsesPortAudio =
 			#if defined (_WIN32)
-				MelderAudio_getInputSoundSystem () == kMelder_inputSoundSystem_MME_VIA_PORTAUDIO;
+				MelderAudio_getInputSoundSystem () == kMelder_inputSoundSystem::MME_VIA_PORTAUDIO;
 			#elif defined (macintosh)
-				MelderAudio_getInputSoundSystem () == kMelder_inputSoundSystem_COREAUDIO_VIA_PORTAUDIO;
+				MelderAudio_getInputSoundSystem () == kMelder_inputSoundSystem::COREAUDIO_VIA_PORTAUDIO;
 			#else
-				MelderAudio_getInputSoundSystem () == kMelder_inputSoundSystem_ALSA_VIA_PORTAUDIO;
+				MelderAudio_getInputSoundSystem () == kMelder_inputSoundSystem::ALSA_VIA_PORTAUDIO;
 			#endif
 
 		if (my inputUsesPortAudio) {
