@@ -1,6 +1,6 @@
 /* Sound_files.cpp
  *
- * Copyright (C) 1992-2011,2012,2014,2015,2016 Paul Boersma & David Weenink
+ * Copyright (C) 1992-2011,2012,2014,2015,2016,2017 Paul Boersma & David Weenink
  *
  * This code is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -71,7 +71,7 @@ autoSound Sound_readFromSoundFile (MelderFile file) {
 		int numberOfChannels, encoding;
 		double sampleRate;
 		long startOfData;
-		int32 numberOfSamples;
+		integer numberOfSamples;
 		int fileType = MelderFile_checkSoundFile (file, & numberOfChannels, & encoding, & sampleRate, & startOfData, & numberOfSamples);
 		if (fileType == 0)
 			Melder_throw (U"Not an audio file.");
@@ -95,7 +95,7 @@ autoSound Sound_readFromSesamFile (MelderFile file) {
 		autofile f = Melder_fopen (file, "rb");
 		int32_t header [1 + 128];
 		for (long i = 1; i <= 128; i ++)
-			header [i] = bingeti4LE (f);
+			header [i] = bingeti32LE (f);
 		/*
 		 * Try SESAM header.
 		 */
@@ -112,7 +112,7 @@ autoSound Sound_readFromSesamFile (MelderFile file) {
 			Melder_throw (U"Not a correct SESAM or LVS file.");
 		autoSound me = Sound_createSimple (1, numberOfSamples / samplingFrequency, samplingFrequency);
 		for (int32_t i = 1; i <= numberOfSamples; i ++) {
-			my z [1] [i] = (double) bingeti2LE (f) * (1.0 / 2048);   // 12 bits
+			my z [1] [i] = (double) bingeti16LE (f) * (1.0 / 2048);   // 12 bits
 		}
 		f.close (file);
 		return me;
@@ -177,7 +177,7 @@ autoSound Sound_readFromBellLabsFile (MelderFile file) {
 		 */
 		fseek (f, tagLength + headerLength, SEEK_SET);
 		for (unsigned long i = 1; i <= numberOfSamples; i ++)
-			my z [1] [i] = (double) bingeti2 (f) * (1.0 / 32768);   // 16-bits big-endian
+			my z [1] [i] = (double) bingeti16 (f) * (1.0 / 32768);   // 16-bits big-endian
 
 		f.close (file);
 		return me;
@@ -206,17 +206,17 @@ autoSound Sound_readFromKayFile (MelderFile file) {
 		if (fread (data, 1, 4, f) < 4) readError ();
 		if (! strnequ (data, "HEDR", 4) && ! strnequ (data, "HDR8", 4))
 			Melder_throw (U"Missing HEDR or HDR8 chunk. Please report to paul.boersma@uva.nl.");
-		uint32_t chunkSize = bingetu4LE (f);
+		uint32_t chunkSize = bingetu32LE (f);
 		if (chunkSize & 1) ++ chunkSize;
 		if (chunkSize != 32 && chunkSize != 44)
-			Melder_throw (U"Unknown chunk size %ld. Please report to paul.boersma@uva.nl.", chunkSize);
+			Melder_throw (U"Unknown chunk size ", chunkSize, U". Please report to paul.boersma@uva.nl.");
 		if (fread (data, 1, 20, f) < 20) readError ();
-		double samplingFrequency = bingetu4LE (f);   // converting up (from 32 to 53 bits)
-		uint32_t numberOfSamples = bingetu4LE (f);
+		double samplingFrequency = bingetu32LE (f);   // converting up (from 32 to 53 bits)
+		uint32_t numberOfSamples = bingetu32LE (f);
 		if (samplingFrequency <= 0 || samplingFrequency > 1e7 || numberOfSamples >= 1000000000)
 			Melder_throw (U"Not a correct Kay file.");
-		int16_t tmp1 = bingeti2LE (f);
-		int16_t tmp2 = bingeti2LE (f);
+		int16_t tmp1 = bingeti16LE (f);
+		int16_t tmp2 = bingeti16LE (f);
 		long numberOfChannels = tmp1 == -1 || tmp2 == -1 ? 1 : 2;
 		if (chunkSize == 44)
 			if (fread (data, 1, 12, f) < 12) readError ();
@@ -227,19 +227,19 @@ autoSound Sound_readFromKayFile (MelderFile file) {
 		while (! strnequ (data, "SDA_", 4) && ! strnequ (data, "SD_B", 4)) {
 			if (feof ((FILE *) f))
 				Melder_throw (U"Missing or unreadable SD chunk. Please report to paul.boersma@uva.nl.");
-			chunkSize = bingetu4LE (f);
+			chunkSize = bingetu32LE (f);
 			if (chunkSize & 1) ++ chunkSize;
 			if (fread (data, 1, chunkSize, f) < chunkSize) readError ();
 			if (fread (data, 1, 4, f) < 4) readError ();
 		}
-		chunkSize = bingetu4LE (f);
+		chunkSize = bingetu32LE (f);
 		if (chunkSize != numberOfSamples * 2)
 			Melder_throw (U"Incomplete SD chunk. Please report to paul.boersma@uva.nl.");
 
 		autoSound me = Sound_createSimple (numberOfChannels, numberOfSamples / samplingFrequency, samplingFrequency);
 		for (long ichan = 1; ichan <= numberOfChannels; ichan ++) {
 			for (unsigned long i = 1; i <= numberOfSamples; i ++) {
-				my z [ichan] [i] = (double) bingeti2LE (f) / 32768.0;
+				my z [ichan] [i] = (double) bingeti16LE (f) / 32768.0;
 			}
 		}
 		f.close (file);
@@ -288,18 +288,18 @@ void Sound_saveAsSesamFile (Sound me, MelderFile file) {
 		/* LVS header. */
 			header [62] = lround (1 / my dx);   // sampling frequency, rounded to n Hz
 			header [63] = -32000;   // magic: "sampled signal"
-			header [66] = 2047;   // maximum absolute value: 12 bits
+			header [66] = INT12_MAX;   // maximum absolute value: 12 bits
 			header [67] = 2047;   // LVS magic
 			header [68] = my nx % 256;   // number of samples in last block
 			header [69] = 1;   // ?
 		/* Sesam header. */
 			header [126] = lround (1 / my dx);   // sampling frequency, rounded to n Hz
 			header [127] = my nx;   // number of samples
-		for (long i = 1; i <= 128; i ++) binputi4LE (header [i], f);
-		for (long i = 1; i <= my nx; i ++) binputi2LE (lround (my z [1] [i] * 2048), f);
+		for (long i = 1; i <= 128; i ++) binputi32LE (header [i], f);
+		for (long i = 1; i <= my nx; i ++) binputi16LE (lround (my z [1] [i] * 2048), f);
 		tail = 256 - my nx % 256;
 		if (tail == 256) tail = 0;
-		for (long i = 1; i <= tail; i ++) binputi2LE (0, f);   // pad last block with zeroes
+		for (long i = 1; i <= tail; i ++) binputi16LE (0, f);   // pad last block with zeroes
 		f.close (file);
 	} catch (MelderError) {
 		Melder_throw (me, U": not written to Sesam file ", file, U".");
@@ -312,26 +312,26 @@ void Sound_saveAsKayFile (Sound me, MelderFile file) {
 
 		/* Form Chunk: contains all other chunks. */
 		fwrite ("FORMDS16", 1, 8, file -> filePointer);
-		binputi4LE (48 + my nx * 2, file -> filePointer);   // size of Form Chunk
+		binputi32LE (48 + my nx * 2, file -> filePointer);   // size of Form Chunk
 		fwrite ("HEDR", 1, 4, file -> filePointer);
-		binputi4LE (32, file -> filePointer);
+		binputi32LE (32, file -> filePointer);
 
 		char date [100];
 		time_t today = time (nullptr);
 		strcpy (date, ctime (& today));	
 		fwrite (date+4, 1, 20, file -> filePointer);   // skip weekday
 
-		binputi4LE (lround (1 / my dx), file -> filePointer);   // sampling frequency
-		binputi4LE (my nx, file -> filePointer);   // number of samples
+		binputi32LE (lround (1 / my dx), file -> filePointer);   // sampling frequency
+		binputi32LE (my nx, file -> filePointer);   // number of samples
 		int maximumA = 0;
 		for (long i = 1; i <= my nx; i ++) {
 			long value = lround (my z [1] [i] * 32768);
 			if (value < - maximumA) maximumA = - value;
 			if (value > maximumA) maximumA = value;
 		}
-		binputi2LE (maximumA, file -> filePointer);   // absolute maximum window A
+		binputi16LE (maximumA, file -> filePointer);   // absolute maximum window A
 		if (my ny == 1) {
-			binputi2LE (-1, file -> filePointer);
+			binputi16LE (-1, file -> filePointer);
 		} else {
 			int maximumB = 0;
 			for (long i = 1; i <= my nx; i ++) {
@@ -339,10 +339,10 @@ void Sound_saveAsKayFile (Sound me, MelderFile file) {
 				if (value < - maximumB) maximumB = - value;
 				if (value > maximumB) maximumB = value;
 			}
-			binputi2LE (maximumB, file -> filePointer);   // absolute maximum window B
+			binputi16LE (maximumB, file -> filePointer);   // absolute maximum window B
 		}
 		fwrite ("SDA_", 1, 4, file -> filePointer);
-		binputi4LE (my nx * 2, file -> filePointer);   // chunk size
+		binputi32LE (my nx * 2, file -> filePointer);   // chunk size
 
 		MelderFile_writeFloatToAudio (file, 1, Melder_LINEAR_16_LITTLE_ENDIAN, my z, my nx, true);
 		if (my ny > 1)
