@@ -1,6 +1,6 @@
 /* Sound_to_Pitch.cpp
  *
- * Copyright (C) 1992-2011,2014,2015,2016 Paul Boersma
+ * Copyright (C) 1992-2011,2014,2015,2016,2017 Paul Boersma
  *
  * This code is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -49,11 +49,10 @@ static void Sound_into_PitchFrame (Sound me, Pitch_Frame pitchFrame, double t,
 	double **frame, double *ac, double *window, double *windowR,
 	double *r, long *imax, double *localMean)
 {
-	double localPeak;
-	long leftSample = Sampled_xToLowIndex (me, t), rightSample = leftSample + 1;
-	long startSample, endSample;
+	integer leftSample = Sampled_xToLowIndex (me, t), rightSample = leftSample + 1;
+	integer startSample, endSample;
 
-	for (long channel = 1; channel <= my ny; channel ++) {
+	for (integer channel = 1; channel <= my ny; channel ++) {
 		/*
 		 * Compute the local mean; look one longest period to both sides.
 		 */
@@ -62,7 +61,7 @@ static void Sound_into_PitchFrame (Sound me, Pitch_Frame pitchFrame, double t,
 		Melder_assert (startSample >= 1);
 		Melder_assert (endSample <= my nx);
 		localMean [channel] = 0.0;
-		for (long i = startSample; i <= endSample; i ++) {
+		for (integer i = startSample; i <= endSample; i ++) {
 			localMean [channel] += my z [channel] [i];
 		}
 		localMean [channel] /= 2 * nsamp_period;
@@ -76,12 +75,12 @@ static void Sound_into_PitchFrame (Sound me, Pitch_Frame pitchFrame, double t,
 		Melder_assert (startSample >= 1);
 		Melder_assert (endSample <= my nx);
 		if (method < FCC_NORMAL) {
-			for (long j = 1, i = startSample; j <= nsamp_window; j ++)
+			for (integer j = 1, i = startSample; j <= nsamp_window; j ++)
 				frame [channel] [j] = (my z [channel] [i ++] - localMean [channel]) * window [j];
-			for (long j = nsamp_window + 1; j <= nsampFFT; j ++)
+			for (integer j = nsamp_window + 1; j <= nsampFFT; j ++)
 				frame [channel] [j] = 0.0;
 		} else {
-			for (long j = 1, i = startSample; j <= nsamp_window; j ++)
+			for (integer j = 1, i = startSample; j <= nsamp_window; j ++)
 				frame [channel] [j] = my z [channel] [i ++] - localMean [channel];
 		}
 	}
@@ -89,64 +88,65 @@ static void Sound_into_PitchFrame (Sound me, Pitch_Frame pitchFrame, double t,
 	/*
 	 * Compute the local peak; look half a longest period to both sides.
 	 */
-	localPeak = 0.0;
+	real localPeak = 0.0;
 	if ((startSample = halfnsamp_window + 1 - halfnsamp_period) < 1) startSample = 1;
 	if ((endSample = halfnsamp_window + halfnsamp_period) > nsamp_window) endSample = nsamp_window;
-	for (long channel = 1; channel <= my ny; channel ++) {
-		for (long j = startSample; j <= endSample; j ++) {
-			double value = fabs (frame [channel] [j]);
+	for (integer channel = 1; channel <= my ny; channel ++) {
+		for (integer j = startSample; j <= endSample; j ++) {
+			real value = fabs (frame [channel] [j]);
 			if (value > localPeak) localPeak = value;
 		}
 	}
-	pitchFrame->intensity = localPeak > globalPeak ? 1.0 : localPeak / globalPeak;
+	pitchFrame -> intensity =
+		localPeak > globalPeak ? 1.0 : localPeak / globalPeak;
 
 	/*
 	 * Compute the correlation into the array 'r'.
 	 */
 	if (method >= FCC_NORMAL) {
-		double startTime = t - 0.5 * (1.0 / minimumPitch + dt_window);
-		long localSpan = maximumLag + nsamp_window, localMaximumLag, offset;
+		real startTime = t - 0.5 * (1.0 / minimumPitch + dt_window);
+		integer localSpan = maximumLag + nsamp_window, localMaximumLag, offset;
 		if ((startSample = Sampled_xToLowIndex (me, startTime)) < 1) startSample = 1;
 		if (localSpan > my nx + 1 - startSample) localSpan = my nx + 1 - startSample;
 		localMaximumLag = localSpan - nsamp_window;
 		offset = startSample - 1;
-		double sumx2 = 0;   // sum of squares
-		for (long channel = 1; channel <= my ny; channel ++) {
-			double *amp = my z [channel] + offset;
-			for (long i = 1; i <= nsamp_window; i ++) {
-				double x = amp [i] - localMean [channel];
+		real80 sumx2 = 0.0;   // sum of squares
+		for (integer channel = 1; channel <= my ny; channel ++) {
+			real *amp = my z [channel] + offset;
+			for (integer i = 1; i <= nsamp_window; i ++) {
+				real x = amp [i] - localMean [channel];
 				sumx2 += x * x;
 			}
 		}
-		double sumy2 = sumx2;   // at zero lag, these are still equal
+		real80 sumy2 = sumx2;   // at zero lag, these are still equal
 		r [0] = 1.0;
-		for (long i = 1; i <= localMaximumLag; i ++) {
-			double product = 0.0;
-			for (long channel = 1; channel <= my ny; channel ++) {
-				double *amp = my z [channel] + offset;
-				double y0 = amp [i] - localMean [channel];
-				double yZ = amp [i + nsamp_window] - localMean [channel];
+		for (integer i = 1; i <= localMaximumLag; i ++) {
+			real80 product = 0.0;
+			for (integer channel = 1; channel <= my ny; channel ++) {
+				real *amp = my z [channel] + offset;
+				real y0 = amp [i] - localMean [channel];
+				real yZ = amp [i + nsamp_window] - localMean [channel];
 				sumy2 += yZ * yZ - y0 * y0;
-				for (long j = 1; j <= nsamp_window; j ++) {
-					double x = amp [j] - localMean [channel];
-					double y = amp [i + j] - localMean [channel];
+				for (integer j = 1; j <= nsamp_window; j ++) {
+					real x = amp [j] - localMean [channel];
+					real y = amp [i + j] - localMean [channel];
 					product += x * y;
 				}
 			}
-			r [- i] = r [i] = product / sqrt (sumx2 * sumy2);
+			r [- i] = r [i] = (real) product / sqrt ((real) sumx2 * (real) sumy2);
 		}
 	} else {
 
 		/*
 		 * The FFT of the autocorrelation is the power spectrum.
 		 */
-		for (long i = 1; i <= nsampFFT; i ++) {
+		for (integer i = 1; i <= nsampFFT; i ++) {
 			ac [i] = 0.0;
 		}
-		for (long channel = 1; channel <= my ny; channel ++) {
+		for (integer channel = 1; channel <= my ny; channel ++) {
 			NUMfft_forward (fftTable, frame [channel]);   // complex spectrum
 			ac [1] += frame [channel] [1] * frame [channel] [1];   // DC component
-			for (long i = 2; i < nsampFFT; i += 2) {
+			for (integer i = 2; i < nsampFFT; i += 2) {
 				ac [i] += frame [channel] [i] * frame [channel] [i] + frame [channel] [i+1] * frame [channel] [i+1];   // power spectrum
 			}
 			ac [nsampFFT] += frame [channel] [nsampFFT] * frame [channel] [nsampFFT];   // Nyquist frequency
@@ -158,22 +158,22 @@ static void Sound_into_PitchFrame (Sound me, Pitch_Frame pitchFrame, double t,
 		 * and divide it by the normalized autocorrelation of the window.
 		 */
 		r [0] = 1.0;
-		for (long i = 1; i <= brent_ixmax; i ++)
+		for (integer i = 1; i <= brent_ixmax; i ++)
 			r [- i] = r [i] = ac [i + 1] / (ac [1] * windowR [i + 1]);
 	}
 
 	/*
 	 * Register the first candidate, which is always present: voicelessness.
 	 */
-	pitchFrame->nCandidates = 1;
-	pitchFrame->candidate[1].frequency = 0.0;   // voiceless: always present
-	pitchFrame->candidate[1].strength = 0.0;
+	pitchFrame -> nCandidates = 1;
+	pitchFrame -> candidate [1]. frequency = 0.0;   // voiceless: always present
+	pitchFrame -> candidate [1]. strength = 0.0;
 
 	/*
 	 * Shortcut: absolute silence is always voiceless.
 	 * We are done for this frame.
 	 */
-	if (localPeak == 0) return;
+	if (localPeak == 0.0) return;
 
 	/*
 	 * Find the strongest maxima of the correlation of this frame, 
@@ -190,8 +190,8 @@ static void Sound_into_PitchFrame (Sound me, Pitch_Frame pitchFrame, double t,
 		 * Use parabolic interpolation for first estimate of frequency,
 		 * and sin(x)/x interpolation to compute the strength of this frequency.
 		 */
-		double dr = 0.5 * (r [i+1] - r [i-1]), d2r = 2 * r [i] - r [i-1] - r [i+1];
-		double frequencyOfMaximum = 1 / my dx / (i + dr / d2r);
+		double dr = 0.5 * (r [i+1] - r [i-1]), d2r = 2.0 * r [i] - r [i-1] - r [i+1];
+		double frequencyOfMaximum = 1.0 / my dx / (i + dr / d2r);
 		long offset = - brent_ixmax - 1;
 		double strengthOfMaximum = /* method & 1 ? */
 			NUM_interpolate_sinc (& r [offset], brent_ixmax - offset, 1 / my dx / frequencyOfMaximum - offset, 30)
@@ -203,24 +203,27 @@ static void Sound_into_PitchFrame (Sound me, Pitch_Frame pitchFrame, double t,
 		 * Find a place for this maximum.
 		 */
 		if (pitchFrame->nCandidates < maxnCandidates) {   // is there still a free place?
-			place = ++ pitchFrame->nCandidates;
+			place = ++ pitchFrame -> nCandidates;
 		} else {
 			/* Try the place of the weakest candidate so far. */
-			double weakest = 2;
+			double weakest = 2.0;
 			for (int iweak = 2; iweak <= maxnCandidates; iweak ++) {
 				/* High frequencies are to be favoured */
 				/* if we want to analyze a perfectly periodic signal correctly. */
-				double localStrength = pitchFrame->candidate[iweak].strength - octaveCost *
-					NUMlog2 (minimumPitch / pitchFrame->candidate[iweak].frequency);
-				if (localStrength < weakest) { weakest = localStrength; place = iweak; }
+				double localStrength = pitchFrame -> candidate [iweak]. strength - octaveCost *
+					NUMlog2 (minimumPitch / pitchFrame -> candidate [iweak]. frequency);
+				if (localStrength < weakest) {
+					weakest = localStrength;
+					place = iweak;
+				}
 			}
 			/* If this maximum is weaker than the weakest candidate so far, give it no place. */
 			if (strengthOfMaximum - octaveCost * NUMlog2 (minimumPitch / frequencyOfMaximum) <= weakest)
 				place = 0;
 		}
 		if (place) {   // have we found a place for this candidate?
-			pitchFrame->candidate[place].frequency = frequencyOfMaximum;
-			pitchFrame->candidate[place].strength = strengthOfMaximum;
+			pitchFrame -> candidate [place]. frequency = frequencyOfMaximum;
+			pitchFrame -> candidate [place]. strength = strengthOfMaximum;
 			imax [place] = i;
 		}
 	}
@@ -228,16 +231,16 @@ static void Sound_into_PitchFrame (Sound me, Pitch_Frame pitchFrame, double t,
 	/*
 	 * Second pass: for extra precision, maximize sin(x)/x interpolation ('sinc').
 	 */
-	for (long i = 2; i <= pitchFrame->nCandidates; i ++) {
-		if (method != AC_HANNING || pitchFrame->candidate[i].frequency > 0.0 / my dx) {
+	for (long i = 2; i <= pitchFrame -> nCandidates; i ++) {
+		if (method != AC_HANNING || pitchFrame -> candidate [i]. frequency > 0.0 / my dx) {
 			double xmid, ymid;
 			long offset = - brent_ixmax - 1;
 			ymid = NUMimproveMaximum (& r [offset], brent_ixmax - offset, imax [i] - offset,
-				pitchFrame->candidate[i].frequency > 0.3 / my dx ? NUM_PEAK_INTERPOLATE_SINC700 : brent_depth, & xmid);
+				pitchFrame -> candidate [i]. frequency > 0.3 / my dx ? NUM_PEAK_INTERPOLATE_SINC700 : brent_depth, & xmid);
 			xmid += offset;
-			pitchFrame->candidate[i].frequency = 1.0 / my dx / xmid;
+			pitchFrame -> candidate [i]. frequency = 1.0 / my dx / xmid;
 			if (ymid > 1.0) ymid = 1.0 / ymid;
-			pitchFrame->candidate[i].strength = ymid;
+			pitchFrame -> candidate [i]. strength = ymid;
 		}
 	}
 }
@@ -348,14 +351,11 @@ autoPitch Sound_to_Pitch_any (Sound me,
 {
 	try {
 		autoNUMfft_Table fftTable;
-		double duration, t1;
-		double dt_window;   // window length in seconds
-		long nsamp_window, halfnsamp_window;   // number of samples per window
-		long nFrames, minimumLag, maximumLag;
-		long nsampFFT;
+		double t1;
+		integer numberOfFrames, minimumLag, maximumLag;
+		integer nsampFFT;
 		double interpolation_depth;
-		long nsamp_period, halfnsamp_period;   // number of samples in longest period
-		long brent_ixmax, brent_depth;
+		integer brent_ixmax, brent_depth;
 		double globalPeak;
 
 		Melder_assert (maxnCandidates >= 2);
@@ -384,7 +384,7 @@ autoPitch Sound_to_Pitch_any (Sound me,
 				interpolation_depth = 1.0;
 				break;
 		}
-		duration = my dx * my nx;
+		real duration = my dx * my nx;
 		if (minimumPitch < periodsPerWindow / duration)
 			Melder_throw (U"To analyse this Sound, ", U_LEFT_DOUBLE_QUOTE, U"minimum pitch", U_RIGHT_DOUBLE_QUOTE, U" must not be less than ", periodsPerWindow / duration, U" Hz.");
 
@@ -393,17 +393,17 @@ autoPitch Sound_to_Pitch_any (Sound me,
 		 * We need this to compute the local mean of the sound (looking one period in both directions),
 		 * and to compute the local peak of the sound (looking half a period in both directions).
 		 */
-		nsamp_period = (long) floor (1 / my dx / minimumPitch);
-		halfnsamp_period = nsamp_period / 2 + 1;
+		integer nsamp_period = (long) floor (1 / my dx / minimumPitch);
+		integer halfnsamp_period = nsamp_period / 2 + 1;
 
 		if (ceiling > 0.5 / my dx) ceiling = 0.5 / my dx;
 
 		/*
 		 * Determine window length in seconds and in samples.
 		 */
-		dt_window = periodsPerWindow / minimumPitch;
-		nsamp_window = (long) floor (dt_window / my dx);
-		halfnsamp_window = nsamp_window / 2 - 1;
+		real dt_window = periodsPerWindow / minimumPitch;
+		integer nsamp_window = (long) floor (dt_window / my dx);
+		integer halfnsamp_window = nsamp_window / 2 - 1;
 		if (halfnsamp_window < 2)
 			Melder_throw (U"Analysis window too short.");
 		nsamp_window = halfnsamp_window * 2;
@@ -411,7 +411,7 @@ autoPitch Sound_to_Pitch_any (Sound me,
 		/*
 		 * Determine the minimum and maximum lags.
 		 */
-		minimumLag = (long) floor (1 / my dx / ceiling);
+		minimumLag = (long) floor (1.0 / my dx / ceiling);
 		if (minimumLag < 2) minimumLag = 2;
 		maximumLag = (long) floor (nsamp_window / periodsPerWindow) + 2;
 		if (maximumLag > nsamp_window) maximumLag = nsamp_window;
@@ -423,7 +423,7 @@ autoPitch Sound_to_Pitch_any (Sound me,
 		 * because that allows us to compare the two methods.
 		 */
 		try {
-			Sampled_shortTermAnalysis (me, method >= FCC_NORMAL ? 1 / minimumPitch + dt_window : dt_window, dt, & nFrames, & t1);
+			Sampled_shortTermAnalysis (me, method >= FCC_NORMAL ? 1.0 / minimumPitch + dt_window : dt_window, dt, & numberOfFrames, & t1);
 		} catch (MelderError) {
 			Melder_throw (U"The pitch analysis would give zero pitch frames.");
 		}
@@ -431,12 +431,12 @@ autoPitch Sound_to_Pitch_any (Sound me,
 		/*
 		 * Create the resulting pitch contour.
 		 */
-		autoPitch thee = Pitch_create (my xmin, my xmax, nFrames, dt, t1, ceiling, maxnCandidates);
+		autoPitch thee = Pitch_create (my xmin, my xmax, numberOfFrames, dt, t1, ceiling, maxnCandidates);
 
 		/*
 		 * Create (too much) space for candidates.
 		 */
-		for (long iframe = 1; iframe <= nFrames; iframe ++) {
+		for (integer iframe = 1; iframe <= numberOfFrames; iframe ++) {
 			Pitch_Frame pitchFrame = & thy frame [iframe];
 			Pitch_Frame_init (pitchFrame, maxnCandidates);
 		}
@@ -446,11 +446,11 @@ autoPitch Sound_to_Pitch_any (Sound me,
 		 */
 		globalPeak = 0.0;
 		for (long channel = 1; channel <= my ny; channel ++) {
-			double mean = 0.0;
+			real80 sum = 0.0;
 			for (long i = 1; i <= my nx; i ++) {
-				mean += my z [channel] [i];
+				sum += my z [channel] [i];
 			}
-			mean /= my nx;
+			real mean = real (sum / my nx);
 			for (long i = 1; i <= my nx; i ++) {
 				double value = fabs (my z [channel] [i] - mean);
 				if (value > globalPeak) globalPeak = value;
@@ -475,7 +475,10 @@ autoPitch Sound_to_Pitch_any (Sound me,
 			* The maximum lag considered for maxima is maximumLag.
 			* The maximum lag used in interpolation is nsamp_window * interpolation_depth.
 			*/
-			nsampFFT = 1; while (nsampFFT < nsamp_window * (1 + interpolation_depth)) nsampFFT *= 2;
+			nsampFFT = 1;
+			while (nsampFFT < nsamp_window * (1 + interpolation_depth)) {
+				nsampFFT *= 2;
+			}
 
 			/*
 			* Create buffers for autocorrelation analysis.
@@ -491,27 +494,33 @@ autoPitch Sound_to_Pitch_any (Sound me,
 			*/
 			if (method == AC_GAUSS) {   /* Gaussian window. */
 				double imid = 0.5 * (nsamp_window + 1), edge = exp (-12.0);
-				for (long i = 1; i <= nsamp_window; i ++)
+				for (long i = 1; i <= nsamp_window; i ++) {
 					window [i] = (exp (-48.0 * (i - imid) * (i - imid) /
-						(nsamp_window + 1) / (nsamp_window + 1)) - edge) / (1 - edge);
+						(nsamp_window + 1) / (nsamp_window + 1)) - edge) / (1.0 - edge);
+				}
 			} else {   // Hanning window
-				for (long i = 1; i <= nsamp_window; i ++)
+				for (long i = 1; i <= nsamp_window; i ++) {
 					window [i] = 0.5 - 0.5 * cos (i * 2 * NUMpi / (nsamp_window + 1));
+				}
 			}
 
 			/*
 			* Compute the normalized autocorrelation of the window.
 			*/
-			for (long i = 1; i <= nsamp_window; i ++) windowR [i] = window [i];
+			for (long i = 1; i <= nsamp_window; i ++) {
+				windowR [i] = window [i];
+			}
 			NUMfft_forward (& fftTable, windowR.peek());
 			windowR [1] *= windowR [1];   // DC component
 			for (long i = 2; i < nsampFFT; i += 2) {
-				windowR [i] = windowR [i] * windowR [i] + windowR [i+1] * windowR [i+1];
+				windowR [i] = windowR [i] * windowR [i] + windowR [i + 1] * windowR [i + 1];
 				windowR [i + 1] = 0.0;   // power spectrum: square and zero
 			}
 			windowR [nsampFFT] *= windowR [nsampFFT];   // Nyquist frequency
 			NUMfft_backward (& fftTable, windowR.peek());   // autocorrelation
-			for (long i = 2; i <= nsamp_window; i ++) windowR [i] /= windowR [1];   // normalize
+			for (long i = 2; i <= nsamp_window; i ++) {
+				windowR [i] /= windowR [1];   // normalize
+			}
 			windowR [1] = 1.0;   // normalize
 
 			brent_ixmax = (long) floor (nsamp_window * interpolation_depth);
@@ -519,21 +528,21 @@ autoPitch Sound_to_Pitch_any (Sound me,
 
 		autoMelderProgress progress (U"Sound to Pitch...");
 
-		long numberOfFramesPerThread = 20;
-		int numberOfThreads = (nFrames - 1) / numberOfFramesPerThread + 1;
+		integer numberOfFramesPerThread = 20;
+		int numberOfThreads = (numberOfFrames - 1) / numberOfFramesPerThread + 1;
 		const int numberOfProcessors = MelderThread_getNumberOfProcessors ();
 		trace (numberOfProcessors, U" processors");
 		if (numberOfThreads > numberOfProcessors) numberOfThreads = numberOfProcessors;
 		if (numberOfThreads > 16) numberOfThreads = 16;
 		if (numberOfThreads < 1) numberOfThreads = 1;
-		numberOfFramesPerThread = (nFrames - 1) / numberOfThreads + 1;
+		numberOfFramesPerThread = (numberOfFrames - 1) / numberOfThreads + 1;
 
 		if (! mutex_inited) { MelderThread_MUTEX_INIT (mutex); mutex_inited = true; }
 		autoSound_into_Pitch_Args args [16];
 		long firstFrame = 1, lastFrame = numberOfFramesPerThread;
 		volatile int cancelled = 0;
 		for (int ithread = 1; ithread <= numberOfThreads; ithread ++) {
-			if (ithread == numberOfThreads) lastFrame = nFrames;
+			if (ithread == numberOfThreads) lastFrame = numberOfFrames;
 			args [ithread - 1] = Sound_into_Pitch_Args_create (me, thee.get(),
 				firstFrame, lastFrame, minimumPitch, maxnCandidates, method,
 				voicingThreshold, octaveCost,
