@@ -57,7 +57,7 @@ void Spectrogram_paintInside (Spectrogram me, Graphics g, double tmin, double tm
 {
 	if (tmax <= tmin) { tmin = my xmin; tmax = my xmax; }
 	if (fmax <= fmin) { fmin = my ymin; fmax = my ymax; }
-	long itmin, itmax, ifmin, ifmax;
+	integer itmin, itmax, ifmin, ifmax;
 	if (! Matrix_getWindowSamplesX (me, tmin - 0.49999 * my dx, tmax + 0.49999 * my dx, & itmin, & itmax) ||
 		 ! Matrix_getWindowSamplesY (me, fmin - 0.49999 * my dy, fmax + 0.49999 * my dy, & ifmin, & ifmax))
 		return;
@@ -65,9 +65,9 @@ void Spectrogram_paintInside (Spectrogram me, Graphics g, double tmin, double tm
 	autoNUMvector <double> preemphasisFactor (ifmin, ifmax);
 	autoNUMvector <double> dynamicFactor (itmin, itmax);
 	/* Pre-emphasis in place; also compute maximum after pre-emphasis. */
-	for (long ifreq = ifmin; ifreq <= ifmax; ifreq ++) {
+	for (integer ifreq = ifmin; ifreq <= ifmax; ifreq ++) {
 		preemphasisFactor [ifreq] = (preemphasis / NUMln2) * log (ifreq * my dy / 1000.0);
-		for (long itime = itmin; itime <= itmax; itime ++) {
+		for (integer itime = itmin; itime <= itmax; itime ++) {
 			double value = my z [ifreq] [itime];   // power
 			value = (10.0/NUMln10) * log ((value + 1e-30) / 4.0e-10) + preemphasisFactor [ifreq];   // dB
 			if (value > dynamicFactor [itime]) dynamicFactor [itime] = value;   // local maximum
@@ -77,13 +77,13 @@ void Spectrogram_paintInside (Spectrogram me, Graphics g, double tmin, double tm
 	/* Compute global maximum. */
 	if (autoscaling) {
 		maximum = 0.0;
-		for (long itime = itmin; itime <= itmax; itime ++)
+		for (integer itime = itmin; itime <= itmax; itime ++)
 			if (dynamicFactor [itime] > maximum) maximum = dynamicFactor [itime];
 	}
 	/* Dynamic compression in place. */
-	for (long itime = itmin; itime <= itmax; itime ++) {
+	for (integer itime = itmin; itime <= itmax; itime ++) {
 		dynamicFactor [itime] = dynamicCompression * (maximum - dynamicFactor [itime]);
-		for (long ifreq = ifmin; ifreq <= ifmax; ifreq ++)
+		for (integer ifreq = ifmin; ifreq <= ifmax; ifreq ++)
 			my z [ifreq] [itime] += dynamicFactor [itime];
 	}
 	Graphics_image (g, my z,
@@ -94,8 +94,8 @@ void Spectrogram_paintInside (Spectrogram me, Graphics g, double tmin, double tm
 		Matrix_rowToY (me, ifmin - 0.5),
 		Matrix_rowToY (me, ifmax + 0.5),
 		maximum - dynamic, maximum);
-	for (long ifreq = ifmin; ifreq <= ifmax; ifreq ++)
-		for (long itime = itmin; itime <= itmax; itime ++) {
+	for (integer ifreq = ifmin; ifreq <= ifmax; ifreq ++)
+		for (integer itime = itmin; itime <= itmax; itime ++) {
 			double value = 4.0e-10 * exp ((my z [ifreq] [itime] - dynamicFactor [itime]
 				- preemphasisFactor [ifreq]) * (NUMln10 / 10.0)) - 1e-30;
 			my z [ifreq] [itime] = value > 0.0 ? value : 0.0;
