@@ -1,6 +1,6 @@
 /* Spectrum.cpp
  *
- * Copyright (C) 1992-2012,2014,2015,2016 Paul Boersma
+ * Copyright (C) 1992-2012,2014,2015,2016,2017 Paul Boersma
  *
  * This code is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -62,7 +62,7 @@ void structSpectrum :: v_info () {
 
 double structSpectrum :: v_getValueAtSample (long isamp, long which, int units) {
 	if (units == 0) {
-		return which == 1 ? z [1] [isamp] : which == 2 ? z [2] [isamp] : NUMundefined;
+		return which == 1 ? z [1] [isamp] : which == 2 ? z [2] [isamp] : undefined;
 	} else {
 		/*
 		 * The energy in a bin is 2 * (re^2 + im^2) times the bin width.
@@ -82,7 +82,7 @@ double structSpectrum :: v_getValueAtSample (long isamp, long which, int units)
 			}
 		}
 	}
-	return NUMundefined;
+	return undefined;
 }
 
 autoSpectrum Spectrum_create (double fmax, long nf) {
@@ -113,7 +113,7 @@ void Spectrum_drawInside (Spectrum me, Graphics g, double fmin, double fmax, dou
 	bool autoscaling = ( minimum >= maximum );
 
 	if (fmax <= fmin) { fmin = my xmin; fmax = my xmax; }
-	long ifmin, ifmax;
+	integer ifmin, ifmax;
 	if (! Matrix_getWindowSamplesX (me, fmin, fmax, & ifmin, & ifmax)) return;
 
 	autoNUMvector <double> yWC (ifmin, ifmax);
@@ -132,7 +132,7 @@ void Spectrum_drawInside (Spectrum me, Graphics g, double fmin, double fmax, dou
 		minimum = maximum - defaultDynamicRange_dB;
 		if (minimum == maximum) {   // because infinity minus something is still infinity
 			Graphics_setWindow (g, 0.0, 1.0, 0.0, 1.0);
-			Graphics_setTextAlignment (g, kGraphics_horizontalAlignment_CENTRE, Graphics_HALF);
+			Graphics_setTextAlignment (g, kGraphics_horizontalAlignment::CENTRE, Graphics_HALF);
 			Graphics_text (g, 0.5, 0.5, U"(undefined spectrum values cannot be drawn)");
 			return;
 		}
@@ -166,7 +166,7 @@ void Spectrum_draw (Spectrum me, Graphics g, double fmin, double fmax, double mi
 void Spectrum_drawLogFreq (Spectrum me, Graphics g, double fmin, double fmax, double minimum, double maximum, int garnish) {
 	bool autoscaling = ( minimum >= maximum );
 	if (fmax <= fmin) { fmin = my xmin; fmax = my xmax; }
-	long ifmin, ifmax;
+	integer ifmin, ifmax;
 	if (! Matrix_getWindowSamplesX (me, fmin, fmax, & ifmin, & ifmax)) return;
 if(ifmin==1)ifmin=2;  /* BUG */
 	autoNUMvector <double> xWC (ifmin, ifmax);
@@ -357,7 +357,7 @@ double Spectrum_getBandEnergy (Spectrum me, double fmin, double fmax) {
 	 * of the positive-frequency values, and that only the positive-frequency values are included
 	 * in the spectrum.
 	 */
-	if (my xmin < 0.0) return NUMundefined;
+	if (my xmin < 0.0) return undefined;
 	/*
 	 * Any energy outside [my xmin, my xmax] is ignored.
 	 * This is very important, since my xmin and my xmax determine the meaning of the first and last bins; see below.
@@ -378,28 +378,29 @@ double Spectrum_getBandEnergy (Spectrum me, double fmin, double fmax) {
 }
 
 double Spectrum_getBandDensity (Spectrum me, double fmin, double fmax) {
-	if (my xmin < 0.0) return NUMundefined;   // no negative frequencies allowed in one-sided spectral density
+	if (my xmin < 0.0) return undefined;   // no negative frequencies allowed in one-sided spectral density
 	return Sampled_getMean (me, fmin, fmax, 0, 1, false);
 }
 
 double Spectrum_getBandDensityDifference (Spectrum me, double lowBandMin, double lowBandMax, double highBandMin, double highBandMax) {
 	double lowBandDensity = Spectrum_getBandDensity (me, lowBandMin, lowBandMax);
 	double highBandDensity = Spectrum_getBandDensity (me, highBandMin, highBandMax);
-	if (lowBandDensity == NUMundefined || highBandDensity == NUMundefined) return NUMundefined;
-	if (lowBandDensity == 0.0 || highBandDensity == 0.0) return NUMundefined;
-	return 10 * log10 (highBandDensity / lowBandDensity);
+	if (isundef (lowBandDensity) || isundef (highBandDensity)) return undefined;
+	if (lowBandDensity == 0.0 || highBandDensity == 0.0) return undefined;
+	return 10.0 * log10 (highBandDensity / lowBandDensity);
 }
 
 double Spectrum_getBandEnergyDifference (Spectrum me, double lowBandMin, double lowBandMax, double highBandMin, double highBandMax) {
 	double lowBandEnergy = Spectrum_getBandEnergy (me, lowBandMin, lowBandMax);
 	double highBandEnergy = Spectrum_getBandEnergy (me, highBandMin, highBandMax);
-	if (lowBandEnergy == NUMundefined || highBandEnergy == NUMundefined) return NUMundefined;
-	if (lowBandEnergy == 0.0 || highBandEnergy == 0.0) return NUMundefined;
+	if (isundef (lowBandEnergy) || isundef (highBandEnergy)) return undefined;
+	if (lowBandEnergy == 0.0 || highBandEnergy == 0.0) return undefined;
 	return 10.0 * log10 (highBandEnergy / lowBandEnergy);
 }
 
 double Spectrum_getCentreOfGravity (Spectrum me, double power) {
-	double halfpower = 0.5 * power, sumenergy = 0.0, sumfenergy = 0.0;
+	double halfpower = 0.5 * power;
+	long double sumenergy = 0.0, sumfenergy = 0.0;
 	for (long i = 1; i <= my nx; i ++) {
 		double re = my z [1] [i], im = my z [2] [i], energy = re * re + im * im;
 		double f = my x1 + (i - 1) * my dx;
@@ -407,13 +408,14 @@ double Spectrum_getCentreOfGravity (Spectrum me, double power) {
 		sumenergy += energy;
 		sumfenergy += f * energy;
 	}
-	return sumenergy == 0.0 ? NUMundefined : sumfenergy / sumenergy;
+	return sumenergy == 0.0 ? undefined : double (sumfenergy / sumenergy);
 }
 
 double Spectrum_getCentralMoment (Spectrum me, double moment, double power) {
-	double halfpower = 0.5 * power, sumenergy = 0.0, sumfenergy = 0.0;
 	double fmean = Spectrum_getCentreOfGravity (me, power);
-	if (fmean == NUMundefined) return NUMundefined;
+	if (isundef (fmean)) return undefined;
+	double halfpower = 0.5 * power;
+	long double sumenergy = 0.0, sumfenergy = 0.0;
 	for (long i = 1; i <= my nx; i ++) {
 		double re = my z [1] [i], im = my z [2] [i], energy = re * re + im * im;
 		double f = my x1 + (i - 1) * my dx;
@@ -421,7 +423,7 @@ double Spectrum_getCentralMoment (Spectrum me, double moment, double power) {
 		sumenergy += energy;
 		sumfenergy += pow (f - fmean, moment) * energy;
 	}
-	return sumfenergy / sumenergy;
+	return double (sumfenergy / sumenergy);
 }
 
 double Spectrum_getStandardDeviation (Spectrum me, double power) {
@@ -431,21 +433,21 @@ double Spectrum_getStandardDeviation (Spectrum me, double power) {
 double Spectrum_getSkewness (Spectrum me, double power) {
 	double m2 = Spectrum_getCentralMoment (me, 2.0, power);
 	double m3 = Spectrum_getCentralMoment (me, 3.0, power);
-	if (m2 == NUMundefined || m3 == NUMundefined || m2 == 0.0) return NUMundefined;
+	if (isundef (m2) || isundef (m3) || m2 == 0.0) return undefined;
 	return m3 / (m2 * sqrt (m2));
 }
 
 double Spectrum_getKurtosis (Spectrum me, double power) {
 	double m2 = Spectrum_getCentralMoment (me, 2.0, power);
 	double m4 = Spectrum_getCentralMoment (me, 4.0, power);
-	if (m2 == NUMundefined || m4 == NUMundefined || m2 == 0.0) return NUMundefined;
+	if (isundef (m2) || isundef (m4) || m2 == 0.0) return undefined;
 	return m4 / (m2 * m2) - 3;
 }
 
 void Spectrum_getNearestMaximum (Spectrum me, double frequency, double *frequencyOfMaximum, double *heightOfMaximum) {
 	try {
 		autoSpectrumTier thee = Spectrum_to_SpectrumTier_peaks (me);
-		long index = AnyTier_timeToNearestIndex (thee.get()->asAnyTier(), frequency);
+		integer index = AnyTier_timeToNearestIndex (thee.get()->asAnyTier(), frequency);
 		if (index == 0)
 			Melder_throw (U"No peak.");
 		RealPoint point = thy points.at [index];
