@@ -1,6 +1,6 @@
 /* manual_Picture.cpp
  *
- * Copyright (C) 1992-2011,2012,2013,2014,2015 Paul Boersma
+ * Copyright (C) 1992-2011,2012,2013,2014,2015,2017 Paul Boersma
  *
  * This code is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -25,7 +25,7 @@ static void drawOneIpaSymbol (Graphics g, double x, double y, const char32 *symb
 	Graphics_rectangle (g, x - 0.5, x + 0.5, y - 0.5, y + 0.5);
 	if (! symbol) return;
 	Graphics_setTextAlignment (g, Graphics_CENTRE, Graphics_HALF);
-	Graphics_setFont (g, kGraphics_font_TIMES);
+	Graphics_setFont (g, kGraphics_font::TIMES);
 	Graphics_setFontSize (g, fontSize * 3 / 2);
 	Graphics_text (g, x, y + 0.25, symbol);
 	while (*symbol) {
@@ -34,7 +34,7 @@ static void drawOneIpaSymbol (Graphics g, double x, double y, const char32 *symb
 		symbol ++;
 	}
 	*p = '\0';   // trailing null byte
-	Graphics_setFont (g, kGraphics_font_HELVETICA);
+	Graphics_setFont (g, kGraphics_font::HELVETICA);
 	Graphics_setFontSize (g, fontSize * 5 / 6);
 	Graphics_text (g, x, y - 0.25, buffer);
 	Graphics_setFontSize (g, fontSize);
