@@ -352,7 +352,7 @@ DO
 
 DIRECT (REAL_Matrix_getMinimum) {
 	NUMBER_ONE (Matrix)
-		double minimum = NUMundefined, maximum = NUMundefined;
+		double minimum = undefined, maximum = undefined;
 		Matrix_getWindowExtrema (me, 0, 0, 0, 0, & minimum, & maximum);
 		double result = minimum;
 	NUMBER_ONE_END (U" (minimum)");
@@ -360,7 +360,7 @@ DIRECT (REAL_Matrix_getMinimum) {
 
 DIRECT (REAL_Matrix_getMaximum) {
 	NUMBER_ONE (Matrix)
-		double minimum = NUMundefined, maximum = NUMundefined;
+		double minimum = undefined, maximum = undefined;
 		Matrix_getWindowExtrema (me, 0, 0, 0, 0, & minimum, & maximum);
 		double result = maximum;
 	NUMBER_ONE_END (U" (maximum)");
@@ -792,16 +792,16 @@ DIRECT (WINDOW_Movie_viewAndEdit) {
 
 static autoDaata imageFileRecognizer (int /* nread */, const char * /* header */, MelderFile file) {
 	const char32 *fileName = MelderFile_name (file);
-	if (Melder_stringMatchesCriterion (fileName, kMelder_string_ENDS_WITH, U".jpg") ||
-	    Melder_stringMatchesCriterion (fileName, kMelder_string_ENDS_WITH, U".JPG") ||
-	    Melder_stringMatchesCriterion (fileName, kMelder_string_ENDS_WITH, U".jpeg") ||
-		Melder_stringMatchesCriterion (fileName, kMelder_string_ENDS_WITH, U".JPEG") ||
-	    Melder_stringMatchesCriterion (fileName, kMelder_string_ENDS_WITH, U".png") ||
-		Melder_stringMatchesCriterion (fileName, kMelder_string_ENDS_WITH, U".PNG") ||
-	    Melder_stringMatchesCriterion (fileName, kMelder_string_ENDS_WITH, U".tiff") ||
-		Melder_stringMatchesCriterion (fileName, kMelder_string_ENDS_WITH, U".TIFF") ||
-		Melder_stringMatchesCriterion (fileName, kMelder_string_ENDS_WITH, U".tif") ||
-		Melder_stringMatchesCriterion (fileName, kMelder_string_ENDS_WITH, U".TIF"))
+	if (Melder_stringMatchesCriterion (fileName, kMelder_string::ENDS_WITH, U".jpg") ||
+	    Melder_stringMatchesCriterion (fileName, kMelder_string::ENDS_WITH, U".JPG") ||
+	    Melder_stringMatchesCriterion (fileName, kMelder_string::ENDS_WITH, U".jpeg") ||
+		Melder_stringMatchesCriterion (fileName, kMelder_string::ENDS_WITH, U".JPEG") ||
+	    Melder_stringMatchesCriterion (fileName, kMelder_string::ENDS_WITH, U".png") ||
+		Melder_stringMatchesCriterion (fileName, kMelder_string::ENDS_WITH, U".PNG") ||
+	    Melder_stringMatchesCriterion (fileName, kMelder_string::ENDS_WITH, U".tiff") ||
+		Melder_stringMatchesCriterion (fileName, kMelder_string::ENDS_WITH, U".TIFF") ||
+		Melder_stringMatchesCriterion (fileName, kMelder_string::ENDS_WITH, U".tif") ||
+		Melder_stringMatchesCriterion (fileName, kMelder_string::ENDS_WITH, U".TIF"))
 	{
 		return Photo_readFromImageFile (file);
 	}
