@@ -1,6 +1,6 @@
 /* Network.cpp
  *
- * Copyright (C) 2009-2012,2013,2014,2015,2016 Paul Boersma
+ * Copyright (C) 2009-2012,2013,2014,2015,2016,2017 Paul Boersma
  *
  * This code is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -71,7 +71,7 @@ void structNetwork :: v_info ()
 
 Thing_implement (Network, Daata, 6);
 
-void Network_init (Network me, double spreadingRate, enum kNetwork_activityClippingRule activityClippingRule,
+void Network_init (Network me, double spreadingRate, kNetwork_activityClippingRule activityClippingRule,
 	double minimumActivity, double maximumActivity, double activityLeak,
 	double learningRate, double minimumWeight, double maximumWeight, double weightLeak,
 	double xmin, double xmax, double ymin, double ymax, long numberOfNodes, long numberOfConnections)
@@ -97,7 +97,7 @@ void Network_init (Network me, double spreadingRate, enum kNetwork_activityClipp
 	my connections = NUMvector <structNetworkConnection> (1, numberOfConnections);
 }
 
-autoNetwork Network_create (double spreadingRate, enum kNetwork_activityClippingRule activityClippingRule,
+autoNetwork Network_create (double spreadingRate, kNetwork_activityClippingRule activityClippingRule,
 	double minimumActivity, double maximumActivity, double activityLeak,
 	double learningRate, double minimumWeight, double maximumWeight, double weightLeak,
 	double xmin, double xmax, double ymin, double ymax, long numberOfNodes, long numberOfConnections)
@@ -184,11 +184,11 @@ void Network_spreadActivities (Network me, long numberOfSteps) {
 			NetworkNode node = & my nodes [inode];
 			if (! node -> clamped) {
 				switch (my activityClippingRule) {
-					case kNetwork_activityClippingRule_SIGMOID:
+					case kNetwork_activityClippingRule::SIGMOID:
 						node -> activity = my minimumActivity +
 							(my maximumActivity - my minimumActivity) * NUMsigmoid (node -> excitation - 0.5 * (my minimumActivity + my maximumActivity));
 					break;
-					case kNetwork_activityClippingRule_LINEAR:
+					case kNetwork_activityClippingRule::LINEAR:
 						if (node -> excitation < my minimumActivity) {
 							node -> activity = my minimumActivity;
 						} else if (node -> excitation > my maximumActivity) {
@@ -197,7 +197,7 @@ void Network_spreadActivities (Network me, long numberOfSteps) {
 							node -> activity = node -> excitation;
 						}
 					break;
-					case kNetwork_activityClippingRule_TOP_SIGMOID:
+					case kNetwork_activityClippingRule::TOP_SIGMOID:
 						if (node -> excitation <= my minimumActivity) {
 							node -> activity = my minimumActivity;
 						} else {
@@ -432,7 +432,9 @@ void Network_draw (Network me, Graphics graphics, bool useColour) {
 
 void Network_addNode (Network me, double x, double y, double activity, bool clamped) {
 	try {
-		NUMvector_append (& my nodes, 1, & my numberOfNodes);
+		integer numberOfNodes = my numberOfNodes;
+		NUMvector_append (& my nodes, 1, & numberOfNodes);
+		my numberOfNodes = numberOfNodes;
 		my nodes [my numberOfNodes]. x = x;
 		my nodes [my numberOfNodes]. y = y;
 		my nodes [my numberOfNodes]. activity = my nodes [my numberOfNodes]. excitation = activity;
@@ -444,7 +446,9 @@ void Network_addNode (Network me, double x, double y, double activity, bool clam
 
 void Network_addConnection (Network me, long nodeFrom, long nodeTo, double weight, double plasticity) {
 	try {
-		NUMvector_append (& my connections, 1, & my numberOfConnections);
+		integer numberOfConnections = my numberOfConnections;
+		NUMvector_append (& my connections, 1, & numberOfConnections);
+		my numberOfConnections = numberOfConnections;
 		my connections [my numberOfConnections]. nodeFrom = nodeFrom;
 		my connections [my numberOfConnections]. nodeTo = nodeTo;
 		my connections [my numberOfConnections]. weight = weight;
