@@ -1,6 +1,6 @@
 /* NUMarrays.cpp
  *
- * Copyright (C) 1992-2012 Paul Boersma
+ * Copyright (C) 1992-2012,2017 Paul Boersma
  *
  * This code is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -16,22 +16,23 @@
  * along with this work. If not, see <http://www.gnu.org/licenses/>.
  */
 
-#include "NUM.h"
 #include "melder.h"
 
-static long theTotalNumberOfArrays;
+static integer theTotalNumberOfArrays;
 
-long NUM_getTotalNumberOfArrays () { return theTotalNumberOfArrays; }
+integer NUM_getTotalNumberOfArrays () { return theTotalNumberOfArrays; }
 
 /*** Generic memory routines for vectors. ***/
 
-void * NUMvector (long elementSize, long lo, long hi) {
+void * NUMvector (integer elementSize, integer lo, integer hi, bool zero) {
 	try {
 		if (hi < lo) return nullptr;   // not an error
 		char *result;
 		Melder_assert (sizeof (char) == 1);   // some say that this is true by definition
 		for (;;) {   // not very infinite: 99.999 % of the time once, 0.001 % twice
-			result = reinterpret_cast<char*> (_Melder_calloc (hi - lo + 1, elementSize));
+			result = zero ?
+				reinterpret_cast<char*> (_Melder_calloc (hi - lo + 1, elementSize)) :
+				reinterpret_cast<char*> (_Melder_malloc ((hi - lo + 1) * elementSize));
 			if (result -= lo * elementSize) break;   // this will normally succeed at the first try
 			(void) Melder_realloc_f (result + lo * elementSize, 1);   // make "sure" that the second try will succeed (not *very* sure, because realloc might move memory even if it shrinks)
 		}
@@ -42,18 +43,18 @@ void * NUMvector (long elementSize, long lo, long hi) {
 	}
 }
 
-void NUMvector_free (long elementSize, void *v, long lo) {
+void NUMvector_free (integer elementSize, void *v, integer lo) noexcept {
 	if (! v) return;   // no error
 	char *dum = (char *) v + lo * elementSize;
 	Melder_free (dum);
 	theTotalNumberOfArrays -= 1;
 }
 
-void * NUMvector_copy (long elementSize, void *v, long lo, long hi) {
+void * NUMvector_copy (integer elementSize, void *v, integer lo, integer hi) {
 	try {
 		if (! v) return nullptr;
-		char *result = reinterpret_cast <char *> (NUMvector (elementSize, lo, hi));
-		long offset = lo * elementSize;
+		char *result = reinterpret_cast <char *> (NUMvector (elementSize, lo, hi, false));
+		integer offset = lo * elementSize;
 		memcpy (result + offset, (char *) v + offset, (hi - lo + 1) * elementSize);
 		return result;
 	} catch (MelderError) {
@@ -61,26 +62,26 @@ void * NUMvector_copy (long elementSize, void *v, long lo, long hi) {
 	}
 }
 
-void NUMvector_copyElements (long elementSize, void *v, void *to, long lo, long hi) {
-	long offset = lo * elementSize;
+void NUMvector_copyElements (integer elementSize, void *v, void *to, integer lo, integer hi) {
+	integer offset = lo * elementSize;
 	Melder_assert (!! v && !! to);
 	if (hi >= lo) memcpy ((char *) to + offset, (char *) v + offset, (hi - lo + 1) * elementSize);
 }
 
-bool NUMvector_equal (long elementSize, void *v1, void *v2, long lo, long hi) {
-	long offset = lo * elementSize;
+bool NUMvector_equal (integer elementSize, void *v1, void *v2, integer lo, integer hi) {
+	integer offset = lo * elementSize;
 	Melder_assert (v1 && v2);
 	return ! memcmp ((char *) v1 + offset, (char *) v2 + offset, (hi - lo + 1) * elementSize);
 }
 
-void NUMvector_append (long elementSize, void **v, long lo, long *hi) {
+void NUMvector_append (integer elementSize, void **v, integer lo, integer *hi) {
 	try {
 		char *result;
 		if (! *v) {
-			result = reinterpret_cast <char *> (NUMvector (elementSize, lo, lo));
+			result = reinterpret_cast <char *> (NUMvector (elementSize, lo, lo, true));
 			*hi = lo;
 		} else {
-			long offset = lo * elementSize;
+			integer offset = lo * elementSize;
 			for (;;) {   // not very infinite: 99.999 % of the time once, 0.001 % twice
 				result = reinterpret_cast <char *> (Melder_realloc ((char *) *v + offset, (*hi - lo + 2) * elementSize));
 				if ((result -= offset) != nullptr) break;   // this will normally succeed at the first try
@@ -95,17 +96,18 @@ void NUMvector_append (long elementSize, void **v, long lo, long *hi) {
 	}
 }
 
-void NUMvector_insert (long elementSize, void **v, long lo, long *hi, long position) {
+void NUMvector_insert (integer elementSize, void **v, integer lo, integer *hi, integer position) {
 	try {
 		char *result;
 		if (! *v) {
-			result = reinterpret_cast <char *> (NUMvector (elementSize, lo, lo));
+			result = reinterpret_cast <char *> (NUMvector (elementSize, lo, lo, true));
 			*hi = lo;
 			Melder_assert (position == lo);
 		} else {
-			result = reinterpret_cast <char *> (NUMvector (elementSize, lo, *hi + 1));
+			result = reinterpret_cast <char *> (NUMvector (elementSize, lo, *hi + 1, false));
 			Melder_assert (position >= lo && position <= *hi + 1);
 			NUMvector_copyElements (elementSize, *v, result, lo, position - 1);
+			memset (result + position * elementSize, 0, elementSize);
 			NUMvector_copyElements (elementSize, *v, result + elementSize, position, *hi);
 			NUMvector_free (elementSize, *v, lo);
 			(*hi) ++;
@@ -118,7 +120,7 @@ void NUMvector_insert (long elementSize, void **v, long lo, long *hi, long posit
 
 /*** Generic memory routines for matrices. ***/
 
-void * NUMmatrix (long elementSize, long row1, long row2, long col1, long col2) {
+void * NUMmatrix (integer elementSize, integer row1, integer row2, integer col1, integer col2, bool zero) {
 	try {
 		int64 numberOfRows = row2 - row1 + 1;
 		int64 numberOfColumns = col2 - col1 + 1;
@@ -130,7 +132,7 @@ void * NUMmatrix (long elementSize, long row1, long row2, long col1, long col2)
 		char **result;
 		Melder_assert (sizeof (char) == 1);   // true by definition
 		for (;;) {
-			result = reinterpret_cast <char **> (_Melder_malloc_f (numberOfRows * sizeof (char *)));   // assume that all pointers have the same size
+			result = reinterpret_cast <char **> (_Melder_malloc_f (numberOfRows * (int64) sizeof (char *)));   // assume that all pointers have the same size
 			result -= row1;
 			if (result) break;   // this will normally succeed at the first try
 			(void) Melder_realloc_f (result + row1, 1);   // make "sure" that the second try will succeed
@@ -141,7 +143,9 @@ void * NUMmatrix (long elementSize, long row1, long row2, long col1, long col2)
 		 */
 		for (;;) {
 			try {
-				result [row1] = reinterpret_cast <char *> (_Melder_calloc (numberOfCells, elementSize));
+				result [row1] = zero ?
+					reinterpret_cast <char *> (_Melder_calloc (numberOfCells, elementSize)) :
+					reinterpret_cast <char *> (_Melder_malloc (numberOfCells * elementSize));
 			} catch (MelderError) {
 				result += row1;
 				Melder_free (result);   // free the row pointers
@@ -151,7 +155,7 @@ void * NUMmatrix (long elementSize, long row1, long row2, long col1, long col2)
 			(void) Melder_realloc_f (result [row1] + col1 * elementSize, 1);   // make "sure" that the second try will succeed
 		}
 		int64 columnSize = numberOfColumns * elementSize;
-		for (long irow = row1 + 1; irow <= row2; irow ++) result [irow] = result [irow - 1] + columnSize;
+		for (integer irow = row1 + 1; irow <= row2; irow ++) result [irow] = result [irow - 1] + columnSize;
 		theTotalNumberOfArrays += 1;
 		return result;
 	} catch (MelderError) {
@@ -159,7 +163,7 @@ void * NUMmatrix (long elementSize, long row1, long row2, long col1, long col2)
 	}
 }
 
-void NUMmatrix_free (long elementSize, void *m, long row1, long col1) {
+void NUMmatrix_free (integer elementSize, void *m, integer row1, integer col1) noexcept {
 	if (! m) return;
 	char *dummy1 = ((char **) m) [row1] + col1 * elementSize;
 	Melder_free (dummy1);
@@ -168,13 +172,13 @@ void NUMmatrix_free (long elementSize, void *m, long row1, long col1) {
 	theTotalNumberOfArrays -= 1;
 }
 
-void * NUMmatrix_copy (long elementSize, void * m, long row1, long row2, long col1, long col2) {
+void * NUMmatrix_copy (integer elementSize, void * m, integer row1, integer row2, integer col1, integer col2) {
 	try {
 		if (! m) return nullptr;
-		char **result = reinterpret_cast <char **> (NUMmatrix (elementSize, row1, row2, col1, col2));
+		char **result = reinterpret_cast <char **> (NUMmatrix (elementSize, row1, row2, col1, col2, false));
 		if (! result) return nullptr;
-		long columnOffset = col1 * elementSize;
-		long dataSize = (row2 - row1 + 1) * (col2 - col1 + 1) * elementSize;
+		integer columnOffset = col1 * elementSize;
+		integer dataSize = (row2 - row1 + 1) * (col2 - col1 + 1) * elementSize;
 		memcpy (result [row1] + columnOffset, ((char **) m) [row1] + columnOffset, dataSize);
 		return result;
 	} catch (MelderError) {
@@ -182,40 +186,40 @@ void * NUMmatrix_copy (long elementSize, void * m, long row1, long row2, long co
 	}
 }
 
-void NUMmatrix_copyElements (long elementSize, void *m, void *to, long row1, long row2, long col1, long col2) {
+void NUMmatrix_copyElements (integer elementSize, void *m, void *to, integer row1, integer row2, integer col1, integer col2) {
 	Melder_assert (m && to);
-	long columnOffset = col1 * elementSize;
-	long dataSize = (row2 - row1 + 1) * (col2 - col1 + 1) * elementSize;
+	integer columnOffset = col1 * elementSize;
+	integer dataSize = (row2 - row1 + 1) * (col2 - col1 + 1) * elementSize;
 	memcpy (((char **) to) [row1] + columnOffset, ((char **) m) [row1] + columnOffset, dataSize);
 }
 
-bool NUMmatrix_equal (long elementSize, void *m1, void *m2, long row1, long row2, long col1, long col2) {
+bool NUMmatrix_equal (integer elementSize, void *m1, void *m2, integer row1, integer row2, integer col1, integer col2) {
 	Melder_assert (m1 && m2);
-	long columnOffset = col1 * elementSize;
-	long dataSize = (row2 - row1 + 1) * (col2 - col1 + 1) * elementSize;
+	integer columnOffset = col1 * elementSize;
+	integer dataSize = (row2 - row1 + 1) * (col2 - col1 + 1) * elementSize;
 	return ! memcmp (((char **) m1) [row1] + columnOffset, ((char **) m2) [row1] + columnOffset, dataSize);
 }
 
 /*** Typed I/O routines for vectors and matrices. ***/
 
 #define FUNCTION(type,storage)  \
-	void NUMvector_writeText_##storage (const type *v, long lo, long hi, MelderFile file, const char32 *name) { \
+	void NUMvector_writeText_##storage (const type *v, integer lo, integer hi, MelderFile file, const char32 *name) { \
 		texputintro (file, name, U" []: ", hi >= lo ? nullptr : U"(empty)", 0,0,0); \
-		for (long i = lo; i <= hi; i ++) \
+		for (integer i = lo; i <= hi; i ++) \
 			texput##storage (file, v [i], name, U" [", Melder_integer (i), U"]", 0,0); \
 		texexdent (file); \
 		if (feof (file -> filePointer) || ferror (file -> filePointer)) Melder_throw (U"Write error."); \
 	} \
-	void NUMvector_writeBinary_##storage (const type *v, long lo, long hi, FILE *f) { \
-		for (long i = lo; i <= hi; i ++) \
+	void NUMvector_writeBinary_##storage (const type *v, integer lo, integer hi, FILE *f) { \
+		for (integer i = lo; i <= hi; i ++) \
 			binput##storage (v [i], f); \
 		if (feof (f) || ferror (f)) Melder_throw (U"Write error."); \
 	} \
-	type * NUMvector_readText_##storage (long lo, long hi, MelderReadText text, const char *name) { \
+	type * NUMvector_readText_##storage (integer lo, integer hi, MelderReadText text, const char *name) { \
 		type *result = nullptr; \
 		try { \
 			result = NUMvector <type> (lo, hi); \
-			for (long i = lo; i <= hi; i ++) { \
+			for (integer i = lo; i <= hi; i ++) { \
 				try { \
 					result [i] = texget##storage (text); \
 				} catch (MelderError) { \
@@ -228,11 +232,11 @@ bool NUMmatrix_equal (long elementSize, void *m1, void *m2, long row1, long row2
 			throw; \
 		} \
 	} \
-	type * NUMvector_readBinary_##storage (long lo, long hi, FILE *f) { \
+	type * NUMvector_readBinary_##storage (integer lo, integer hi, FILE *f) { \
 		type *result = nullptr; \
 		try { \
 			result = NUMvector <type> (lo, hi); \
-			for (long i = lo; i <= hi; i ++) { \
+			for (integer i = lo; i <= hi; i ++) { \
 				result [i] = binget##storage (f); \
 			} \
 			return result; \
@@ -241,12 +245,12 @@ bool NUMmatrix_equal (long elementSize, void *m1, void *m2, long row1, long row2
 			throw; \
 		} \
 	} \
-	void NUMmatrix_writeText_##storage (type **m, long row1, long row2, long col1, long col2, MelderFile file, const char32 *name) { \
+	void NUMmatrix_writeText_##storage (type **m, integer row1, integer row2, integer col1, integer col2, MelderFile file, const char32 *name) { \
 		texputintro (file, name, U" [] []: ", row2 >= row1 ? nullptr : U"(empty)", 0,0,0); \
 		if (row2 >= row1) { \
-			for (long irow = row1; irow <= row2; irow ++) { \
+			for (integer irow = row1; irow <= row2; irow ++) { \
 				texputintro (file, name, U" [", Melder_integer (irow), U"]:", 0,0); \
-				for (long icol = col1; icol <= col2; icol ++) { \
+				for (integer icol = col1; icol <= col2; icol ++) { \
 					texput##storage (file, m [irow] [icol], name, U" [", Melder_integer (irow), U"] [", Melder_integer (icol), U"]"); \
 				} \
 				texexdent (file); \
@@ -255,20 +259,20 @@ bool NUMmatrix_equal (long elementSize, void *m1, void *m2, long row1, long row2
 		texexdent (file); \
 		if (feof (file -> filePointer) || ferror (file -> filePointer)) Melder_throw (U"Write error."); \
 	} \
-	void NUMmatrix_writeBinary_##storage (type **m, long row1, long row2, long col1, long col2, FILE *f) { \
+	void NUMmatrix_writeBinary_##storage (type **m, integer row1, integer row2, integer col1, integer col2, FILE *f) { \
 		if (row2 >= row1) { \
-			for (long irow = row1; irow <= row2; irow ++) { \
-				for (long icol = col1; icol <= col2; icol ++) \
+			for (integer irow = row1; irow <= row2; irow ++) { \
+				for (integer icol = col1; icol <= col2; icol ++) \
 					binput##storage (m [irow] [icol], f); \
 			} \
 		} \
 		if (feof (f) || ferror (f)) Melder_throw (U"Write error."); \
 	} \
-	type ** NUMmatrix_readText_##storage (long row1, long row2, long col1, long col2, MelderReadText text, const char *name) { \
+	type ** NUMmatrix_readText_##storage (integer row1, integer row2, integer col1, integer col2, MelderReadText text, const char *name) { \
 		type **result = nullptr; \
 		try { \
 			result = NUMmatrix <type> (row1, row2, col1, col2); \
-			for (long irow = row1; irow <= row2; irow ++) for (long icol = col1; icol <= col2; icol ++) { \
+			for (integer irow = row1; irow <= row2; irow ++) for (integer icol = col1; icol <= col2; icol ++) { \
 				try { \
 					result [irow] [icol] = texget##storage (text); \
 				} catch (MelderError) { \
@@ -281,11 +285,11 @@ bool NUMmatrix_equal (long elementSize, void *m1, void *m2, long row1, long row2
 			throw; \
 		} \
 	} \
-	type ** NUMmatrix_readBinary_##storage (long row1, long row2, long col1, long col2, FILE *f) { \
+	type ** NUMmatrix_readBinary_##storage (integer row1, integer row2, integer col1, integer col2, FILE *f) { \
 		type **result = nullptr; \
 		try { \
 			result = NUMmatrix <type> (row1, row2, col1, col2); \
-			for (long irow = row1; irow <= row2; irow ++) for (long icol = col1; icol <= col2; icol ++) \
+			for (integer irow = row1; irow <= row2; irow ++) for (integer icol = col1; icol <= col2; icol ++) \
 				result [irow] [icol] = binget##storage (f); \
 			return result; \
 		} catch (MelderError) { \
@@ -294,16 +298,16 @@ bool NUMmatrix_equal (long elementSize, void *m1, void *m2, long row1, long row2
 		} \
 	}
 
-FUNCTION (signed char, i1)
-FUNCTION (int, i2)
-FUNCTION (long, i4)
-FUNCTION (unsigned char, u1)
-FUNCTION (unsigned int, u2)
-FUNCTION (unsigned long, u4)
-FUNCTION (double, r4)
-FUNCTION (double, r8)
-FUNCTION (fcomplex, c8)
-FUNCTION (dcomplex, c16)
+FUNCTION (signed char, i8)
+FUNCTION (int, i16)
+FUNCTION (long, i32)
+FUNCTION (unsigned char, u8)
+FUNCTION (unsigned int, u16)
+FUNCTION (unsigned long, u32)
+FUNCTION (double, r32)
+FUNCTION (double, r64)
+FUNCTION (dcomplex, c64)
+FUNCTION (dcomplex, c128)
 #undef FUNCTION
 
 /* End of file NUMarrays.cpp */
