@@ -1,6 +1,6 @@
 /* NUMsort.c
  *
- * Copyright (C) 1992-2011,2015 Paul Boersma
+ * Copyright (C) 1992-2011,2015,2017 Paul Boersma
  *
  * This code is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -16,15 +16,7 @@
  * along with this work. If not, see <http://www.gnu.org/licenses/>.
  */
 
-/*
- * pb 2002/06/24 removed NUMselect
- * pb 2007/08/10 NUMsort_strW
- * pb 2008/01/21 double
- * pb 2011/03/29 C++
- */
-
-#include "NUM.h"
-#include <string.h>
+#include "melder.h"
 
 /*
 	NUMsort uses heapsort.
@@ -39,63 +31,67 @@
 	Modification: there is no distinction between record and key.
 */
 
-#define MACRO_NUMsort(TYPE)  { \
-	long l, r, j, i; \
-	TYPE k; \
-	if (n < 2) return;   /* Already sorted. */ \
-	/* This n<2 step is absent from Press et al.'s implementation, */ \
-	/* which will therefore not terminate on if(--ir==1). */ \
-	/* Knuth's initial assumption is now fulfilled: n >= 2. */ \
-if (n == 2) { \
-	if (a [1] > a [2]) { TYPE min = a [2]; a [2] = a [1]; a [1] = min; } \
-	return; \
-} \
-if (n <= 12) { \
-	for (i = 1; i < n; i ++) { \
-		TYPE min = a [i]; \
-		long pmin = i; \
-		for (j = i + 1; j <= n; j ++) if (a [j] < min) { \
-			min = a [j]; \
-			pmin = j; \
+#define MACRO_NUMsort(DataType, dataExpression, CounterType, sizeExpression) \
+	{/* scope */ \
+		DataType *_x = dataExpression; \
+		CounterType _n = sizeExpression; \
+		if (_n < 2) return;   /* Already sorted. */ \
+		/* This `n < 2` step is absent from Press et al.'s implementation,      */ \
+		/* which will therefore not terminate on `if (_r == 1)`.                */ \
+		/* Knuth's initial assumption is now fulfilled: n >= 2.                 */ \
+		if (_n == 2) { \
+			if (_x [1] > _x [2]) { DataType _min = _x [2]; _x [2] = _x [1]; _x [1] = _min; } \
+		} else if (_n <= 44) { \
+			for (CounterType _i = 1; _i < _n; _i ++) { \
+				DataType _min = _x [_i]; \
+				CounterType _pmin = _i; \
+				for (CounterType _j = _i + 1; _j <= _n; _j ++) if (_x [_j] < _min) { \
+					_min = _x [_j]; \
+					_pmin = _j; \
+				} \
+				_x [_pmin] = _x [_i]; \
+				_x [_i] = _min; \
+			} \
+		} else { \
+			CounterType _l = (_n >> 1) + 1; \
+			CounterType _r = _n; \
+			for (;;) { \
+				DataType _k; \
+				if (_l > 1) { \
+					_l --; \
+					_k = _x [_l]; \
+				} else /* _l == 1 */ { \
+					_k = _x [_r]; \
+					_x [_r] = _x [1]; \
+					_r --; \
+					if (_r == 1) { _x [1] = _k; return; } \
+				} \
+				CounterType _j = _l; \
+				CounterType _i; \
+				for (;;) { \
+					_i = _j; \
+					_j = _j << 1; \
+					if (_j > _r) break; \
+					if (_j < _r && _x [_j] < _x [_j + 1]) _j ++; \
+					if (_k >= _x [_j]) break; \
+					_x [_i] = _x [_j]; \
+				} \
+				_x [_i] = _k; \
+			} \
 		} \
-		a [pmin] = a [i]; \
-		a [i] = min; \
-	} \
-	return; \
-} \
-	l = (n >> 1) + 1; \
-	r = n; \
-	for (;;) { \
-		if (l > 1) { \
-			l --; \
-			k = a [l]; \
-		} else /* l == 1 */ { \
-			k = a [r]; \
-			a [r] = a [1]; \
-			r --; \
-			if (r == 1) { a [1] = k; return; } \
-		} \
-		j = l; \
-		for (;;) { \
-			i = j; \
-			j = j << 1; \
-			if (j > r) break; \
-			if (j < r && a [j] < a [j + 1]) j ++; \
-			if (k >= a [j]) break; \
-			a [i] = a [j]; \
-		} \
-		a [i] = k; \
-	} \
+	}
+
+void NUMsort_d (long n, double a []) {
+	MACRO_NUMsort (double, a, integer, n)
 }
 
-void NUMsort_d (long n, double a [])
-	MACRO_NUMsort (double)
+void NUMsort_i (long n, int a []) {
+	MACRO_NUMsort (int, a, integer, n)
+}
 
-void NUMsort_i (long n, int a [])
-	MACRO_NUMsort (int)
-
-void NUMsort_l (long n, long a [])
-	MACRO_NUMsort (long)
+void NUMsort_l (long n, long a []) {
+	MACRO_NUMsort (long, a, integer, n)
+}
 
 void NUMsort_str (long n, char32 *a []) {
 	long l, r, j, i;
