@@ -4,19 +4,18 @@
  *
  * Copyright (C) 1996-2011,2012,2015 Paul Boersma
  *
- * This program is free software; you can redistribute it and/or modify
+ * This code is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or (at
  * your option) any later version.
  *
- * This program is distributed in the hope that it will be useful, but
+ * This code is distributed in the hope that it will be useful, but
  * WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  * See the GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ * along with this work. If not, see <http://www.gnu.org/licenses/>.
  */
 
 #include "HyperPage.h"
@@ -37,7 +36,7 @@ Thing_define (ButtonEditor, HyperPage) {
 		override;
 };
 
-ButtonEditor ButtonEditor_create ();
+autoButtonEditor ButtonEditor_create ();
 
 /* End of file ButtonEditor.h */
 #endif
