@@ -35,16 +35,6 @@ static Data_Description Class_getDescription (ClassInfo table) {
 	return ((Daata) _Thing_dummyObject (table)) -> v_description ();
 }
 
-/*static const char * typeStrings [] = { "none",
-	"byte", "int", "long", "ubyte", "ushort", "uint", "ulong", "bool",
-	"float", "double", "fcomplex", "dcomplex",
-	"enum", "lenum", "boolean", "question", "stringw", "lstringw",
-	"struct", "widget", "object", "collection" };*/
-static int stringLengths [] = { 0,
-	4, 6, 11, 3, 5, 10, 1,
-	15, 27, 35, 59,
-	33, 33, 8, 6, 60, 60 };
-
 static void VectorEditor_create (DataEditor root, const char32 *title, void *address,
 	Data_Description description, long minimum, long maximum);
 
@@ -137,6 +127,22 @@ static void gui_button_cb_change (DataSubEditor me, GuiButtonEvent /* event */)
 						}
 					}
 				} break;
+				case int16wa: {
+					int16 oldValue = * (int16 *) my d_fieldData [irow]. address;
+					int64 newValue = Melder_atoi (text);
+					if (newValue != oldValue) {
+						Data_Description numberUse = DataSubEditor_findNumberUse (me, my d_fieldData [irow]. description -> name);
+						if (numberUse) {
+							Melder_flushError (U"Changing field \"", strip_d (my d_fieldData [irow]. description -> name),
+								U"\" would damage the array \"", strip_d (numberUse -> name), U"\".");
+						} else if (newValue < INT16_MIN || newValue > INT16_MAX) {
+							Melder_flushError (U"Field \"", strip_d (my d_fieldData [irow]. description -> name),
+								U"\" can have no values less than ", INT16_MIN, U" or greater than ", INT16_MAX, U".");
+						} else {
+							* (int16 *) my d_fieldData [irow]. address = (int16) newValue;   // guarded conversion
+						}
+					}
+				} break;
 				case intwa: {
 					int oldValue = * (int *) my d_fieldData [irow]. address, newValue = Melder_atoi (text);
 					if (newValue != oldValue) {
@@ -161,14 +167,26 @@ static void gui_button_cb_change (DataSubEditor me, GuiButtonEvent /* event */)
 						}
 					}
 				} break;
+				case integerwa: {
+					integer oldValue = * (integer *) my d_fieldData [irow]. address, newValue = Melder_atoi (text);
+					if (newValue != oldValue) {
+						Data_Description numberUse = DataSubEditor_findNumberUse (me, my d_fieldData [irow]. description -> name);
+						if (numberUse) {
+							Melder_flushError (U"Changing field \"", strip_d (my d_fieldData [irow]. description -> name),
+								U"\" would damage the array \"", strip_d (numberUse -> name), U"\".");
+						} else {
+							* (integer *) my d_fieldData [irow]. address = newValue;
+						}
+					}
+				} break;
 				case ubytewa: { * (unsigned char *) my d_fieldData [irow]. address = (uint8) Melder_atoi (text); } break;
 				case uintwa: { * (unsigned int *) my d_fieldData [irow]. address = Melder_atoi (text); } break;
 				case ulongwa: { * (unsigned long *) my d_fieldData [irow]. address = (unsigned long) Melder_atoi (text); } break;
 				case boolwa: { * (bool *) my d_fieldData [irow]. address = Melder_atoi (text); } break;
 				case floatwa: { * (double *) my d_fieldData [irow]. address = Melder_atof (text); } break;
 				case doublewa: { * (double *) my d_fieldData [irow]. address = Melder_atof (text); } break;
-				case fcomplexwa: { fcomplex *x = (fcomplex *) my d_fieldData [irow]. address;
-					sscanf (Melder_peek32to8 (text), "%f + %f i", & x -> re, & x -> im); } break;
+				case fcomplexwa: { dcomplex *x = (dcomplex *) my d_fieldData [irow]. address;
+					sscanf (Melder_peek32to8 (text), "%lf + %lf i", & x -> re, & x -> im); } break;
 				case dcomplexwa: { dcomplex *x = (dcomplex *) my d_fieldData [irow]. address;
 					sscanf (Melder_peek32to8 (text), "%lf + %lf i", & x -> re, & x -> im); } break;
 				case enumwa: {
@@ -186,14 +204,26 @@ static void gui_button_cb_change (DataSubEditor me, GuiButtonEvent /* event */)
 					* (signed short *) my d_fieldData [irow]. address = (signed short) value;
 				} break;
 				case booleanwa: {
-					int value = str32nequ (text, U"<true>", 6) ? 1 : str32nequ (text, U"<false>", 7) ? 0 : -1;
-					if (value < 0) goto error;
-					* (signed char *) my d_fieldData [irow]. address = (signed char) value;
+					bool value;
+					if (str32nequ (text, U"<true>", 6)) {
+						value = true;
+					} else if (str32nequ (text, U"<false>", 7)) {
+						value = false;
+					} else {
+						goto error;
+					}
+					* (bool *) my d_fieldData [irow]. address = value;
 				} break;
 				case questionwa: {
-					int value = str32nequ (text, U"<yes>", 5) ? 1 : str32nequ (text, U"<no>", 4) ? 0 : -1;
-					if (value < 0) goto error;
-					* (signed char *) my d_fieldData [irow]. address = (signed char) value;
+					bool value;
+					if (str32nequ (text, U"<yes>", 5)) {
+						value = true;
+					} else if (str32nequ (text, U"<no>", 4)) {
+						value = false;
+					} else {
+						goto error;
+					}
+					* (bool *) my d_fieldData [irow]. address = value;
 				} break;
 				case stringwa:
 				case lstringwa: {
@@ -232,7 +262,7 @@ static void gui_cb_scroll (DataSubEditor me, GuiScrollBarEvent event) {
 
 static void gui_button_cb_open (DataSubEditor me, GuiButtonEvent event) {
 	int ifield = 0;
-	static MelderString name { 0 };
+	static MelderString name { };
 	MelderString_empty (& name);
 
 	/* Identify the pressed button; it must be one of those created in the list. */
@@ -340,23 +370,23 @@ long structStructEditor :: v_countFields () {
 
 static const char32 * singleTypeToText (void *address, int type, void *tagType, MelderString *buffer) {
 	switch (type) {
-		case bytewa:   MelderString_append (buffer, Melder_integer (* (signed char *)    address)); break;
-		case intwa:    MelderString_append (buffer, Melder_integer (* (int *)            address)); break;
-		case longwa:   MelderString_append (buffer, Melder_integer (* (long *)           address)); break;
-		case ubytewa:  MelderString_append (buffer, Melder_integer (* (unsigned char *)  address)); break;
-		case uintwa:   MelderString_append (buffer, Melder_integer (* (unsigned int *)   address)); break;
-		case ulongwa:  MelderString_append (buffer, Melder_integer (* (unsigned long *)  address)); break;
-		case boolwa:   MelderString_append (buffer, Melder_integer (* (bool *)           address)); break;
-		case floatwa:  MelderString_append (buffer, Melder_single  (* (double *)         address)); break;
-		case doublewa: MelderString_append (buffer, Melder_double  (* (double *)         address)); break;
-		case fcomplexwa: { fcomplex value = * (fcomplex *) address;
-			MelderString_append (buffer, Melder_single (value. re), U" + ", Melder_single (value. im), U" i"); } break;
-		case dcomplexwa: { dcomplex value = * (dcomplex *) address;
-			MelderString_append (buffer, Melder_double (value. re), U" + ", Melder_double (value. im), U" i"); } break;
+		case bytewa:     MelderString_append (buffer, Melder_integer  (* (signed char *)    address)); break;
+		case int16wa:    MelderString_append (buffer, Melder_integer  (* (int16 *)          address)); break;
+		case intwa:      MelderString_append (buffer, Melder_integer  (* (int *)            address)); break;
+		case longwa:     MelderString_append (buffer, Melder_integer  (* (long *)           address)); break;
+		case integerwa:  MelderString_append (buffer, Melder_integer  (* (integer *)        address)); break;
+		case ubytewa:    MelderString_append (buffer, Melder_integer  (* (unsigned char *)  address)); break;
+		case uintwa:     MelderString_append (buffer, Melder_integer  (* (unsigned int *)   address)); break;
+		case ulongwa:    MelderString_append (buffer, Melder_integer  (* (unsigned long *)  address)); break;
+		case boolwa:     MelderString_append (buffer, Melder_integer  (* (bool *)           address)); break;
+		case floatwa:    MelderString_append (buffer, Melder_single   (* (double *)         address)); break;
+		case doublewa:   MelderString_append (buffer, Melder_double   (* (double *)         address)); break;
+		case fcomplexwa: MelderString_append (buffer, Melder_scomplex (* (dcomplex *)       address)); break;
+		case dcomplexwa: MelderString_append (buffer, Melder_dcomplex (* (dcomplex *)       address)); break;
 		case enumwa:  MelderString_append (buffer, U"<", ((const char32 * (*) (int)) tagType) (* (signed char *)  address), U">"); break;
 		case lenumwa: MelderString_append (buffer, U"<", ((const char32 * (*) (int)) tagType) (* (signed short *) address), U">"); break;
-		case booleanwa:  MelderString_append (buffer, * (signed char *) address ? U"<true>" : U"<false>"); break;
-		case questionwa: MelderString_append (buffer, * (signed char *) address ? U"<yes>"  : U"<no>"   ); break;
+		case booleanwa:  MelderString_append (buffer, * (bool *) address ? U"<true>" : U"<false>"); break;
+		case questionwa: MelderString_append (buffer, * (bool *) address ? U"<yes>"  : U"<no>"   ); break;
 		case stringwa:
 		case lstringwa: {
 			char32 *string = * (char32 **) address;
@@ -391,7 +421,7 @@ static void showStructMember (
 	/* Show the value (for a single type) or a button (for a composite type). */
 	if (isSingleType) {
 		#if motif
-			XtVaSetValues (fieldData -> text -> d_widget, XmNcolumns, stringLengths [type], nullptr);   // TODO: change to GuiObject_size
+			XtVaSetValues (fieldData -> text -> d_widget, XmNcolumns, 60, nullptr);   // TODO: change to GuiObject_size
 		#endif
 		autoMelderString buffer;
 		const char32 *text = singleTypeToText (memberAddress, type, memberDescription -> tagType, & buffer);
@@ -554,14 +584,14 @@ void structVectorEditor :: v_showMembers () {
 			autoMelderString buffer;
 			const char32 *text = singleTypeToText (elementAddress, type, d_description -> tagType, & buffer);
 			#if motif
-				XtVaSetValues (fieldData -> text -> d_widget, XmNcolumns, stringLengths [type], nullptr);   // TODO: change to GuiObject_size
+				XtVaSetValues (fieldData -> text -> d_widget, XmNcolumns, 60, nullptr);   // TODO: change to GuiObject_size
 			#endif
 			GuiText_setString (fieldData -> text, text);
 			GuiThing_show (fieldData -> text);
 			fieldData -> address = elementAddress;
 			fieldData -> description = d_description;
 		} else if (type == structwa) {
-			static MelderString history { 0 };
+			static MelderString history { };
 			MelderString_copy (& history, name);
 
 			/* Replace things like [1..100] by things like [19]. */
@@ -584,7 +614,7 @@ void structVectorEditor :: v_showMembers () {
 			}
 			showStructMembers (this, elementAddress, * (Data_Description *) d_description -> tagType, skip, history.string);
 		} else if (type == objectwa || type == autoobjectwa) {
-			static MelderString history { 0 };
+			static MelderString history { };
 			MelderString_copy (& history, name);
 			if (history.string [history.length - 1] == U']') {
 				char32 *openingBracket = str32rchr (history.string, U'[');
@@ -660,7 +690,7 @@ void structMatrixEditor :: v_showMembers () {
 			autoMelderString buffer;
 			const char32 *text = singleTypeToText (elementAddress, type, d_description -> tagType, & buffer);
 			#if motif
-				XtVaSetValues (fieldData -> text -> d_widget, XmNcolumns, stringLengths [type], nullptr);   // TODO: change to GuiObject_size
+				XtVaSetValues (fieldData -> text -> d_widget, XmNcolumns, 60, nullptr);   // TODO: change to GuiObject_size
 			#endif
 			GuiText_setString (fieldData -> text, text);
 			GuiThing_show (fieldData -> text);
