@@ -34,7 +34,7 @@ Thing_implement (Graphics, Thing, 0);
 enum kGraphics_cjkFontStyle theGraphicsCjkFontStyle;
 
 void Graphics_prefs () {
-	Preferences_addEnum (U"Graphics.cjkFontStyle", & theGraphicsCjkFontStyle, kGraphics_cjkFontStyle, kGraphics_cjkFontStyle_DEFAULT);
+	Preferences_addEnum (U"Graphics.cjkFontStyle", & theGraphicsCjkFontStyle, kGraphics_cjkFontStyle, (int) kGraphics_cjkFontStyle::DEFAULT);
 }
 
 void structGraphics :: v_destroy () noexcept {
@@ -70,25 +70,25 @@ static void computeTrafo (Graphics me) {
 void Graphics_init (Graphics me, int resolution) {
 	my resolution = resolution;
 	if (resolution == 96) {
-		my resolutionNumber = kGraphics_resolution_96;
+		my resolutionNumber = kGraphics_resolution::DPI_96;
 	} else if (resolution == 100) {
-		my resolutionNumber = kGraphics_resolution_100;
+		my resolutionNumber = kGraphics_resolution::DPI_100;
 	} else if (resolution == 180) {
-		my resolutionNumber = kGraphics_resolution_180;
+		my resolutionNumber = kGraphics_resolution::DPI_180;
 	} else if (resolution == 200) {
-		my resolutionNumber = kGraphics_resolution_200;
+		my resolutionNumber = kGraphics_resolution::DPI_200;
 	} else if (resolution == 300) {
-		my resolutionNumber = kGraphics_resolution_300;
+		my resolutionNumber = kGraphics_resolution::DPI_300;
 	} else if (resolution == 360) {
-		my resolutionNumber = kGraphics_resolution_360;
+		my resolutionNumber = kGraphics_resolution::DPI_360;
 	} else if (resolution == 600) {
-		my resolutionNumber = kGraphics_resolution_600;
+		my resolutionNumber = kGraphics_resolution::DPI_600;
 	} else if (resolution == 720) {
-		my resolutionNumber = kGraphics_resolution_720;
+		my resolutionNumber = kGraphics_resolution::DPI_720;
 	} else if (resolution == 900) {
-		my resolutionNumber = kGraphics_resolution_900;
+		my resolutionNumber = kGraphics_resolution::DPI_900;
 	} else if (resolution == 1200) {
-		my resolutionNumber = kGraphics_resolution_1200;
+		my resolutionNumber = kGraphics_resolution::DPI_1200;
 	} else {
 		Melder_fatal (U"Unsupported resolution ", resolution, U" dpi.");
 	}
@@ -102,7 +102,7 @@ void Graphics_init (Graphics me, int resolution) {
 	my lineWidth = 1.0;
 	my arrowSize = 1.0;
 	my speckleSize = 1.0;
-	my font = kGraphics_font_HELVETICA;
+	my font = kGraphics_font::HELVETICA;
 	my fontSize = 10;
 	my fontStyle = Graphics_NORMAL;
 	my record = nullptr;
