@@ -1,6 +1,6 @@
 /* Graphics_enums.h
  *
- * Copyright (C) 1992-2007,2013,2014,2015 Paul Boersma
+ * Copyright (C) 1992-2007,2013,2014,2015,2017 Paul Boersma
  *
  * This code is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -31,17 +31,17 @@ enums_begin (kGraphics_horizontalAlignment, 0)
 enums_end (kGraphics_horizontalAlignment, 2, CENTRE)
 
 enums_begin (kGraphics_resolution, 0)
-	enums_add (kGraphics_resolution, 0,  96, U"96 dpi")
-	enums_add (kGraphics_resolution, 1, 100, U"100 dpi")
-	enums_add (kGraphics_resolution, 2, 180, U"180 dpi")
-	enums_add (kGraphics_resolution, 3, 200, U"200 dpi")
-	enums_add (kGraphics_resolution, 4, 300, U"300 dpi")
-	enums_add (kGraphics_resolution, 5, 360, U"360 dpi")
-	enums_add (kGraphics_resolution, 6, 600, U"600 dpi")
-	enums_add (kGraphics_resolution, 7, 720, U"720 dpi")
-	enums_add (kGraphics_resolution, 8, 900, U"900 dpi")
-	enums_add (kGraphics_resolution, 9, 1200, U"1200 dpi")
-enums_end (kGraphics_resolution, 9, 100)
+	enums_add (kGraphics_resolution, 0, DPI_96, U"96 dpi")
+	enums_add (kGraphics_resolution, 1, DPI_100, U"100 dpi")
+	enums_add (kGraphics_resolution, 2, DPI_180, U"180 dpi")
+	enums_add (kGraphics_resolution, 3, DPI_200, U"200 dpi")
+	enums_add (kGraphics_resolution, 4, DPI_300, U"300 dpi")
+	enums_add (kGraphics_resolution, 5, DPI_360, U"360 dpi")
+	enums_add (kGraphics_resolution, 6, DPI_600, U"600 dpi")
+	enums_add (kGraphics_resolution, 7, DPI_720, U"720 dpi")
+	enums_add (kGraphics_resolution, 8, DPI_900, U"900 dpi")
+	enums_add (kGraphics_resolution, 9, DPI_1200, U"1200 dpi")
+enums_end (kGraphics_resolution, 9, DPI_100)
 
 enums_begin (kGraphics_colourScale, 0)
 	enums_add (kGraphics_colourScale, 0, GREY, U"grey")
