@@ -221,13 +221,13 @@ static void _GraphicsScreen_cellArrayOrImage (GraphicsScreen me, double **z_floa
 		#elif quartz
 			#define ROW_START_ADDRESS  (imageData + (clipy1 - 1 - yDC) * bytesPerRow)
 			#define PUT_PIXEL \
-				if (my colourScale == kGraphics_colourScale_GREY) { \
+				if (my colourScale == kGraphics_colourScale::GREY) { \
 					unsigned char kar = value <= 0 ? 0 : value >= 255 ? 255 : (int) value; \
 					*pixelAddress ++ = kar; \
 					*pixelAddress ++ = kar; \
 					*pixelAddress ++ = kar; \
 					*pixelAddress ++ = 0; \
-				} else if (my colourScale == kGraphics_colourScale_BLUE_TO_RED) { \
+				} else if (my colourScale == kGraphics_colourScale::BLUE_TO_RED) { \
 					if (value < 0.0) { \
 						*pixelAddress ++ = 0; \
 						*pixelAddress ++ = 0; \
@@ -700,7 +700,7 @@ static void _GraphicsScreen_imageFromFile (GraphicsScreen me, const char32 *rela
 	long x1DC = wdx (x1), x2DC = wdx (x2), y1DC = wdy (y1), y2DC = wdy (y2);
 	long width = x2DC - x1DC, height = my yIsZeroAtTheTop ? y1DC - y2DC : y2DC - y1DC;
 	#if 0
-		structMelderFile file = { 0 };
+		structMelderFile file { };
 		Melder_relativePathToFile (relativeFileName, & file);
 		try {
 			autoPhoto photo = Photo_readFromImageFile (& file);
@@ -734,7 +734,7 @@ static void _GraphicsScreen_imageFromFile (GraphicsScreen me, const char32 *rela
 		}
 	#elif gdi
 		if (my d_useGdiplus) {
-			structMelderFile file = { 0 };
+			structMelderFile file { };
 			Melder_relativePathToFile (relativeFileName, & file);
 			Gdiplus::Bitmap image (Melder_peek32toW (file. path));
 			if (x1 == x2 && y1 == y2) {
@@ -753,7 +753,7 @@ static void _GraphicsScreen_imageFromFile (GraphicsScreen me, const char32 *rela
 		} else {
 		}
 	#elif quartz
-		structMelderFile file = { 0 };
+		structMelderFile file { };
 		Melder_relativePathToFile (relativeFileName, & file);
 		char utf8 [500];
 		Melder_str32To8bitFileRepresentation_inline (file. path, utf8);
