@@ -1,6 +1,6 @@
 /* GuiProgressBar.cpp
  *
- * Copyright (C) 1993-2012,2013,2015 Paul Boersma, 2008 Stefan de Konink
+ * Copyright (C) 1993-2012,2013,2015,2017 Paul Boersma, 2008 Stefan de Konink
  *
  * This code is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -26,6 +26,14 @@ Thing_implement (GuiProgressBar, GuiControl, 0);
 		iam (GuiProgressBar);
 		Melder_free (me);
 	}
+#elif motif
+	static void _guiMotifProgressBar_destroyCallback (GuiObject widget, XtPointer void_me, XtPointer call) {
+		(void) widget; (void) call;
+		trace (U"destroying a progress bar");
+		iam (GuiProgressBar);
+		//forget (me);   // because I am already forgotten in the scale::destroy callback
+		trace (U"destroyed a progress bar");
+	}
 #elif cocoa
 	@implementation GuiCocoaProgressBar {
 		GuiProgressBar d_userData;
@@ -44,14 +52,6 @@ Thing_implement (GuiProgressBar, GuiControl, 0);
 		d_userData = static_cast <GuiProgressBar> (userData);
 	}
 	@end
-#elif motif
-	static void _guiMotifProgressBar_destroyCallback (GuiObject widget, XtPointer void_me, XtPointer call) {
-		(void) widget; (void) call;
-		trace (U"destroying a progress bar");
-		iam (GuiProgressBar);
-		//forget (me);   // because I am already forgotten in the scale::destroy callback
-		trace (U"destroyed a progress bar");
-	}
 #endif
 
 GuiProgressBar GuiProgressBar_create (GuiForm parent, int left, int right, int top, int bottom, uint32 /* flags */)
@@ -63,6 +63,14 @@ GuiProgressBar GuiProgressBar_create (GuiForm parent, int left, int right, int t
 		my d_widget = gtk_progress_bar_new ();
 		_GuiObject_setUserData (my d_widget, me.get());
 		my v_positionInForm (my d_widget, left, right, top, bottom, parent);
+	#elif motif
+		my d_widget = XmCreateScale (parent -> d_widget, "scale", nullptr, 0);
+		_GuiObject_setUserData (my d_widget, me.get());
+		my v_positionInForm (my d_widget, left, right, top, bottom, parent);
+		XtVaSetValues (my d_widget, XmNorientation, XmHORIZONTAL,
+			XmNminimum, 0, XmNmaximum, 10000, XmNvalue, 0,
+			//XmNscaleHeight, 20,
+			nullptr);
 	#elif cocoa
 		my d_cocoaProgressBar = [[GuiCocoaProgressBar alloc] init];
 		my d_widget = my d_cocoaProgressBar;
@@ -70,19 +78,6 @@ GuiProgressBar GuiProgressBar_create (GuiForm parent, int left, int right, int t
 		[my d_cocoaProgressBar   setUserData: me.get()];
 		[my d_cocoaProgressBar   setIndeterminate: false];
 		[my d_cocoaProgressBar   setMaxValue: 1.0];
-	#elif motif
-		my d_widget = XmCreateScale (parent -> d_widget, "scale", nullptr, 0);
-		_GuiObject_setUserData (my d_widget, me.get());
-		my v_positionInForm (my d_widget, left, right, top, bottom, parent);
-		XtVaSetValues (my d_widget, XmNorientation, XmHORIZONTAL,
-			XmNminimum, 0, XmNmaximum, 10000, XmNvalue, 0,
-			#if ! defined (macintosh)
-				//XmNscaleHeight, 20,
-			#endif
-			#ifdef macintosh
-				//XmNscaleWidth, 340,
-			#endif
-			nullptr);
 	#endif
 
 	#if gtk
@@ -105,10 +100,10 @@ GuiProgressBar GuiProgressBar_createShown (GuiForm parent, int left, int right,
 void GuiProgressBar_setValue (GuiProgressBar me, double value) {
 	#if gtk
 		gtk_progress_bar_set_fraction (GTK_PROGRESS_BAR (my d_widget), value);
-	#elif cocoa
-		[my d_cocoaProgressBar   setDoubleValue: value];
 	#elif motif
 		XmScaleSetValue (my d_widget, round (value * 10000));
+	#elif cocoa
+		[my d_cocoaProgressBar   setDoubleValue: value];
 	#endif
 }
 
