@@ -2,7 +2,7 @@
 #define _ManPagesM_h_
 /* ManPagesM.h
  *
- * Copyright (C) 1996-2011,2014,2015 Paul Boersma
+ * Copyright (C) 1996-2011,2014,2015,2017 Paul Boersma
  *
  * This code is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -26,32 +26,32 @@
 
 #define MAN_BEGIN(t,a,d)  { const char32 *title = t, *author = a; long date = d; \
 	static struct structManPage_Paragraph page [] = {
-#define INTRO(text)  { kManPage_type_INTRO, text },
-#define ENTRY(text)  { kManPage_type_ENTRY, text },
-#define NORMAL(text)  { kManPage_type_NORMAL, text },
-#define LIST_ITEM(text)  { kManPage_type_LIST_ITEM, text },
-#define LIST_ITEM1(text)  { kManPage_type_LIST_ITEM1, text },
-#define LIST_ITEM2(text)  { kManPage_type_LIST_ITEM2, text },
-#define LIST_ITEM3(text)  { kManPage_type_LIST_ITEM3, text },
-#define TAG(text)  { kManPage_type_TAG, text },
-#define TAG1(text)  { kManPage_type_TAG1, text },
-#define TAG2(text)  { kManPage_type_TAG2, text },
-#define TAG3(text)  { kManPage_type_TAG3, text },
-#define DEFINITION(text)  { kManPage_type_DEFINITION, text },
-#define DEFINITION1(text)  { kManPage_type_DEFINITION1, text },
-#define DEFINITION2(text)  { kManPage_type_DEFINITION2, text },
-#define DEFINITION3(text)  { kManPage_type_DEFINITION3, text },
-#define CODE(text)  { kManPage_type_CODE, text },
-#define CODE1(text)  { kManPage_type_CODE1, text },
-#define CODE2(text)  { kManPage_type_CODE2, text },
-#define CODE3(text)  { kManPage_type_CODE3, text },
-#define CODE4(text)  { kManPage_type_CODE4, text },
-#define CODE5(text)  { kManPage_type_CODE5, text },
-#define PROTOTYPE(text)  { kManPage_type_PROTOTYPE, text },
-#define FORMULA(text)  { kManPage_type_FORMULA, text },
-#define PICTURE(width,height,draw)  { kManPage_type_PICTURE, nullptr, width, height, draw },
-#define SCRIPT(width,height,text)  { kManPage_type_SCRIPT, text, width, height },
-#define MAN_END  { 0 } }; ManPages_addPage (me, title, author, date, page); }
+#define INTRO(text)  { kManPage_type::INTRO, text, 0.0, 0.0, nullptr },
+#define ENTRY(text)  { kManPage_type::ENTRY, text, 0.0, 0.0, nullptr },
+#define NORMAL(text)  { kManPage_type::NORMAL, text, 0.0, 0.0, nullptr },
+#define LIST_ITEM(text)  { kManPage_type::LIST_ITEM, text, 0.0, 0.0, nullptr },
+#define LIST_ITEM1(text)  { kManPage_type::LIST_ITEM1, text, 0.0, 0.0, nullptr },
+#define LIST_ITEM2(text)  { kManPage_type::LIST_ITEM2, text, 0.0, 0.0, nullptr },
+#define LIST_ITEM3(text)  { kManPage_type::LIST_ITEM3, text, 0.0, 0.0, nullptr },
+#define TAG(text)  { kManPage_type::TAG, text, 0.0, 0.0, nullptr },
+#define TAG1(text)  { kManPage_type::TAG1, text, 0.0, 0.0, nullptr },
+#define TAG2(text)  { kManPage_type::TAG2, text, 0.0, 0.0, nullptr },
+#define TAG3(text)  { kManPage_type::TAG3, text, 0.0, 0.0, nullptr },
+#define DEFINITION(text)  { kManPage_type::DEFINITION, text, 0.0, 0.0, nullptr },
+#define DEFINITION1(text)  { kManPage_type::DEFINITION1, text, 0.0, 0.0, nullptr },
+#define DEFINITION2(text)  { kManPage_type::DEFINITION2, text, 0.0, 0.0, nullptr },
+#define DEFINITION3(text)  { kManPage_type::DEFINITION3, text, 0.0, 0.0, nullptr },
+#define CODE(text)  { kManPage_type::CODE, text, 0.0, 0.0, nullptr },
+#define CODE1(text)  { kManPage_type::CODE1, text, 0.0, 0.0, nullptr },
+#define CODE2(text)  { kManPage_type::CODE2, text, 0.0, 0.0, nullptr },
+#define CODE3(text)  { kManPage_type::CODE3, text, 0.0, 0.0, nullptr },
+#define CODE4(text)  { kManPage_type::CODE4, text, 0.0, 0.0, nullptr },
+#define CODE5(text)  { kManPage_type::CODE5, text, 0.0, 0.0, nullptr },
+#define PROTOTYPE(text)  { kManPage_type::PROTOTYPE, text, 0.0, 0.0, nullptr },
+#define FORMULA(text)  { kManPage_type::FORMULA, text, 0.0, 0.0, nullptr },
+#define PICTURE(width,height,draw)  { kManPage_type::PICTURE, nullptr, width, height, draw },
+#define SCRIPT(width,height,text)  { kManPage_type::SCRIPT, text, width, height, nullptr },
+#define MAN_END  { } }; ManPages_addPage (me, title, author, date, page); }
 
 #define Manual_DRAW_WINDOW(height,title,menu) \
 	"Select inner viewport... 0.2 5.8 0.2 " #height "-0.2\n" \
