@@ -132,7 +132,6 @@ static autoStrings Strings_createAsFileOrDirectoryList (const char32 *path /* ca
 				Melder_throw (U"Cannot open directory ", searchDirectory. string, U".");
 			//Melder_casual (U"opened");
 			autoStrings me = Thing_new (Strings);
-			my strings = NUMvector <char32 *> (1, 1000000);
 			struct dirent *entry;
 			while (!! (entry = readdir (d))) {
 				MelderString_copy (& filePath, searchDirectory. string [0] ? searchDirectory. string : U".");
@@ -158,7 +157,7 @@ static autoStrings Strings_createAsFileOrDirectoryList (const char32 *path /* ca
 						(left. length == 0 || str32nequ (buffer32, left. string, left. length)) &&
 						(right. length == 0 || (length >= right. length && str32equ (buffer32 + (length - right. length), right. string))))
 					{
-						my strings [++ my numberOfStrings] = Melder_dup (buffer32);
+						Strings_insert (me.get(), 0, buffer32);
 					}
 				}
 			}
@@ -176,7 +175,6 @@ static autoStrings Strings_createAsFileOrDirectoryList (const char32 *path /* ca
 			bool hasAsterisk = !! str32chr (path, U'*');
 			bool endsInSeparator = ( len != 0 && path [len - 1] == U'\\' );
 			autoStrings me = Thing_new (Strings);
-			my strings = NUMvector <char32 *> (1, 1000000);
 			Melder_sprint (searchPath, kMelder_MAXPATH+1, path, hasAsterisk || endsInSeparator ? U"" : U"\\", hasAsterisk ? U"" : U"*");
 			WIN32_FIND_DATAW findData;
 			HANDLE searchHandle = FindFirstFileW (Melder_peek32toW (searchPath), & findData);
@@ -188,7 +186,7 @@ static autoStrings Strings_createAsFileOrDirectoryList (const char32 *path /* ca
 							(findData. dwFileAttributes & FILE_ATTRIBUTE_DIRECTORY) != 0))
 					{
 						if (findData. cFileName [0] != L'.') {
-							my strings [++ my numberOfStrings] = Melder_dup (Melder_peekWto32 (findData. cFileName));
+							Strings_insert (me.get(), 0, Melder_peekWto32 (findData. cFileName));
 						}
 					}
 				} while (FindNextFileW (searchHandle, & findData));
@@ -339,14 +337,20 @@ void Strings_insert (Strings me, long position, const char32 *text) {
 	 * Create without change.
 	 */
 	autostring32 newString = Melder_dup (text);
+	autoNUMvector <char32 *> newStrings (1, my numberOfStrings + 1);
 	/*
 	 * Change without error.
 	 */
-	for (long i = my numberOfStrings + 1; i > position; i --) {
-		my strings [i] = my strings [i - 1];
+	for (long i = 1; i < position; i ++) {
+		newStrings [i] = my strings [i];
 	}
-	my strings [position] = newString.transfer();
+	newStrings [position] = newString.transfer();
 	my numberOfStrings ++;
+	for (long i = position + 1; i <= my numberOfStrings; i ++) {
+		newStrings [i] = my strings [i - 1];
+	}
+	NUMvector_free (my strings, 1);
+	my strings = newStrings.transfer();
 }
 
 /* End of file Strings.cpp */
