@@ -2,7 +2,7 @@
 #define _Thing_h_
 /* Thing.h
  *
- * Copyright (C) 1992-2011,2012,2013,2014,2015,2016 Paul Boersma
+ * Copyright (C) 1992-2011,2012,2013,2014,2015,2016,2017 Paul Boersma
  *
  * This code is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -21,34 +21,15 @@
 /* The root class of all objects. */
 
 /* Anyone who uses Thing can also use: */
-	/* Arrays with any bounds and 1 or 2 indices, math, and numerics: */
-		#include "../num/NUM.h"   /* Including math.h */
-	/* The messaging mechanism: */
-		#include "melder.h"   /* Including stdio.h string.h etc. */
+	/* The messaging mechanism, arrays with any bounds and 1 or 2 indices, math, and numerics: */
+		#include "melder.h"   /* Including stdio.h string.h math.h etc. */
 	/* The macros for struct and class definitions: */
 		#include "oo.h"
 	/* The input/output mechanism: */
 		#include "abcio.h"
 
-//#include <string>
-
 #define _Thing_auto_DEBUG  0
 
-/*
-	Use the macro 'iam'
-	as the first declaration in a function definition.
-	After this, the object 'me' has the right class (for the compiler),
-	so that you can use the macro 'my' to refer to members.
-	Example: int Person_getAge (void *void_me) { iam (Person); return my age; }
-*/
-#define iam(klas)  klas me = (klas) void_me
-#define my  me ->
-#define thy  thee ->
-#define your  you ->
-#define his  him ->
-#define her  she ->
-#define our  this ->
-
 typedef struct structClassInfo *ClassInfo;
 struct structClassInfo {
 	/*
@@ -204,9 +185,9 @@ ClassInfo Thing_classFromClassName (const char32 *className, int *formatVersion)
 	((klas) _Thing_dummyObject (class##klas))
 Thing _Thing_dummyObject (ClassInfo classInfo);
 
-char32 * Thing_getName (Thing me);
+const char32 * Thing_getName (Thing me);
 /* Return a pointer to your internal name (which can be null). */
-char32 * Thing_messageName (Thing me);
+const char32 * Thing_messageName (Thing me);
 
 void Thing_setName (Thing me, const char32 *name /* cattable */);
 /*
@@ -339,17 +320,6 @@ public:
 		our ptr = nullptr;   // make the pointer non-automatic again
 		return temp;
 	}
-	#if 0
-		operator T* () {
-			return our ptr;
-		}
-	#endif
-	/*
-	 * An autoThing can be cloned. This can be used for giving ownership without losing ownership.
-	 */
-	T* clone () const {
-		return static_cast<T *> (Data_copy (our ptr));
-	}
 	void reset () noexcept {
 		_Thing_forget (our ptr);
 		our ptr = nullptr;
@@ -525,7 +495,7 @@ class autoThingVector {
 	long d_from, d_to;
 public:
 	autoThingVector<T> (long from, long to) : d_from (from), d_to (to) {
-		d_ptr = static_cast <_Thing_auto<T>*> (NUMvector (sizeof (_Thing_auto<T>), from, to));
+		d_ptr = static_cast <_Thing_auto<T>*> (NUMvector (sizeof (_Thing_auto<T>), from, to, true));
 	}
 	autoThingVector (_Thing_auto<T> *ptr, long from, long to) : d_ptr (ptr), d_from (from), d_to (to) {
 	}
