@@ -1,6 +1,6 @@
 /* enums_getValue.h
  *
- * Copyright (C) 2007-2009,2015 Paul Boersma
+ * Copyright (C) 2007-2009,2015,2017 Paul Boersma
  *
  * This code is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -24,12 +24,12 @@
 #undef enums_add
 #undef enums_alt
 #undef enums_end
-#define enums_begin(type,minimum)  int type##_getValue (const char32 *testText) {
-#define enums_add(type,value,which,text)  if (Melder_str32equ_firstCharacterCaseInsensitive (testText, text)) return type##_##which;
-#define enums_alt(type,which,text)  if (Melder_str32equ_firstCharacterCaseInsensitive (testText, text)) return type##_##which;
-#define enums_end(type,maximum,def) \
-	if (str32equ (testText, U"\t")) return type##_DEFAULT; \
-	if (str32equ (testText, U"\n")) return maximum; \
-	return -1; }
+#define enums_begin(kType,minimum)  kType kType##_getValue (const char32 *testText) {
+#define enums_add(kType,value,which,text)  if (Melder_equ_firstCharacterCaseInsensitive (testText, text)) return kType::which;
+#define enums_alt(kType,which,text)  if (Melder_equ_firstCharacterCaseInsensitive (testText, text)) return kType::which;
+#define enums_end(kType,maximum,def) \
+	if (str32equ (testText, U"\t")) return kType::DEFAULT; \
+	if (str32equ (testText, U"\n")) return (kType) maximum; \
+	return (kType) -1; }
 
 /* End of file enums_getValue.h */
