@@ -1,6 +1,6 @@
 /* melder_files.cpp
  *
- * Copyright (C) 1992-2012,2013,2014,2015,2016 Paul Boersma, 2013 Tom Naughton
+ * Copyright (C) 1992-2012,2013,2014,2015,2016,2017 Paul Boersma, 2013 Tom Naughton
  *
  * This code is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -42,9 +42,6 @@
  * pb 2012/10/07 
  */
 
-#include <cstdio>
-using namespace std;
-
 #if defined (UNIX)
 	#include <unistd.h>
 	#include <sys/stat.h>
@@ -77,7 +74,7 @@ extern "C" void FLAC__stream_encoder_delete (FLAC__StreamEncoder *);
 
 static char32 theShellDirectory [kMelder_MAXPATH+1];
 void Melder_rememberShellDirectory () {
-	structMelderDir shellDir { { 0 } };
+	structMelderDir shellDir { };
 	Melder_getDefaultDir (& shellDir);
 	str32cpy (theShellDirectory, Melder_dirToPath (& shellDir));
 }
@@ -130,7 +127,13 @@ void Melder_str32To8bitFileRepresentation_inline (const char32 *string, char *ut
 void Melder_8bitFileRepresentationToStr32_inline (const char *path8, char32 *path32) {
 	#if defined (macintosh)
 		CFStringRef cfpath = CFStringCreateWithCString (nullptr, path8, kCFStringEncodingUTF8);
-		Melder_assert (cfpath != 0);
+		if (! cfpath) {
+			/*
+				Probably something wrong, like a disk was disconnected in the meantime.
+			*/
+			Melder_8to32_inline (path8, path32, (int) kMelder_textInputEncoding::UTF8);
+			Melder_throw (U"Unusual error finding or creating file ", path32, U".");
+		}
 		CFMutableStringRef cfpath2 = CFStringCreateMutableCopy (nullptr, 0, cfpath);
 		CFRelease (cfpath);
 		CFStringNormalize (cfpath2, kCFStringNormalizationFormC);   // Praat requires composed characters
@@ -151,7 +154,7 @@ void Melder_8bitFileRepresentationToStr32_inline (const char *path8, char32 *pat
 		path32 [n_utf32] = U'\0';
 		CFRelease (cfpath2);
 	#else
-		Melder_8to32_inline (path8, path32, kMelder_textInputEncoding_UTF8);
+		Melder_8to32_inline (path8, path32, (int) kMelder_textInputEncoding::UTF8);
 	#endif
 }
 #endif
@@ -211,7 +214,7 @@ void Melder_relativePathToFile (const char32 *path, MelderFile file) {
 		} else if (path [0] == U'/' || str32equ (path, U"<stdout>") || str32str (path, U"://")) {
 			str32cpy (file -> path, path);
 		} else {
-			structMelderDir dir = { { 0 } };
+			structMelderDir dir { };
 			Melder_getDefaultDir (& dir);   // BUG
 			if (dir. path [0] == U'/' && dir. path [1] == U'\0') {
 				Melder_sprint (file -> path,kMelder_MAXPATH+1, U"/", path);
@@ -226,7 +229,7 @@ void Melder_relativePathToFile (const char32 *path, MelderFile file) {
 		 *    LPT1:
 		 *    \\host\path
 		 */
-		structMelderDir dir { { 0 } };
+		structMelderDir dir { };
 		if (path [0] == U'~' && path [1] == U'/') {
 			Melder_getHomeDir (& dir);
 			Melder_sprint (file -> path,kMelder_MAXPATH+1, dir. path, & path [1]);
@@ -317,7 +320,7 @@ void MelderDir_getFile (MelderDir parent, const char32 *fileName, MelderFile fil
 }
 
 void MelderDir_relativePathToFile (MelderDir dir, const char32 *path, MelderFile file) {
-	structMelderDir saveDir { { 0 } };
+	structMelderDir saveDir { };
 	Melder_getDefaultDir (& saveDir);
 	Melder_setDefaultDir (dir);
 	Melder_relativePathToFile (path, file);
@@ -496,7 +499,7 @@ void Melder_getHomeDir (MelderDir homeDir) {
 
 void Melder_getPrefDir (MelderDir prefDir) {
 	#if defined (macintosh)
-		structMelderDir homeDir;
+		structMelderDir homeDir { };
 		Melder_getHomeDir (& homeDir);
 		Melder_sprint (prefDir -> path,kMelder_MAXPATH+1, homeDir. path, U"/Library/Preferences");
 	#elif defined (UNIX)
@@ -706,7 +709,7 @@ bool MelderFile_readable (MelderFile file) {
 	}
 }
 
-long MelderFile_length (MelderFile file) {
+integer MelderFile_length (MelderFile file) {
 	#if defined (UNIX)
 		char utf8path [kMelder_MAXPATH+1];
 		Melder_str32To8bitFileRepresentation_inline (file -> path, utf8path);
@@ -717,7 +720,7 @@ long MelderFile_length (MelderFile file) {
 		try {
 			autofile f = Melder_fopen (file, "r");
 			fseek (f, 0, SEEK_END);
-			long length = ftell (f);
+			integer length = ftell (f);
 			f.close (file);
 			return length;
 		} catch (MelderError) {
@@ -777,14 +780,14 @@ void Melder_setDefaultDir (MelderDir dir) {
 }
 
 void MelderFile_setDefaultDir (MelderFile file) {
-	structMelderDir dir { { 0 } };
+	structMelderDir dir { };
 	MelderFile_getParentDir (file, & dir);
 	Melder_setDefaultDir (& dir);
 }
 
 void Melder_createDirectory (MelderDir parent, const char32 *dirName, int mode) {
 #if defined (UNIX)
-	structMelderFile file { 0 };
+	structMelderFile file { };
 	if (dirName [0] == U'/') {
 		Melder_sprint (file. path,kMelder_MAXPATH+1, dirName);   // absolute path
 	} else if (parent -> path [0] == U'/' && parent -> path [1] == U'\0') {
@@ -797,7 +800,7 @@ void Melder_createDirectory (MelderDir parent, const char32 *dirName, int mode)
 	if (mkdir (utf8path, mode) == -1 && errno != EEXIST)   // ignore if directory already exists
 		Melder_throw (U"Cannot create directory ", & file, U".");
 #elif defined (_WIN32)
-	structMelderFile file { 0 };
+	structMelderFile file { };
 	SECURITY_ATTRIBUTES sa;
 	(void) mode;
 	sa. nLength = sizeof (SECURITY_ATTRIBUTES);
@@ -819,8 +822,6 @@ void Melder_createDirectory (MelderDir parent, const char32 *dirName, int mode)
  * Routines for wrapping the file pointers.
  */
 
-#define my  me ->
-
 MelderFile MelderFile_open (MelderFile me) {
 	my filePointer = Melder_fopen (me, "rb");
 	my openForReading = true;
@@ -836,7 +837,7 @@ char * MelderFile_readLine (MelderFile me) {
 	if (! buffer) {
 		buffer = Melder_malloc (char, capacity = 100);
 	}
-	for (i = 0; 1; i ++) {
+	for (i = 0; true; i ++) {
 		if (i >= capacity) {
 			buffer = (char *) Melder_realloc (buffer, capacity *= 2);
 		}
@@ -873,7 +874,7 @@ MelderFile MelderFile_create (MelderFile me) {
 	return me;
 }
 
-void MelderFile_seek (MelderFile me, long position, int direction) {
+void MelderFile_seek (MelderFile me, integer position, int direction) {
 	if (! my filePointer) return;
 	if (fseek (my filePointer, position, direction)) {
 		fclose (my filePointer);
@@ -882,9 +883,9 @@ void MelderFile_seek (MelderFile me, long position, int direction) {
 	}
 }
 
-long MelderFile_tell (MelderFile me) {
+integer MelderFile_tell (MelderFile me) {
 	if (! my filePointer) return 0;
-	long result = ftell (my filePointer);
+	integer result = ftell (my filePointer);
 	if (result == -1) {
 		fclose (my filePointer);
 		my filePointer = nullptr;
