@@ -1,6 +1,6 @@
 /* oo_DESTROY.h
  *
- * Copyright (C) 1994-2012,2013,2014,2015,2016 Paul Boersma
+ * Copyright (C) 1994-2012,2013,2014,2015,2016,2017 Paul Boersma
  *
  * This code is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -31,14 +31,14 @@
 	NUMmatrix_free <type> (our x, row1, col1);
 
 
-#define oo_ENUMx(type,storage,Type,x)
+#define oo_ENUMx(kType,storage,x)
 
-#define oo_ENUMx_ARRAY(type,storage,Type,x,cap,n)
+//#define oo_ENUMx_ARRAY(kType,storage,x,cap,n)
 
-#define oo_ENUMx_SET(type,storage,Type,x,setType)
+//#define oo_ENUMx_SET(kType,storage,x,setType)
 
-#define oo_ENUMx_VECTOR(type,storage,Type,x,min,max)  \
-	NUMvector_free <type> (our x, min);
+//#define oo_ENUMx_VECTOR(kType,storage,x,min,max)  \
+//	NUMvector_free <type> (our x, min);
 
 #define oo_STRINGx(storage,x)  \
 	Melder_free (our x);
@@ -48,7 +48,7 @@
 		Melder_free (our x [i]);
 
 #define oo_STRINGx_SET(storage,x,setType)  \
-	for (int i = 0; i <= setType##_MAX; i ++) \
+	for (int i = 0; i <= setType::MAX; i ++) \
 		Melder_free (our x [i]);
 
 #define oo_STRINGx_VECTOR(storage,x,min,max)  \
@@ -66,7 +66,7 @@
 		our x [i]. destroy ();
 
 #define oo_STRUCT_SET(Type,x,setType)  \
-	for (int i = 0; i <= setType##_MAX; i ++) \
+	for (int i = 0; i <= (int) setType::MAX; i ++) \
 		our x [i]. destroy ();
 
 #define oo_STRUCT_VECTOR_FROM(Type,x,min,max)  \
