@@ -1,6 +1,6 @@
 /* oo_READ_BINARY.h
  *
- * Copyright (C) 1994-2012,2013,2014,2015,2016 Paul Boersma
+ * Copyright (C) 1994-2012,2013,2014,2015,2016,2017 Paul Boersma
  *
  * This code is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -28,7 +28,7 @@
 	}
 
 #define oo_SET(type,storage,x,setType)  \
-	for (int i = 0; i <= setType##_MAX; i ++) { \
+	for (int i = 0; i <= (int) setType::MAX; i ++) { \
 		our x [i] = binget##storage (f); \
 	}
 
@@ -42,26 +42,26 @@
 	    our x = NUMmatrix_readBinary_##storage (row1, row2, col1, col2, f); \
 	}
 
-#define oo_ENUMx(type,storage,Type,x)  \
-	our x = binget##storage (f, Type##_MIN, Type##_MAX, U"" #Type);
+#define oo_ENUMx(kType,storage,x)  \
+	our x = (kType) binget##storage (f, (int) kType::MIN, (int) kType::MAX, U"" #kType);
 
-#define oo_ENUMx_ARRAY(type,storage,Type,x,cap,n)  \
-	if (n > cap) Melder_throw (U"Number of \"" #x U"\" (", n, U") greater than ", cap, U"."); \
-	for (int i = 0; i < n; i ++) { \
-		our x [i] = binget##storage (f, Type##_MIN, Type##_MAX, U"" #Type); \
-	}
+//#define oo_ENUMx_ARRAY(kType,storage,x,cap,n)  \
+//	if (n > cap) Melder_throw (U"Number of \"" #x U"\" (", n, U") greater than ", cap, U"."); \
+//	for (int i = 0; i < n; i ++) { \
+//		our x [i] = (kType) binget##storage (f, (int) kType::MIN, (int) kType::MAX, U"" #kType); \
+//	}
 
-#define oo_ENUMx_SET(type,storage,Type,x,setType)  \
-	for (int i = 0; i <= setType##_MAX; i ++) { \
-		our x [i] = binget##storage (f, Type##_MIN, Type##_MAX, U"" #Type); \
-	}
+//#define oo_ENUMx_SET(kType,storage,x,setType)  \
+//	for (int i = 0; i <= (int) setType::MAX; i ++) { \
+//		our x [i] = (kType) binget##storage (f, (int) kType::MIN, (int) kType::MAX, U"" #kType); \
+//	}
 
-#define oo_ENUMx_VECTOR(type,storage,Type,x,min,max)  \
-	if (max >= min) { \
-		our x = NUMvector <type> (min, max); \
-		for (long i = min; i <= max; i ++) { \
-			our x [i] = binget##storage (f, Type##_MIN, Type##_MAX, U"" #Type); \
-	}
+//#define oo_ENUMx_VECTOR(kType,storage,x,min,max)  \
+//	if (max >= min) { \
+//		our x = NUMvector <type> (min, max); \
+//		for (integer i = min; i <= max; i ++) { \
+//			our x [i] = (kType) binget##storage (f, (int) kType::MIN, (int) kType::MAX, U"" #kType); \
+//	}
 
 #define oo_STRINGx(storage,x)  \
 	our x = binget##storage (f);
@@ -73,7 +73,7 @@
 	}
 
 #define oo_STRINGx_SET(storage,x,setType)  \
-	for (int i = 0; i <= setType##_MAX; i ++) { \
+	for (int i = 0; i <= setType::MAX; i ++) { \
 		our x [i] = binget##storage (f); \
 	}
 
@@ -95,7 +95,7 @@
 	}
 
 #define oo_STRUCT_SET(Type,x,setType) \
-	for (int i = 0; i <= setType##_MAX; i ++) { \
+	for (int i = 0; i <= (int) setType::MAX; i ++) { \
 		our x [i]. readBinary (f, formatVersion); \
 	}
 
@@ -125,7 +125,7 @@
 
 #define oo_COLLECTION_OF(Class,x,ItemClass,formatVersion)  \
 	{ \
-		int32 n = bingeti4 (f); \
+		int32 n = bingeti32 (f); \
 		for (int32 i = 1; i <= n; i ++) { \
 			auto##ItemClass item = Thing_new (ItemClass); \
 			item -> v_readBinary (f, formatVersion); \
@@ -135,7 +135,7 @@
 
 #define oo_AUTO_COLLECTION(Class,x,ItemClass,formatVersion)  \
 	{ \
-		int32 n = bingeti4 (f); \
+		int32 n = bingeti32 (f); \
 		our x = Class##_create (); \
 		for (int32 i = 1; i <= n; i ++) { \
 			auto##ItemClass item = Thing_new (ItemClass); \
