@@ -1,6 +1,6 @@
 /* oo_WRITE_TEXT.h
  *
- * Copyright (C) 1994-2012,2013,2014,2015 Paul Boersma
+ * Copyright (C) 1994-2012,2013,2014,2015,2017 Paul Boersma
  *
  * This code is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -29,8 +29,8 @@
 
 #define oo_SET(type,storage,x,setType)  \
 	texputintro (file, U"" #x U" []:", 0,0,0,0,0); \
-	for (int i = 0; i <= setType##_MAX; i ++) \
-		texput##storage (file, our x [i], U"" #x U" [", setType##_getText (i), U"]", 0,0,0); \
+	for (int i = 0; i <= (int) setType::MAX; i ++) \
+		texput##storage (file, our x [i], U"" #x U" [", setType##_getText ((setType) i), U"]", 0,0,0); \
 	texexdent (file);
 
 #define oo_VECTOR(type,storage,x,min,max)  \
@@ -41,26 +41,26 @@
 	if (our x) \
 		NUMmatrix_writeText_##storage (our x, row1, row2, col1, col2, file, U"" #x);
 
-#define oo_ENUMx(type,storage,Type,x)  \
-	texput##storage (file, our x, Type##_getText, U"" #x, 0,0,0,0,0);
+#define oo_ENUMx(kType,storage,x)  \
+	texput##storage (file, (int) our x, (const char32* (*) (int)) kType##_getText, U"" #x, 0,0,0,0,0);
 
-#define oo_ENUMx_ARRAY(type,storage,Type,x,cap,n)  \
-	texputintro (file, U"" #x U" []:", 0,0,0,0,0); \
-	for (int i = 0; i < n; i ++) \
-		texput##storage (file, our x [i], Type##_getText, U"" #x U" [", Melder_integer (i), U"]", 0,0,0); \
-	texexdent (file);
+//#define oo_ENUMx_ARRAY(kType,storage,x,cap,n)  \
+//	texputintro (file, U"" #x U" []:", 0,0,0,0,0); \
+//	for (int i = 0; i < n; i ++) \
+//		texput##storage (file, (int) our x [i], (const char32* (*) (int)) kType##_getText, U"" #x U" [", Melder_integer (i), U"]", 0,0,0); \
+//	texexdent (file);
 
-#define oo_ENUMx_SET(type,storage,Type,x,setType)  \
-	texputintro (file, U"" #x U" []: ", n ? nullptr : U"(empty)", 0,0,0,0); \
-	for (int i = 0; i <= setType##_MAX; i ++) \
-		texput##storage (file, our x [i], Type##_getText, U"" #x U" [", setType##_getText (i), U"]", 0,0,0); \
-	texexdent (file);
+//#define oo_ENUMx_SET(kType,storage,x,setType)  \
+//	texputintro (file, U"" #x U" []: ", n ? nullptr : U"(empty)", 0,0,0,0); \
+//	for (int i = 0; i <= (int) setType::MAX; i ++) \
+//		texput##storage (file, (int) our x [i], (const char32* (*) (int)) kType##_getText, U"" #x U" [", setType##_getText ((setType) i), U"]", 0,0,0); \
+//	texexdent (file);
 
-#define oo_ENUMx_VECTOR(type,storage,Type,x,min,max)  \
-	texputintro (file, U"" #x U" []: ", max >= min ? nullptr : U"(empty)", 0,0,0,0); \
-	for (long i = min; i <= max; i ++) \
-		texput##storage (file, our x [i], Type##_getText, U"" #x U" [", Melder_integer (i), U"]", 0,0,0); \
-	texexdent (file);
+//#define oo_ENUMx_VECTOR(kType,storage,x,min,max)  \
+//	texputintro (file, U"" #x U" []: ", max >= min ? nullptr : U"(empty)", 0,0,0,0); \
+//	for (long i = min; i <= max; i ++) \
+//		texput##storage (file, (int) our x [i], (const char32* (*) (int)) kType##_getText, U"" #x U" [", Melder_integer (i), U"]", 0,0,0); \
+//	texexdent (file);
 
 #define oo_STRINGx(storage,x)  \
 	texput##storage (file, our x, U""#x, 0,0,0,0,0);
@@ -73,8 +73,8 @@
 
 #define oo_STRINGx_SET(storage,x,setType)  \
 	texputintro (file, U"" #x U" []:", 0,0,0,0,0); \
-	for (int i = 0; i <= setType##_MAX; i ++) \
-		texput##storage (file, our x [i], U"" #x U" [", setType##_getText (i), U"]", 0,0,0); \
+	for (int i = 0; i <= (int) setType::MAX; i ++) \
+		texput##storage (file, our x [i], U"" #x U" [", setType##_getText ((setType) i), U"]", 0,0,0); \
 	texexdent (file);
 
 #define oo_STRINGx_VECTOR(storage,x,min,max)  \
@@ -99,8 +99,8 @@
 
 #define oo_STRUCT_SET(Type,x,setType)  \
 	texputintro (file, U"" #x U" []:", 0,0,0,0,0); \
-	for (int i = 0; i <= setType##_MAX; i ++) { \
-		texputintro (file, U"" #x U" [", setType##_getText (i), U"]:", 0,0,0); \
+	for (int i = 0; i <= (int) setType::MAX; i ++) { \
+		texputintro (file, U"" #x U" [", setType##_getText ((setType) i), U"]:", 0,0,0); \
 		our x [i]. writeText (file); \
 		texexdent (file); \
 	} \
@@ -134,7 +134,7 @@
 		Data_writeText (our x.get(), file);
 
 #define oo_COLLECTION_OF(Class,x,ItemClass,version)  \
-	texputi4 (file, our x.size, U"" #x U": size", 0,0,0,0,0); \
+	texputi32 (file, our x.size, U"" #x U": size", 0,0,0,0,0); \
 	for (long i = 1; i <= our x.size; i ++) { \
 		ItemClass data = our x.at [i]; \
 		texputintro (file, U"" #x U" [", Melder_integer (i), U"]:", 0,0,0); \
@@ -143,7 +143,7 @@
 	}
 
 #define oo_AUTO_COLLECTION(Class,x,ItemClass,version)  \
-	texputi4 (file, our x ? our x->size : 0, U"" #x U": size", 0,0,0,0,0); \
+	texputi32 (file, our x ? our x->size : 0, U"" #x U": size", 0,0,0,0,0); \
 	if (our x) { \
 		for (long i = 1; i <= our x->size; i ++) { \
 			ItemClass data = our x->at [i]; \
