@@ -27,7 +27,7 @@
 static bool praat_mouseSelectsInnerViewport;
 
 void praat_picture_prefs () {
-	Preferences_addEnum (U"Picture.font", & theCurrentPraatPicture -> font, kGraphics_font, kGraphics_font_DEFAULT);
+	Preferences_addEnum (U"Picture.font", & theCurrentPraatPicture -> font, kGraphics_font, kGraphics_font::DEFAULT);
 	Preferences_addInt (U"Picture.fontSize", & theCurrentPraatPicture -> fontSize, 10);
 	Preferences_addBool (U"Picture.mouseSelectsInnerViewport", & praat_mouseSelectsInnerViewport, false);
 }
@@ -40,13 +40,13 @@ static autoPicture praat_picture;
 
 /***** "Font" MENU: font part *****/
 
-static GuiMenuItem praatButton_fonts [1 + kGraphics_font_MAX];
+static GuiMenuItem praatButton_fonts [1 + (int) kGraphics_font::MAX];
 
 static void updateFontMenu () {
 	if (! theCurrentPraatApplication -> batch) {
-		if (theCurrentPraatPicture -> font < kGraphics_font_MIN) theCurrentPraatPicture -> font = kGraphics_font_MIN;
-		if (theCurrentPraatPicture -> font > kGraphics_font_MAX) theCurrentPraatPicture -> font = kGraphics_font_MAX;
-		for (int i = kGraphics_font_MIN; i <= kGraphics_font_MAX; i ++) {
+		if (theCurrentPraatPicture -> font < (int) kGraphics_font::MIN) theCurrentPraatPicture -> font = (int) kGraphics_font::MIN;
+		if (theCurrentPraatPicture -> font > (int) kGraphics_font::MAX) theCurrentPraatPicture -> font = (int) kGraphics_font::MAX;
+		for (int i = (int) kGraphics_font::MIN; i <= (int) kGraphics_font::MAX; i ++) {
 			GuiMenuItem_check (praatButton_fonts [i], theCurrentPraatPicture -> font == i);
 		}
 	}
@@ -56,15 +56,15 @@ static void setFont (kGraphics_font font) {
 		autoPraatPicture picture;
 		Graphics_setFont (GRAPHICS, font);
 	}
-	theCurrentPraatPicture -> font = font;
+	theCurrentPraatPicture -> font = (int) font;
 	if (theCurrentPraatPicture == & theForegroundPraatPicture) {
 		updateFontMenu ();
 	}
 }
-DIRECT (GRAPHICS_Times)     { setFont (kGraphics_font_TIMES);     END }
-DIRECT (GRAPHICS_Helvetica) { setFont (kGraphics_font_HELVETICA); END }
-DIRECT (GRAPHICS_Palatino)  { setFont (kGraphics_font_PALATINO);  END }
-DIRECT (GRAPHICS_Courier)   { setFont (kGraphics_font_COURIER);   END }
+DIRECT (GRAPHICS_Times)     { setFont (kGraphics_font::TIMES);     END }
+DIRECT (GRAPHICS_Helvetica) { setFont (kGraphics_font::HELVETICA); END }
+DIRECT (GRAPHICS_Palatino)  { setFont (kGraphics_font::PALATINO);  END }
+DIRECT (GRAPHICS_Courier)   { setFont (kGraphics_font::COURIER);   END }
 
 /***** "Font" MENU: size part *****/
 
@@ -289,7 +289,7 @@ DO
 	autoPraatPicture picture;
 	Graphics_inqWindow (GRAPHICS, & x1WC, & x2WC, & y1WC, & y2WC);
 	Graphics_setWindow (GRAPHICS, 0, 1, 0, 1);
-	Graphics_setTextAlignment (GRAPHICS, horizontalAlignment, verticalAlignment);
+	Graphics_setTextAlignment (GRAPHICS, (kGraphics_horizontalAlignment) horizontalAlignment, verticalAlignment);
 	Graphics_setTextRotation (GRAPHICS, rotation);
 	Graphics_text (GRAPHICS, horizontalAlignment == 0 ? 0.0 : horizontalAlignment == 1 ? 0.5 : 1.0,
 		verticalAlignment == 0 ? 0.0 : verticalAlignment == 1 ? 0.5 : 1.0, text);
@@ -439,7 +439,7 @@ static void GRAPHICS_Picture_writeToEpsFile (UiForm sendingForm, int narg, Stack
 		GRAPHICS_Picture_writeToEpsFile, nullptr, invokingButtonTitle, nullptr);
 	if (narg < 0) UiForm_info (dia, narg); else if (! sendingForm && ! args && ! sendingString) {
 		UiOutfile_do (dia, U"praat.eps");
-	} else { MelderFile file; structMelderFile file2 { 0 };
+	} else { MelderFile file; structMelderFile file2 { };
 		if (! args && ! sendingString) file = UiFile_getFile (dia);
 		else { Melder_relativePathToFile (args ? args [1]. string : sendingString, & file2); file = & file2; }
 		Picture_writeToEpsFile (praat_picture.get(), file, true, false);
@@ -457,7 +457,7 @@ static void GRAPHICS_Picture_writeToFontlessEpsFile_xipa (UiForm sendingForm, in
 		GRAPHICS_Picture_writeToFontlessEpsFile_xipa, nullptr, invokingButtonTitle, nullptr);
 	if (narg < 0) UiForm_info (dia, narg); else if (! sendingForm && ! args && ! sendingString) {
 		UiOutfile_do (dia, U"praat.eps");
-	} else { MelderFile file; structMelderFile file2 { 0 };
+	} else { MelderFile file; structMelderFile file2 { };
 		if (! args && ! sendingString) file = UiFile_getFile (dia);
 		else { Melder_relativePathToFile (args ? args [1]. string : sendingString, & file2); file = & file2; }
 		Picture_writeToEpsFile (praat_picture.get(), file, false, false);
@@ -472,7 +472,7 @@ static void GRAPHICS_Picture_writeToFontlessEpsFile_silipa (UiForm sendingForm,
 		GRAPHICS_Picture_writeToFontlessEpsFile_silipa, nullptr, invokingButtonTitle, nullptr);
 	if (narg < 0) UiForm_info (dia, narg); else if (! sendingForm && ! args && ! sendingString) {
 		UiOutfile_do (dia, U"praat.eps");
-	} else { MelderFile file; structMelderFile file2 { 0 };
+	} else { MelderFile file; structMelderFile file2 { };
 		if (! args && ! sendingString) file = UiFile_getFile (dia);
 		else { Melder_relativePathToFile (args ? args [1]. string : sendingString, & file2); file = & file2; }
 		Picture_writeToEpsFile (praat_picture.get(), file, false, true);
@@ -487,7 +487,7 @@ static void GRAPHICS_Picture_writeToPdfFile (UiForm sendingForm, int narg, Stack
 		GRAPHICS_Picture_writeToPdfFile, nullptr, invokingButtonTitle, nullptr);
 	if (narg < 0) UiForm_info (dia, narg); else if (! sendingForm && ! args && ! sendingString) {
 		UiOutfile_do (dia, U"praat.pdf");
-	} else { MelderFile file; structMelderFile file2 { 0 };
+	} else { MelderFile file; structMelderFile file2 { };
 		if (! args && ! sendingString) file = UiFile_getFile (dia);
 		else { Melder_relativePathToFile (args ? args [1]. string : sendingString, & file2); file = & file2; }
 		if (theCurrentPraatPicture == & theForegroundPraatPicture) {
@@ -495,7 +495,7 @@ static void GRAPHICS_Picture_writeToPdfFile (UiForm sendingForm, int narg, Stack
 		} else {
 			try {
 				//autoPraatPicture picture;
-				autoGraphics graphics = Graphics_create_pdffile (file, 300, NUMundefined, 10.24, NUMundefined, 7.68);
+				autoGraphics graphics = Graphics_create_pdffile (file, 300, undefined, 10.24, undefined, 7.68);
 				Graphics_play (GRAPHICS, graphics.get());
 			} catch (MelderError) {
 				Melder_throw (U"Picture not written to PDF file ", file, U".");
@@ -512,7 +512,7 @@ static void GRAPHICS_Picture_writeToPngFile_300 (UiForm sendingForm, int narg, S
 		GRAPHICS_Picture_writeToPngFile_300, nullptr, invokingButtonTitle, nullptr);
 	if (narg < 0) UiForm_info (dia, narg); else if (! sendingForm && ! args && ! sendingString) {
 		UiOutfile_do (dia, U"praat.png");
-	} else { MelderFile file; structMelderFile file2 { 0 };
+	} else { MelderFile file; structMelderFile file2 { };
 		if (! args && ! sendingString) file = UiFile_getFile (dia);
 		else { Melder_relativePathToFile (args ? args [1]. string : sendingString, & file2); file = & file2; }
 		if (theCurrentPraatPicture == & theForegroundPraatPicture) {
@@ -536,7 +536,7 @@ static void GRAPHICS_Picture_writeToPngFile_600 (UiForm sendingForm, int narg, S
 		GRAPHICS_Picture_writeToPngFile_600, nullptr, invokingButtonTitle, nullptr);
 	if (narg < 0) UiForm_info (dia, narg); else if (! sendingForm && ! args && ! sendingString) {
 		UiOutfile_do (dia, U"praat.png");
-	} else { MelderFile file; structMelderFile file2 { 0 };
+	} else { MelderFile file; structMelderFile file2 { };
 		if (! args && ! sendingString) file = UiFile_getFile (dia);
 		else { Melder_relativePathToFile (args ? args [1]. string : sendingString, & file2); file = & file2; }
 		if (theCurrentPraatPicture == & theForegroundPraatPicture) {
@@ -560,7 +560,7 @@ static void GRAPHICS_Picture_writeToPraatPictureFile (UiForm sendingForm, int na
 		GRAPHICS_Picture_writeToPraatPictureFile, nullptr, invokingButtonTitle, nullptr);
 	if (narg < 0) UiForm_info (dia, narg); else if (! sendingForm && ! args && ! sendingString) {
 		UiOutfile_do (dia, U"praat.prapic");
-	} else { MelderFile file; structMelderFile file2 { 0 };
+	} else { MelderFile file; structMelderFile file2 { };
 		if (! args && ! sendingString) file = UiFile_getFile (dia);
 		else { Melder_relativePathToFile (args ? args [1]. string : sendingString, & file2); file = & file2; }
 		Picture_writeToPraatPictureFile (praat_picture.get(), file);
@@ -590,7 +590,7 @@ END }
 			GRAPHICS_Picture_writeToWindowsMetafile, nullptr, invokingButtonTitle, nullptr);
 		if (! sendingForm && ! args && ! sendingString) {
 			UiOutfile_do (dia, U"praat.emf");
-		} else { MelderFile file; structMelderFile file2 { 0 };
+		} else { MelderFile file; structMelderFile file2 { };
 			if (! args && ! sendingString) file = UiFile_getFile (dia);
 			else { Melder_relativePathToFile (args ? args [1]. string : sendingString, & file2); file = & file2; }
 			Picture_writeToWindowsMetafile (praat_picture.get(), file);
@@ -653,7 +653,7 @@ FORM (GRAPHICS_Text, U"Praat picture: Text", U"Text...") {
 	OK
 DO
 	GRAPHICS_NONE
-		Graphics_setTextAlignment (GRAPHICS, horizontalAlignment, verticalAlignment);
+		Graphics_setTextAlignment (GRAPHICS, (kGraphics_horizontalAlignment) horizontalAlignment, verticalAlignment);
 		Graphics_setInner (GRAPHICS);
 		Graphics_text (GRAPHICS, horizontalPosition, verticalPosition, text);
 		Graphics_unsetInner (GRAPHICS);
@@ -681,7 +681,7 @@ DO
 	kGraphics_font currentFont = Graphics_inqFont (GRAPHICS);
 	int currentSize = Graphics_inqFontSize (GRAPHICS);
 	GRAPHICS_NONE
-		Graphics_setTextAlignment (GRAPHICS, horizontalAlignment, verticalAlignment);
+		Graphics_setTextAlignment (GRAPHICS, (kGraphics_horizontalAlignment) horizontalAlignment, verticalAlignment);
 		Graphics_setInner (GRAPHICS);
 		Graphics_setFont (GRAPHICS, (kGraphics_font) font);
 		Graphics_setFontSize (GRAPHICS, fontSize);
@@ -777,9 +777,9 @@ DO
 	function -> dx = (toX - fromX) / (numberOfHorizontalSteps - 1);
 	Formula_compile (interpreter, function.get(), formula, kFormula_EXPRESSION_TYPE_NUMERIC, true);
 	for (long i = 1; i <= numberOfHorizontalSteps; i ++) {
-		struct Formula_Result result;
+		Formula_Result result;
 		Formula_run (1, i, & result);
-		y [i] = result. result.numericResult;
+		y [i] = result. numericResult;
 	}
 	GRAPHICS_NONE
 		Graphics_setInner (GRAPHICS);
@@ -1506,7 +1506,7 @@ DIRECT (GRAPHICS_Picture_settings_report) {
 		theCurrentPraatPicture != & theForegroundPraatPicture ?
 			theCurrentPraatPicture -> y2NDC - ymargin :
 			12 - theCurrentPraatPicture -> y1NDC - ymargin, units);
-	MelderInfo_writeLine (U"Font: ", kGraphics_font_getText (theCurrentPraatPicture -> font));
+	MelderInfo_writeLine (U"Font: ", kGraphics_font_getText ((kGraphics_font) theCurrentPraatPicture -> font));
 	MelderInfo_writeLine (U"Line type: ",
 		theCurrentPraatPicture -> lineType == Graphics_DRAWN ? U"Solid" :
 		theCurrentPraatPicture -> lineType == Graphics_DOTTED ? U"Dotted" :
@@ -1870,10 +1870,10 @@ void praat_picture_init () {
 	praatButton_18 = praat_addMenuCommand (U"Picture", U"Font", U"18", nullptr, praat_CHECKBUTTON | praat_NO_API, GRAPHICS_18);
 	praatButton_24 = praat_addMenuCommand (U"Picture", U"Font", U"24", nullptr, praat_CHECKBUTTON | praat_NO_API, GRAPHICS_24);
 	praat_addMenuCommand (U"Picture", U"Font", U"-- font ---", nullptr, 0, nullptr);
-	praatButton_fonts [kGraphics_font_TIMES] = praat_addMenuCommand (U"Picture", U"Font", U"Times", nullptr, praat_RADIO_FIRST, GRAPHICS_Times);
-	praatButton_fonts [kGraphics_font_HELVETICA] = praat_addMenuCommand (U"Picture", U"Font", U"Helvetica", nullptr, praat_RADIO_NEXT, GRAPHICS_Helvetica);
-	praatButton_fonts [kGraphics_font_PALATINO] = praat_addMenuCommand (U"Picture", U"Font", U"Palatino", nullptr, praat_RADIO_NEXT, GRAPHICS_Palatino);
-	praatButton_fonts [kGraphics_font_COURIER] = praat_addMenuCommand (U"Picture", U"Font", U"Courier", nullptr, praat_RADIO_NEXT, GRAPHICS_Courier);
+	praatButton_fonts [(int) kGraphics_font::TIMES] = praat_addMenuCommand (U"Picture", U"Font", U"Times", nullptr, praat_RADIO_FIRST, GRAPHICS_Times);
+	praatButton_fonts [(int) kGraphics_font::HELVETICA] = praat_addMenuCommand (U"Picture", U"Font", U"Helvetica", nullptr, praat_RADIO_NEXT, GRAPHICS_Helvetica);
+	praatButton_fonts [(int) kGraphics_font::PALATINO] = praat_addMenuCommand (U"Picture", U"Font", U"Palatino", nullptr, praat_RADIO_NEXT, GRAPHICS_Palatino);
+	praatButton_fonts [(int) kGraphics_font::COURIER] = praat_addMenuCommand (U"Picture", U"Font", U"Courier", nullptr, praat_RADIO_NEXT, GRAPHICS_Courier);
 
 	praat_addMenuCommand (U"Picture", U"Help", U"Picture window help", nullptr, '?', HELP_PictureWindowHelp);
 	praat_addMenuCommand (U"Picture", U"Help", U"About special symbols", nullptr, 0, HELP_AboutSpecialSymbols);
