@@ -1,6 +1,6 @@
 /* prefs_define.h
  *
- * Copyright (C) 2013,2015 Paul Boersma
+ * Copyright (C) 2013,2015,2017 Paul Boersma
  *
  * This code is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -75,11 +75,11 @@
 
 #define prefs_add_enum(Klas,name,version,enumerated,default) \
 	enum enumerated struct##Klas :: s_##name; \
-	enum enumerated struct##Klas :: sdefault_##name = enumerated##_##default;
+	enum enumerated struct##Klas :: sdefault_##name = enumerated :: default;
 #define prefs_add_enum_with_data(Klas,name,version,enumerated,default)  prefs_add_enum (Klas, name, version, enumerated, default)
 #define prefs_override_enum(Klas,name,version,enumerated,default) \
 	enum enumerated struct##Klas :: s_##name; \
-	enum enumerated struct##Klas :: sdefault_##name = enumerated##_##default;
+	enum enumerated struct##Klas :: sdefault_##name = enumerated :: default;
 
 #define prefs_add_string(Klas,name,version,default) \
 	char32 struct##Klas :: s_##name [Preferences_STRING_BUFFER_SIZE]; \
